/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 06852
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1993
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE cigtry    985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE cig5pk    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cigage    981='(981) NEVER USED CIGARETTES Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned'
                  991='(991) NEVER USED CIGARETTES' 993='(993) NEVER SMOKED DAILY'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cigyrs    985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE packs     1='(1) One to five cigarettes a day'
                  2='(2) About 1/2 pack a day (6-15 cigarettes)'
                  3='(3) About a pack a day (16-25 cigarettes)'
                  4='(4) About 1 1/2 packs a day (26-35 cigarettes)'
                  5='(5) About 2 packs or more a day (over 35 cigarettes)'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigrec    1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE avcig     1='(1) Less than one cigarette a day'
                  2='(2) One to five cigarettes a day'
                  3='(3) About 1/2 pack a day (6-15 cigarettes)'
                  4='(4) About a pack a day (16-25 cigarettes)'
                  5='(5) About 1 1/2 packs a day (26-35 cigarettes)'
                  6='(6) About 2 packs or more a day (over 35 cigarettes)'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigtime   9981='(9981) NEVER USED CIGARETTES Logically assigned'
                  9985='(9985) BAD DATA Logically assigned'
                  9989='(9989) LEGITIMATE SKIP Logically assigned'
                  9991='(9991) NEVER USED CIGARETTES' 9994='(9994) DON''T KNOW'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE snufrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE othtob    1='(1) Daily in the past 12 Months'
                  2='(2) Almost daily (3-6 days a week)' 3='(3) 1 or 2 days a week'
                  4='(4) Several times a month (25-51 days a year)'
                  5='(5) 1 or 2 times a month (12-24 days a year)'
                  6='(6) Every other month or so (6-11 days a year)'
                  7='(7) 3-5 days this past year' 8='(8) 1 or 2 days this past year'
                  83='(83) DID NOT USE SMOKELESS TOBACCO PST YR Logic.assgn.'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alctry    981='(981) NEVER USED ALCOHOL Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED ALCOHOL'
                  994='(994) DON''T KNOW' 998='(998) BLANK (NO ANSWER)' ;
  VALUE alcrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' ;
  VALUE alcage    981='(981) NEVER USED ALCOHOL Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED ALCOHOL'
                  993='(993) NEVER USED ALCOHOL MONTHLY OR MORE OFTEN'
                  994='(994) DON''T KNOW' 998='(998) BLANK (NO ANSWER)' ;
  VALUE alcdays   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nodr30a   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dr5day    81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30a   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30dy  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcpat    1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkyr   1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  9='(9) Never got very high or drunk in past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcbeer   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DON''T KNOW' ;
  VALUE alcwine   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL' ;
  VALUE alcliqr   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL' ;
  VALUE alcvary   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY IMPUTED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE butisol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buticaps  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amytal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mebaral   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE placidyl  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE doriden   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE noludar   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nembutal  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seconal   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tuinal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dalmane   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE restoril  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halcion   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amobarb   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phenobar  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methaq    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE chhyd     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pentob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE secob     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sednewa   108='(108) Nembutal' 120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  122='(122) Sleep Aid' 127='(127) Nytol' 129='(129) Reds' 135='(135) Mini Thins'
                  137='(137) 7-14' 158='(158) Calmociteno (in Brazil)' 159='(159) Octanox'
                  160='(160) sic' 161='(161) Rufonol' 162='(162) sic' 201='(201) Valium'
                  206='(206) Tranxene' 209='(209) Xanax' 224='(224) Triavil' 311='(311) Preludin'
                  326='(326) White cross' 327='(327) Black beauties, Black Beauty'
                  339='(339) Amphetamines (speed generically)' 369='(369) Artane'
                  401='(401) Darvon' 409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  415='(415) Codeine' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  422='(422) Motrin' 423='(423) Percocet' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  435='(435) Tylenol, Tylenol Extrastrength' 456='(456) see also 434'
                  704='(704) Dope' 811='(811) Muscle relaxers'
                  864='(864) Dramamine ,Motion sickness pill'
                  981='(981) NEVER USED SEDATIVES Logically assigned'
                  991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewb   116='(116) Methaqualone, Quaalude, Sopor' 209='(209) Xanax' 244='(244) sic'
                  247='(247) Adapin, Doxepin, Sinequan' 326='(326) White cross'
                  362='(362) Benadryl' 415='(415) Codeine' 428='(428) sic'
                  991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewc   809='(809) Pills' 991='(991) NEVER USED SEDATIVES'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewd   991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewe   991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Sedative use LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seddknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedage    981='(981) NEVER USED SEDATIVES Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED SEDATIVES' 994='(994) DON''T KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE sedtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedrec    1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  83='(83) DID NOT USE SEDATIVE PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE ANY SEDATIVE IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY IMPUTED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE valium    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE librium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE limbtrol  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE menrium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE serax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranxene  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ativan    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE centrax   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE xanax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE paxipam   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buspar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE miltown   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE equanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE deprol    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE vistar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE atarax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE durrax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE diazepam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skly      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE meprob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnewa    110='(110) Tuinal' 116='(116) Methaqualone, Quaalude, Sopor'
                  131='(131) Haldol, Haloperidol' 201='(201) Valium' 207='(207) Ativan'
                  209='(209) Xanax' 218='(218) Diazepam'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 227='(227) Thorazine'
                  228='(228) see also 239' 234='(234) Cyclobenzaprine, Flexeril'
                  239='(239) see also 228' 268='(268) Rahipinal'
                  269='(269) Pasidrin (in Mexico)' 270='(270) Torzien' 336='(336) Diet pills'
                  344='(344) Bennies' 415='(415) Codeine' 422='(422) Motrin' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin' 437='(437) Parafon Forte'
                  438='(438) Anaprox, Naprosyn' 991='(991) NEVER USED TRANQUILIZERS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewb    128='(128) Nervine' 226='(226) Stelazine, Trifluoperazine HCl'
                  991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewc    230='(230) Compazine' 991='(991) NEVER USED TRANQUILIZERS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewd    991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewe    991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnosp    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Tranquilizer use LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trdknam   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED TRANQUILIZERS Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranage   981='(981) NEVER USED TRANQUILIZERS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trantot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED TRANQUILIZERS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED TRANQUILIZERS Logically assigned'
                  83='(83) DID NOT USE TRANQUILIZER PAST 12 MOS. Logic.assgnd'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE ANY TRANQUILIZER IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY IMPUTED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexed     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dexamyl   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE eskat     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE benz      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE biphet    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE desoxyn   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tenuate   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tepanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE didrex    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE plegine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE preludin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ionamin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fastin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pondimin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE voranil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sanorex   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mazanor   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ritalin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cylert    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE detamp    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methi     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methamp   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE obla      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimnewa  124='(124) Yellow jackets' 135='(135) Mini Thins' 145='(145) Red devil(s)'
                  301='(301) Dexedrine' 305='(305) Biphetamine' 313='(313) Fastin, Phentermine'
                  316='(316) Sanorex' 324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  325='(325) USED STIMULANT, DON''T KNOW NAME' 326='(326) White cross'
                  327='(327) Black beauties, Black Beauty' 328='(328) Pink hearts'
                  329='(329) Robin''s eggs, speckled eggs' 331='(331) Whites, Blancas'
                  332='(332) see also 346' 333='(333) 357 Magnum, Magnum 44'
                  334='(334) Crossroads, cross tops' 335='(335) Dexatrim'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  344='(344) Bennies' 347='(347) Phenylpropanolamine' 348='(348) Crystal'
                  352='(352) Lemons' 353='(353) No-Doz' 354='(354) Vivarin' 355='(355) Crystal meth'
                  357='(357) Heart-shaped black pills' 384='(384) Little crosses'
                  385='(385) Little pink one' 386='(386) Ma Huang' 388='(388) Pink lemon'
                  389='(389) sic' 390='(390) Max Alert' 391='(391) sic'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  430='(430) Aspirin, Ecotrin, Empirin'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  606='(606) sic' 621='(621) Red dragon' 635='(635) Ginseng seeds' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  814='(814) Caffeine' 815='(815) Coffee' 991='(991) NEVER USED STIMULANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewb  124='(124) Yellow jackets' 254='(254) sic' 326='(326) White cross'
                  327='(327) Black beauties, Black Beauty' 328='(328) Pink hearts'
                  332='(332) see also 346' 334='(334) Crossroads, cross tops'
                  339='(339) Amphetamines (speed generically)' 344='(344) Bennies'
                  353='(353) No-Doz' 354='(354) Vivarin' 355='(355) Crystal meth' 363='(363) Bam(s)'
                  620='(620) Blue dragon' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  814='(814) Caffeine' 991='(991) NEVER USED STIMULANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewc  374='(374) Christmas tree(s)' 991='(991) NEVER USED STIMULANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewd  387='(387) Pink football' 991='(991) NEVER USED STIMULANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewe  991='(991) NEVER USED STIMULANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnosp  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Stimulant use LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmdknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimage   981='(981) NEVER USED STIMULANTS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED STIMULANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED STIMULANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) DID NOT USE STIMULANT PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stneedle  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) NEVER USED AMPHETAMINES W/A NEEDLE Logic.assigned'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) NEVER USED AMPHETAMINES WITH A NEEDLE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlread   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY IMPUTED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE darvon    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dolene    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sk65a     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wygesic   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE levodro   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE percodan  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE demerol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dilaud    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tylcod    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phencod   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talwin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talwinnx  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talacen   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE propoxy   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE codeine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anilerid  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morphine  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methdon   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stadol    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analnewa  234='(234) Cyclobenzaprine, Flexeril'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  406='(406) Oxycodone, Percodan, Roxicet' 407='(407) Demerol'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 422='(422) Motrin'
                  423='(423) Percocet' 425='(425) Advil'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin' 431='(431) Tylox'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  438='(438) Anaprox, Naprosyn' 442='(442) Ibuprofen' 443='(443) Dolobid'
                  455='(455) Fiorinal with Codeine' 470='(470) Cafergot'
                  471='(471) Butazolidin' 472='(472) Indocin, Indomethacin'
                  473='(473) Pyridium' 474='(474) sic' 475='(475) sic' 476='(476) Isocom, Midrin'
                  477='(477) Neo-Melubrina (Spanish)' 479='(479) Pentrexyl'
                  480='(480) Robitussin AC with Codeine' 702='(702) Heroin' 703='(703) Opium'
                  811='(811) Muscle relaxers' 820='(820) Penicillin' 829='(829) Robitussin DM'
                  991='(991) NEVER USED ANALGESICS' 992='(992) ILLEGIBLE'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewb  415='(415) Codeine' 424='(424) Fioricet'
                  430='(430) Aspirin, Ecotrin, Empirin'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  443='(443) Dolobid' 450='(450) Acetaminophen' 828='(828) Tetracycline'
                  991='(991) NEVER USED ANALGESICS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewc  478='(478) Nogirtronia' 991='(991) NEVER USED ANALGESICS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewd  234='(234) Cyclobenzaprine, Flexeril' 991='(991) NEVER USED ANALGESICS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewe  991='(991) NEVER USED ANALGESICS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE anlnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Analgesic use LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anldknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analage   981='(981) NEVER USED ANALGESICS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED ANALGESICS' 994='(994) DON''T KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analrec   1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anlyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED ANALGESICS Logically assigned'
                  83='(83) DID NOT USE ANALGESICS PAST 12 MO. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjopp     981='(981) NEVER HAD CHANCE TO TRY MARIJUANA Logic.assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER HAD CHANCE TO TRY MARIJUANA' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE mjage     981='(981) NEVER USED MARIJUANA Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED MARIJUANA' 994='(994) DON''T KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE mjtot     1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjrec     1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE mjday30a  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30a   81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30b   81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjamt30a  1='(1) 1 to 10 joints in the past 30 days'
                  2='(2) 11 to 20 joints in the past 30 days'
                  3='(3) About 1 ounce in the past 30 days'
                  4='(4) About 2 ounces in the past 30 days'
                  5='(5) 3 to 4 ounces in the past 30 days'
                  6='(6) 5 to 6 ounces in the past 30 days'
                  8='(8) 8 ounces in the past 30 days'
                  30='(30) 30 ounces in the past 30 days'
                  55='(55) Nickel bag in the past 30 days'
                  77='(77) More than 6 oz. exact amt not spec. in pst 30 days'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjfriend  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjdealer  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjothshr  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjgiven   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjtrgood  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjtrserv  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjstole   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjtrick   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjgrew    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjobtnon  2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjbuck    .0='(.0) Did not spend any money on marijuana pst 30 days'
                  9981.0='(9981.0) NEVER USED MARIJUANA Logically assigned'
                  9983.0='(9983.0) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  9985.0='(9985.0) BAD DATA Logically assigned'
                  9991.0='(9991.0) NEVER USED MARIJUANA'
                  9993.0='(9993.0) DID NOT USE MARIJUANA IN THE PAST 30 DAYS'
                  9994.0='(9994.0) DON''T KNOW' 9997.0='(9997.0) REFUSED'
                  9998.0='(9998.0) BLANK (NO ANSWER)' ;
  VALUE mjyrfreq  1='(1) Several times a day in the past 12 months'
                  2='(2) Daily in the past 12 months'
                  3='(3) Almost daily or 3 to 6 days a week'
                  4='(4) 1 or 2 days a week'
                  5='(5) Several times a month (about 25 to 51 days a year)'
                  6='(6) 1 to 2 times a month (12 to 24 days a year)'
                  7='(7) Every other month or so (6 to 11 days a year)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjjoint   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' ;
  VALUE mjpipe    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' ;
  VALUE mjbake    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' ;
  VALUE mjchew    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' ;
  VALUE mjway     1='(1) Response circled, method not specified'
                  2='(2) Response not circled'
                  4='(4) PST 30 DAY OR PST 12 MTH MJ USER W/NO Q.M-11 ANS.'
                  6='(6) Can with holes/in a bowl' 7='(7) One hitter/pinch hit'
                  8='(8) Boiled with tea'
                  9='(9) Smoky small room(burn in small room like bathroom)'
                  12='(12) Chewing/eating/suck on stems/gumming'
                  13='(13) Through an apple made like a pipe' 14='(14) sic'
                  15='(15) Steam roller' 16='(16) Laced'
                  17='(17) Blunts/smoked with or in a cigar/in cigar paper'
                  19='(19) With cocaine' 24='(24) Drank it'
                  25='(25) Hash under glass/can/glass bottle'
                  28='(28) In tobacco paper/rolling paper' 31='(31) Joint'
                  32='(32) Pipe/water pipe'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS' ;
  VALUE mjlfdaly  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED (from UDAYMJ)'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  91='(91) NEVER USED MARIJUANA' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhread   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gas       1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (from GAS30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE lgas      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (from LGAS30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sppaint   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm SPPAN30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm AEROS30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE glue      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm GLUE30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE solvent   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm SOLVN30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amylnit   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm AMLNT30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ether     1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nitoxid   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm NOX30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cleflu    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CLFL30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnewa   327='(327) Black beauties, Black Beauty' 348='(348) Crystal'
                  417='(417) Morphine' 501='(501) Gasoline or lighter fluids'
                  503='(503) Other aerosol sprays'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  505='(505) Lacquer thinner or other paint solvents'
                  506='(506) Amyl nitrite, poppers, locker rm odorizer,rush'
                  507='(507) Halothane, ether, or other anesthetics; chloroform'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  509='(509) Corr flds, degreasers, cleaning flds, Liquid Paper'
                  511='(511) Markers, felt-tip pens, ink pens' 513='(513) sic' 514='(514) sic'
                  515='(515) Vicks' 516='(516) Freon' 518='(518) Acetone, nail polish remover'
                  519='(519) Helium' 524='(524) see also 509' 525='(525) see also 521,544'
                  526='(526) Nail polish' 528='(528) Whipped-cream can'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  539='(539) ScotchGard' 540='(540) PAM' 542='(542) Spirits of ammonia'
                  545='(545) Car tailpipe exhaust fumes, CO2' 553='(553) Pixie sticks'
                  555='(555) Chillers' 558='(558) Kool Aid' 559='(559) LOLOY' 560='(560) Soap'
                  561='(561) Amputee gas cleanser' 562='(562) Ban apple gas'
                  563='(563) Acetylene' 565='(565) Trichloroethane'
                  566='(566) Smoked tea from Lipton tea bag' 567='(567) Pertussin spray'
                  568='(568) Tally' 569='(569) Peganento' 570='(570) PVC (in Mexico)'
                  702='(702) Heroin' 706='(706) Smack' 803='(803) sic'
                  805='(805) Cocaine, coke, coca'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco' 852='(852) sic'
                  900='(900) Non-Drug reason given for Drug Problem'
                  981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewb   322='(322) Methamphetamine (speed or ice or crank)'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  509='(509) Corr flds, degreasers, cleaning flds, Liquid Paper'
                  511='(511) Markers, felt-tip pens, ink pens'
                  518='(518) Acetone, nail polish remover' 519='(519) Helium'
                  524='(524) see also 509' 548='(548) Cologne, rubbing alcohol'
                  556='(556) Energine' 564='(564) Electric contact cleaner'
                  818='(818) Nicotine'
                  981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewc   504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  519='(519) Helium' 981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewd   981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewe   981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhage    981='(981) NEVER USED INHALANTS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED INHALANTS' 994='(994) DON''T KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE inhtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhrec    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gas30a    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE lgas30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sppan30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic. assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE glue30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USED INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE solvn30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE amlnt30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ether30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USED INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nox30a    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE clfl30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE innew30a  348='(348) Crystal'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  505='(505) Lacquer thinner or other paint solvents'
                  509='(509) Corr flds, degreasers, cleaning flds, Liquid Paper'
                  511='(511) Markers, felt-tip pens, ink pens' 519='(519) Helium'
                  524='(524) see also 509' 526='(526) Nail polish'
                  528='(528) Whipped-cream can' 539='(539) ScotchGard'
                  900='(900) Non-Drug reason given for Drug Problem'
                  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS IN PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30b  519='(519) Helium' 981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30c  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS IN PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30d  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30e  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS IN PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE in30nosp  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inh30no   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  4='(4) Response not circled LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdy30a  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhpo     1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc1f  1='(1) QUESTION 1 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc2f  2='(2) QUESTION 2 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc3f  3='(3) QUESTION 3 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc4f  4='(4) QUESTION 4 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc5f  5='(5) QUESTION 5 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc6f  6='(6) QUESTION 6 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc7f  7='(7) QUESTION 7 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc8f  8='(8) QUESTION 8 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc0f  10='(10) ALL QUESTIONS WERE CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhansy   1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocopp    981='(981) NEVER HAD A CHANCE TO TRY COCAINE Logic. assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER HAD A CHANCE TO TRY COCAINE IN ANY FORM'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE cocage    981='(981) NEVER USED COCAINE Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED COCAINE'
                  994='(994) DON''T KNOW' 998='(998) BLANK (NO ANSWER)' ;
  VALUE coctot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocrec    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  91='(91) NEVER USED COCAINE' ;
  VALUE cocus30a  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' ;
  VALUE cocam30a  1='(1) Used some but less than 1/4 gram in past 30 days'
                  2='(2) About 1/4 gram in the past 30 days'
                  3='(3) About 1/2 gram in the past 30 days'
                  4='(4) About 1 gram in the past 30 days'
                  5='(5) About 2 grams in the past 30 days'
                  6='(6) About 3 grams in the past 30 days'
                  7='(7) About 4 grams in the past 30 days'
                  8='(8) About 5 grams in the past 30 days'
                  10='(10) About 7 grams in the past 30 days'
                  12='(12) About 9 grams in the past 30 days'
                  15='(15) About 12 grams in the past 30 days'
                  19='(19) About 16 grams in the past 30 days'
                  77='(77) More than 3 grams exact amt not spec. pst 30 days'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 30 DAYS Logic.assignd'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ccfriend  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKFRIEND)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ccdealer  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKDEALER)'
                  81='(81) NEVER USED COCAINE Logically Assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ccothshr  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKOTHSHR)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ccgiven   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKGIVEN)'
                  81='(81) NEVER USED COCAINE Logically Assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cctrgood  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKTRGOOD)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PST 30 DAYS Logic assgn.'
                  97='(97) REFUSED' ;
  VALUE cctrserv  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKTRSERV)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PST 30 DAYS Logic assgn.'
                  97='(97) REFUSED' ;
  VALUE ccstole   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (from CKSTOLE)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cctrick   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKTRICK)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ccobtnon  2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cocbuck   0='(0) Did not spend any money on cocaine pst 30 days'
                  9981='(9981) NEVER USED COCAINE Logically assigned'
                  9983='(9983) DID NOT USE COCAINE PAST 30 DAYS Logic.assigned'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED COCAINE'
                  9993='(9993) DID NOT USE COCAINE IN PAST 30 DAYS'
                  9994='(9994) DON''T KNOW' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE cocyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 12 MONTHS Logic.assgnd'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocsniff  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logically assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE cocswal   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logically assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE cociv     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CONDLREC)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logically assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE freebase  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CRAKREC)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logically assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE cocway    1='(1) Response circled, method not specified'
                  2='(2) Response not circled'
                  4='(4) PST 3O DAYS OR PST 12 MTH COC USR W/NO Q.CN-10 ANS'
                  7='(7) On my gums/mouth' 8='(8) Freeze, put on tongue'
                  9='(9) Smoked in a cigarette/Snowcap' 10='(10) Laced with marijuana'
                  11='(11) Smoked using aluminum foil' 12='(12) Pop-can bong'
                  13='(13) Lined with PCP' 14='(14) Mixed in food' 15='(15) Sexually'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logically assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE condlrec  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) USED COCAINE BUT NEVER W/A NEEDLE Logic. assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) USED COCAINE BUT NEVER W/A NEEDLE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cclfdaly  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED (from UDAYCOC)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  91='(91) NEVER USED COCAINE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crakrec   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED CRACK Logically assigned'
                  91='(91) NEVER USED CRACK' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkam30a  981='(981) NEVER USED CRACK Logically assigned'
                  983='(983) DID NOT USE CRACK IN PAST 30 DAYS Logic.assignd'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED CRACK'
                  993='(993) DID NOT USE CRACK IN PAST 30 DAYS' 994='(994) DON''T KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE ckfriend  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ckdealer  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ckothshr  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ckgiven   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cktrgood  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cktrserv  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ckstole   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cktrick   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ckobtnon  2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' ;
  VALUE crakbuck  0='(0) Did not spend any money on crack pst 30 days'
                  9981='(9981) NEVER USED CRACK Logically assigned'
                  9983='(9983) DID NOT USE CRACK PAST 30 DAYS Logic.assigned'
                  9985='(9985) BAD DATA Logically assigned' 9991='(9991) NEVER USED CRACK'
                  9993='(9993) DID NOT USE CRACK IN PAST 30 DAYS' 9994='(9994) DON''T KNOW'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE cklfdaly  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED CRACK Logically assigned'
                  91='(91) NEVER USED CRACK' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE lsd       1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE peyote    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mesc      1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE psilcy    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcp       1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm PCPREC)'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ecstasy   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnewa   116='(116) Methaqualone, Quaalude, Sopor' 125='(125) sic'
                  142='(142) Belladona' 248='(248) sic' 267='(267) Marezine'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)'
                  501='(501) Gasoline or lighter fluids'
                  509='(509) Corr flds, degreasers, cleaning flds, Liquid Paper'
                  601='(601) see also 618' 602='(602) Peyote'
                  604='(604) Psilocybin (mushrooms)' 606='(606) sic'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 609='(609) sic' 614='(614) MDA'
                  616='(616) DMT' 617='(617) Morning glory seeds' 618='(618) see also 601'
                  622='(622) Microdot(s), purple microdot' 625='(625) Window pane'
                  628='(628) Hawaiian rosebud seed tea' 636='(636) STP' 646='(646) sic'
                  649='(649) sic' 653='(653) Cricketshit' 654='(654) Eve' 657='(657) Orange barrel'
                  658='(658) Special' 659='(659) Boat (Marijuana & PCP)'
                  660='(660) Toad, Toad licking' 661='(661) sic' 662='(662) Kanepolin'
                  702='(702) Heroin' 703='(703) Opium' 802='(802) THC, cannabinol' 803='(803) sic'
                  981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewb   328='(328) Pink hearts' 348='(348) Crystal' 601='(601) see also 618'
                  616='(616) DMT' 624='(624) Orange sunshine, sunshine, yellow sunshine'
                  636='(636) STP' 646='(646) sic' 655='(655) Flying elephant' 658='(658) Special'
                  864='(864) Dramamine ,Motion sickness pill'
                  981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewc   625='(625) Window pane' 652='(652) ALD-52, ALD-S2 (version of LSD)'
                  656='(656) Mars'
                  981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewd   981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewe   981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE haldknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallopp   981='(981) NEVER HAD A CHANCE TO TRY HALLUCINOGENS Logic.asgn'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER HAD A CHANCE TO TRY HALLUCINOGENS'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE hallage   981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE halltot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hal30use  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  83='(83) DID NOT USE HALLUCINOGENS PST 30 DAYS Logic.assgnd'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 30 DAYS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  83='(83) DID NOT USE HALLUCINOGENS PST 12 MOS. Logic.assgnd'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcprec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED PCP Logically assigned' 91='(91) NEVER USED PCP'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE heropp    981='(981) NEVER HAD A CHANCE TO TRY HEROIN Logic.assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER HAD A CHANCE TO TRY HEROIN' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE herage    981='(981) NEVER USED HEROIN Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED HEROIN'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE hertot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE her30use  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) DID NOT USE HEROIN PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 30 DAYS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herneedl  1='(1) Yes, have used heroin with a needle'
                  2='(2) No, have used heroin, but not with a needle'
                  3='(3) Yes, used heroin w/a needle LOGICALLY IMPUTED'
                  4='(4) No, used heroin, but w/o a needle LOGIC. IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hrndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) NEVER USED HEROIN WITH A NEEDLE Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) NEVER USED HEROIN WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hersmoke  1='(1) Yes, have smoked heroin'
                  2='(2) No, have used heroin, but have never smoked it'
                  3='(3) Yes, have smoked heroin LOGICALLY IMPUTED'
                  4='(4) No, used heroin, but never smoked it LOGIC.IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hrsmkrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) USED HEROIN IN LIFE/NEVER SMOKED Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) USED HEROIN IN LIFE BUT NEVER SMOKED IT' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hersniff  1='(1) Yes, have sniffed (snorted) heroin'
                  2='(2) No, have used heroin, but have never sniffed it'
                  3='(3) Yes, have sniffed (snorted) heroin LOGIC.IMPUTED'
                  4='(4) No, used heroin, but never sniffed LOGIC. IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hrsnfrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) USED HEROIN IN LIFE/NEVER SNIFFED Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) USED HEROIN IN LIFE BUT NEVER SNIFFED IT' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drgread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdcig     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdalc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdsed     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdtran    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdstm     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdanal    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdmj      1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdinh     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdcoc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdhall    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdher     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdothop   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdnone    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned (CDCIG > 1)'
                  91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned (CDALC > 1)'
                  91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdtran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned (CDMJ > 1)'
                  91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdhall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdnone   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE efftran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effhall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effnone   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaycig   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayalc   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaysed   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaytran  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaystm   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayanal  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaymj    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayinh   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaycoc   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayhall  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayher   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayoth   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaynone  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE deptran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dephall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depnone   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wscig     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsalc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wssed     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wstran    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsstm     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsanal    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsmj      1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsinh     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wscoc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wshall    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsher     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsothop   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsnone    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ndlread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndllif  1='(1) Yes, have used a needle to take a drug'
                  2='(2) No, have never used a needle to take a drug'
                  3='(3) Yes, have used a ndle to take a drug LOGIC.IMPUTED'
                  4='(4) No, have never used a ndle to take drug, LOGIC. IM'
                  81='(81) NEVER USED A NEEDLE TO TAKE A DRUG Logic.assigned'
                  91='(91) NEVER USED A NEEDLE TO TAKE A DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ANY DRUG FOR NONMDCL RSN Logic.assigned'
                  83='(83) NEVER USED A NDL TO TAKE ANY DRUG Logic. assigned'
                  91='(91) NEVER USED ANY DRUG FOR NONMEDICAL REASONS'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlsed  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndltra  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlstm  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm STNDLREC)'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlanl  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlinh  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlcoc  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CONDLREC)'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlhal  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlher  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm HRNDLREC)'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlopt  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlstr  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LSTD ABOVE Logically assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlnon  2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlshf  1='(1) Yes, have used a needle after someone else used it'
                  2='(2) No, have not used a needle after someone used it'
                  81='(81) NEVER USED ANY DRUG Logically assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUG'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndls0f  1='(1) Yes, someone used a needle after I used it'
                  2='(2) No, no one has used a needle after I used it'
                  81='(81) NEVER USED ANY DRUG Logically assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUG'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sptread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drugtest  1='(1) Yes' 2='(2) No' 3='(3) Did not have a job during past 12 months'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE testpos   1='(1) Yes' 2='(2) No' 3='(3) Did not receive test in past 12 months'
                  4='(4) Did not have a job during past 12 months'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE icelife   1='(1) Yes' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED ICE Logically assigned' 91='(91) NEVER USED ICE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE icerec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ICE Logically assigned' 91='(91) NEVER USED ICE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE steropp   981='(981) NEVER HAD CHANCE TO TRY ANABOLIC STEROIDS Log.asn'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER HAD A CHANCE TO TRY ANABOLIC STEROIDS'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sterage   981='(981) NEVER USED ANABOLIC STEROIDS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED ANABOLIC STEROIDS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stertot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED ANABOLIC STEROIDS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED ANABOLIC STEROIDS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sterrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ANABOLIC STEROIDS Logically assigned'
                  91='(91) NEVER USED ANABOLIC STEROIDS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE spnewa    0='(0) None (code used only for question SP-9)'
                  116='(116) Methaqualone, Quaalude, Sopor'
                  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  142='(142) Belladona' 222='(222) USED TRANQUILIZER, DON''T KNOW NAME'
                  240='(240) Lithium carbonate'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  326='(326) White cross' 327='(327) Black beauties, Black Beauty'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 375='(375) sic'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  415='(415) Codeine'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  438='(438) Anaprox, Naprosyn' 516='(516) Freon' 601='(601) see also 618'
                  604='(604) Psilocybin (mushrooms)' 606='(606) sic' 611='(611) Greens'
                  636='(636) STP' 654='(654) Eve' 658='(658) Special' 660='(660) Toad, Toad licking'
                  703='(703) Opium' 705='(705) Speed Ball (heroin + cocaine)' 803='(803) sic'
                  804='(804) Hashish' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  824='(824) Steroids' 828='(828) Tetracycline' 832='(832) Primo'
                  844='(844) Blood pressure medication' 857='(857) sic' 859='(859) sic'
                  866='(866) Boomers' 867='(867) Boron' 868='(868) sic' 872='(872) sic'
                  873='(873) Contraceptives, Ferutal, Ortho Novum' 880='(880) Frios'
                  881='(881) YLOALE' 900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewb    239='(239) see also 228'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth' 456='(456) see also 434'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  616='(616) DMT' 803='(803) sic' 805='(805) Cocaine, coke, coca'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  824='(824) Steroids' 852='(852) sic' 871='(871) sic' 876='(876) Glass'
                  878='(878) Friying' 900='(900) Non-Drug reason given for Drug Problem'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewc    355='(355) Crystal meth' 406='(406) Oxycodone, Percodan, Roxicet'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  652='(652) ALD-52, ALD-S2 (version of LSD)' 803='(803) sic'
                  804='(804) Hashish'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewd    806='(806) Crack, rock' 879='(879) Dimethyltriptamide MMPT'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewe    701='(701) OTHER Opiates, NOT SPECIFIED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE booked    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nobookyr  0='(0) Was not arrested and booked in past 12 months'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE bklarcny  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkburgl   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkagaslt  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bksmaslt  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkmvthft  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkrob     1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkrape    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkmurder  2='(2) Response not circled' 85='(85) BAD DATA Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkarson   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkdrvinf  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkdrunk   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkdrug    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkpros    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkvandal  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkothoff  1='(1) Larceny or theft' 2='(2) Burglary or breaking and entering'
                  3='(3) Aggravated assault'
                  4='(4) Other assault, such as simple assault or battery'
                  6='(6) Robbery'
                  8='(8) Murder, homicide, or nonnegligent manslaughter'
                  10='(10) Driving under the influence'
                  11='(11) Drunkenness or other liquor law violation'
                  12='(12) Possession or sale of drugs'
                  14='(14) Oth proprty offns:- fraud, poss stln goods, vndlsm'
                  15='(15) Other offenses (NOT SPECIFIED)' 16='(16) Weapons offenses'
                  17='(17) Other offenses against persons'
                  18='(18) Violation of court order, parole, probation'
                  19='(19) Public order offenses' 20='(20) Juvenile status offenses'
                  22='(22) Traffic violations' 85='(85) BAD DATA Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE notbked   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE probaton  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE parole    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE strsteal  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othsteal  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE damage    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE carsteal  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE forcemon  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE breakin   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phyfight  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hurtbad   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gunmoney  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkdrv  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE solddrug  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othdoing  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE othdospf  1='(1) Shoplifting' 2='(2) Other larceny or theft'
                  3='(3) Property damage/destruction (incl. vandalism)'
                  4='(4) Motor vehicle theft' 5='(5) Robbery'
                  6='(6) Breaking and entering'
                  7='(7) Hitting someone or physically fighting'
                  8='(8) Hurting someone enough to need medical attn'
                  9='(9) Other assault, battery'
                  10='(10) Driving under the influence of alcohol or drugs'
                  11='(11) Selling illegal drugs'
                  12='(12) Drug offense (except sales) involving marijuana'
                  13='(13) Other drug-related offenses'
                  14='(14) Drunkenness or other liquor law violation'
                  17='(17) Other offenses against persons' 18='(18) Arson'
                  19='(19) Nondestructive prop offenses, fraud, stln goods'
                  20='(20) Prostitution of commercialized sex'
                  21='(21) Weapons offenses'
                  22='(22) Violation of court order, parole, probation'
                  23='(23) Public order offenses' 24='(24) Juvenile status offenses'
                  26='(26) Traffic violations' 27='(27) Other offenses, NOT SPECIFIED'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othdos0f  1='(1) Shoplifting' 2='(2) Other larceny or theft'
                  3='(3) Property damage/destruction (incl. vandalism)'
                  4='(4) Motor vehicle theft'
                  7='(7) Hitting someone or physically fighting'
                  8='(8) Hurting someone enough to need medical attn'
                  9='(9) Other assault, battery'
                  10='(10) Driving under the influence of alcohol or drugs'
                  11='(11) Selling illegal drugs'
                  12='(12) Drug offense (except sales) involving marijuana'
                  13='(13) Other drug-related offenses'
                  14='(14) Drunkenness or other liquor law violation' 18='(18) Arson'
                  19='(19) Nondestructive prop offenses, fraud, stln goods'
                  21='(21) Weapons offenses' 23='(23) Public order offenses'
                  24='(24) Juvenile status offenses' 26='(26) Traffic violations'
                  27='(27) Other offenses, NOT SPECIFIED'
                  85='(85) BAD DATA Logically assigned' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dexread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE noboozyr  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  85='(85) BAD DATA Logically assigned' ;
  VALUE alcaggr   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcargum  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcabsnt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alchigh   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcjob    1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcmatcd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcrelcd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcfrdcd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alctoss   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcholic  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcdrunk  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcintox  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcrem    1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcquick  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcmorn   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcshook  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcalone  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcbrkpm  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcmj     1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alccoc    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcopt    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alchal    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcinh    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcanal   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alctran   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcstm    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcsed    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE as13none  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' ;
  VALUE drdeprss  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depdrg1a  116='(116) Methaqualone, Quaalude, Sopor' 201='(201) Valium'
                  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin' 313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 375='(375) sic'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  501='(501) Gasoline or lighter fluids' 502='(502) Spray paints'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 557='(557) Hagwash'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) sic' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic' 804='(804) Hashish'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 809='(809) Pills' 810='(810) Hemp'
                  812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco' 869='(869) sic'
                  874='(874) Premarin' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg2a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg3a  339='(339) Amphetamines (speed generically)'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 601='(601) see also 618'
                  604='(604) Psilocybin (mushrooms)' 803='(803) sic' 804='(804) Hashish'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg4a  415='(415) Codeine' 601='(601) see also 618'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drargum   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE argdrg1a  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 415='(415) Codeine' 440='(440) Soma' 557='(557) Hagwash'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  804='(804) Hashish' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 824='(824) Steroids'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg2a  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 408='(408) Dilaudid' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg3a  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg4a  508='(508) Nitrous oxide, whippets, dentist gas'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg5a  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE dralone   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alndrg1a  201='(201) Valium' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 241='(241) Prozac'
                  312='(312) Ionamin' 322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 401='(401) Darvon'
                  406='(406) Oxycodone, Percodan, Roxicet' 408='(408) Dilaudid'
                  601='(601) see also 618' 604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 707='(707) Black Tar' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) sic' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg2a  209='(209) Xanax' 324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  840='(840) Cough medicine (contents not specified)'
                  848='(848) Liquid vitamin'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg3a  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE dranx     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE anxdrg1a  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 247='(247) Adapin, Doxepin, Sinequan' 271='(271) Zoloft'
                  301='(301) Dexedrine' 309='(309) Didrex' 312='(312) Ionamin'
                  313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  332='(332) see also 346' 336='(336) Diet pills'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  354='(354) Vivarin' 355='(355) Crystal meth' 375='(375) sic' 408='(408) Dilaudid'
                  415='(415) Codeine' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 557='(557) Hagwash'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) sic' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  702='(702) Heroin' 704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) sic' 804='(804) Hashish' 805='(805) Cocaine, coke, coca'
                  806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine' 815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 873='(873) Contraceptives, Ferutal, Ortho Novum'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg2a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  601='(601) see also 618' 604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg3a  326='(326) White cross' 702='(702) Heroin' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drhealth  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltdrg1a  209='(209) Xanax' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 362='(362) Benadryl' 408='(408) Dilaudid'
                  501='(501) Gasoline or lighter fluids' 557='(557) Hagwash'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  639='(639) Cloves, Nutmeg' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 870='(870) sic'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 992='(992) ILLEGIBLE'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg2a  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  506='(506) Amyl nitrite, poppers, locker rm odorizer,rush'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  702='(702) Heroin' 803='(803) sic' 805='(805) Cocaine, coke, coca'
                  806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine' 815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  865='(865) Diuretics, Water pills'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg3a  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  702='(702) Heroin' 803='(803) sic'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg4a  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg5a  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drnthink  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ntkdrg1a  116='(116) Methaqualone, Quaalude, Sopor'
                  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 241='(241) Prozac'
                  247='(247) Adapin, Doxepin, Sinequan' 271='(271) Zoloft' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 354='(354) Vivarin' 355='(355) Crystal meth' 401='(401) Darvon'
                  407='(407) Demerol' 408='(408) Dilaudid'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  418='(418) Methadone' 501='(501) Gasoline or lighter fluids'
                  502='(502) Spray paints'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, felt-tip pens, ink pens' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 609='(609) sic'
                  702='(702) Heroin' 704='(704) Dope' 705='(705) Speed Ball (heroin + cocaine)'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic' 804='(804) Hashish'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  815='(815) Coffee' 823='(823) sic'
                  840='(840) Cough medicine (contents not specified)'
                  873='(873) Contraceptives, Ferutal, Ortho Novum'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg2a  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  407='(407) Demerol' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  506='(506) Amyl nitrite, poppers, locker rm odorizer,rush'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg3a  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 601='(601) see also 618'
                  602='(602) Peyote' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  702='(702) Heroin' 803='(803) sic' 804='(804) Hashish' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg4a  415='(415) Codeine' 510='(510) OTHER Inhalant, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg5a  201='(201) Valium' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  803='(803) sic' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drupset   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE upsdrg1a  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 601='(601) see also 618'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine' 815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 824='(824) Steroids'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg2a  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 408='(408) Dilaudid'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 811='(811) Muscle relaxers'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine' 815='(815) Coffee'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg3a  437='(437) Parafon Forte' 601='(601) see also 618'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drlswork  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE lswdrg1a  201='(201) Valium' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  501='(501) Gasoline or lighter fluids'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  804='(804) Hashish' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  815='(815) Coffee' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg2a  408='(408) Dilaudid' 508='(508) Nitrous oxide, whippets, dentist gas'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg3a  339='(339) Amphetamines (speed generically)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) sic'
                  804='(804) Hashish'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED' 805='(805) Cocaine, coke'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drsuspic  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE sspdrg1a  312='(312) Ionamin' 322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  707='(707) Black Tar' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  804='(804) Hashish' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg2a  322='(322) Methamphetamine (speed or ice or crank)'
                  408='(408) Dilaudid' 601='(601) see also 618'
                  604='(604) Psilocybin (mushrooms)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg3a  339='(339) Amphetamines (speed generically)' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drcope    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cpedrg1a  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  702='(702) Heroin' 704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) sic' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  818='(818) Nicotine' 824='(824) Steroids' 877='(877) Methazolamide'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg2a  239='(239) see also 228' 408='(408) Dilaudid' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg3a  339='(339) Amphetamines (speed generically)' 803='(803) sic'
                  804='(804) Hashish' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE dremgmed  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE emdrg1a   108='(108) Nembutal' 209='(209) Xanax' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  430='(430) Aspirin, Ecotrin, Empirin'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  503='(503) Other aerosol sprays' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 606='(606) sic'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  815='(815) Coffee' 858='(858) Antibiotic'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg2a   339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg3a   813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg4a   994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg5a   994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drtrmt    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtdrg1a  312='(312) Ionamin' 322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  415='(415) Codeine'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE tmtdrg2a  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  408='(408) Dilaudid' 417='(417) Morphine'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE tmtdrg3a  702='(702) Heroin' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE tmtdrg4a  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE tmtdrg5a  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drdrvun   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE drvdrg1a  110='(110) Tuinal' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)' 348='(348) Crystal'
                  601='(601) see also 618' 604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drvdrg2a  322='(322) Methamphetamine (speed or ice or crank)'
                  408='(408) Dilaudid' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 804='(804) Hashish' 805='(805) Cocaine, coke'
                  806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drvdrg3a  601='(601) see also 618' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drvdrg4a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 804='(804) Hashish'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drvdrg5a  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE tmtread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE empdrug   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cighelp   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER SMOKED CIGARETTES Logically Assigned'
                  91='(91) NEVER SMOKED CIGARETTES' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drnkhelp  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmthelp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtemrg  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmthosp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtdoc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmttrmt  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtmhc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtshg   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtsop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  9='(9) Within myself (self-treatment)'
                  10='(10) Church or religious influence' 12='(12) Friends'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  16='(16) Home, family' 22='(22) Hospital'
                  24='(24) Drug treatment or rehab. center'
                  25='(25) Mental health center' 26='(26) Self-help group'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtrec   1='(1) Within the past month'
                  2='(2) More than one month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Received treatment in past year LOGICALLY IMPUTED'
                  9='(9) Received treatment in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nrtxlife  0='(0) NONE' 985='(985) BAD DATA Logically assigned'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE notrmt    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE txemrg    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txhosp    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txdoc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txtrmt    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txmhc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txshg     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txsop     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txsp      4='(4) AA or NA or CA' 5='(5) Residential placement'
                  9='(9) Within myself (self-treatment)'
                  10='(10) Church or religious influence' 12='(12) Friends'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  16='(16) Home, family'
                  17='(17) Employer''s hotline, job corps, on the job'
                  22='(22) Hospital' 24='(24) Drug treatment or rehab. center'
                  25='(25) Mental health center'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtlife  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmtresp  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtfear  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtcost  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtevnt  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmtpr    1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmthlth  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmtjob   1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmtjail  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtserv  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmtbqd   1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtdna   1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtsor   1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important' 4='(4) Response circled only'
                  5='(5) Reason specified but no ranking'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtrsp   1='(1) Wanted to change lifestyle'
                  2='(2) Had family responsibilities'
                  5='(5) Occurrence of a signif. personal or special event'
                  6='(6) Pressure from family (or close friends)'
                  7='(7) Had concerns about health' 8='(8) Had concerns about job'
                  9='(9) Sent to jail' 14='(14) Depression'
                  15='(15) Fear of dying/suicide(fear of, or attempted)'
                  16='(16) Church or other religious influence'
                  17='(17) Forced/compelled (but by whom is unknown)'
                  18='(18) Wanted to quit drugs'
                  19='(19) Reason connected to the military' 20='(20) Overdose'
                  21='(21) Loss of control/dependency'
                  22='(22) Felt bad about self/wanted to do or be better'
                  23='(23) Reason connected to driver''s license'
                  25='(25) Committing violence'
                  26='(26) Pressure from counselor/soc. srvcs/etc.'
                  27='(27) Psychological disorders'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtdrga  108='(108) Nembutal' 116='(116) Methaqualone, Quaalude, Sopor'
                  118='(118) Pentobarbital, pentothal, sodium pentothal'
                  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 201='(201) Valium'
                  202='(202) Librium' 204='(204) Menrium' 228='(228) see also 239' 241='(241) Prozac'
                  247='(247) Adapin, Doxepin, Sinequan' 319='(319) Cylert'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth' 401='(401) Darvon'
                  406='(406) Oxycodone, Percodan, Roxicet' 408='(408) Dilaudid'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  417='(417) Morphine' 418='(418) Methadone'
                  430='(430) Aspirin, Ecotrin, Empirin'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  501='(501) Gasoline or lighter fluids' 503='(503) Other aerosol sprays'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  824='(824) Steroids'
                  840='(840) Cough medicine (contents not specified)' 875='(875) Buds'
                  900='(900) Not a drug' 989='(989) LEGITIMATE SKIP Logically assigned'
                  992='(992) Illegible' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE trmtdrgb  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or crank)' 415='(415) Codeine'
                  423='(423) Percocet' 427='(427) Darvocet' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic' 804='(804) Hashish'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  900='(900) Not a drug' 989='(989) LEGITIMATE SKIP Logically assigned'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE trmtdrgc  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  246='(246) Clonopin, Klonopin' 355='(355) Crystal meth'
                  601='(601) see also 618' 805='(805) Cocaine, coke, coca'
                  806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE trmtdrgd  605='(605) PCP (angel dust, phencyclidine)'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE trmtdrge  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE trmtoutc  1='(1) Still in treatment' 2='(2) Successfully completed treatment'
                  3='(3) Had a problem with program'
                  4='(4) Couldn''t afford to continue treatment'
                  5='(5) Family needed me' 6='(6) Began using drug(s) again'
                  7='(7) Other outcome, not specified' 8='(8) Didn''t need treatment'
                  10='(10) Successful because of own efforts, not trmt.'
                  11='(11) Use to a lesser extent'
                  14='(14) Successful because of religious reasons'
                  15='(15) Discontinued treatment, success unknown'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtphi    1='(1) Response circled' 2='(2) Response not circled'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpsave  1='(1) Response circled' 2='(2) Response not circled'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpfmly  1='(1) Response circled' 2='(2) Response not circled'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpempr  1='(1) Response circled' 2='(2) Response not circled' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpmedi  1='(1) Response circled' 2='(2) Response not circled'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpfree  1='(1) Response circled' 2='(2) Response not circled' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpoth   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpasp   1='(1) Health Insurance' 2='(2) Own savings or earnings'
                  3='(3) Family member' 4='(4) Employer or union'
                  5='(5) Medicare or Medicaid' 6='(6) Free'
                  9='(9) State/city public assistance/welfare/relief' 10='(10) Court'
                  12='(12) School' 13='(13) Hospital'
                  14='(14) Veterans Administration/military services'
                  15='(15) Treatment program' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE rskpkcig  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rsktrymj  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrypcp  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkpcpreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktryher  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkherreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrycoc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcococc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcocreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcrkocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkansocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkansreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rk2drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rk5drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskbinge  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskdifmj  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdiflsd  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifpcp  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifcoc  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifher  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rsksell   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkneidrn  1='(1) Often' 2='(2) Occasionally' 3='(3) Rarely' 4='(4) Never'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkneisel  1='(1) Often' 2='(2) Occasionally' 3='(3) Rarely' 4='(4) Never'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE highbp    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE bpmed     1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE walkpain  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE timepain  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE upshor    1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE asthma    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trpsych   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE heart     1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE flu       1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE allerg    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hospyr    1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE soreyr    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE runnyyr   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE coughyr   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phlegmyr  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE healthyr  1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE flteat    1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fltmind   1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fltdeprs  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE flteffrt  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fltsleep  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fltsad    1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fltgoing  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE marital   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Has never married' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE nomarr    85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE workstat  1='(1) Working full-time, 35 hours or more a week'
                  2='(2) Working part-time, less than 35 hours a week'
                  3='(3) Have job but out: illness/leave/furlough/strike'
                  4='(4) Unemployed or laid off and looking for work'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work'
                  21='(21) Working full time, 35 hours or more a week'
                  22='(22) Working part time, less than 35 hours a week'
                  23='(23) Have a job but out: illness/leave/furlough/strike'
                  24='(24) Unemployed or laid off and looking for work'
                  25='(25) Unemployed and not looking for work'
                  26='(26) Full-time homemaker' 27='(27) In school only' 28='(28) Retired'
                  29='(29) Disabled, not able to work' 30='(30) Other, in labor force'
                  31='(31) Other, not in the labor force'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE paymo     89='(89) LEGITIMATE SKIP Logically assigned'
                  91='(91) NEVER WORKED FOR PAY' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE payyr     985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned'
                  991='(991) NEVER WORKED FOR PAY' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE no5job    94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE workdays  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE workblah  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cwe       1='(1) Respondent' 2='(2) Someone else (see CWESCs)'
                  3='(3) Income contributed equally by R and (see CWESCs)'
                  4='(4) No one'
                  6='(6) Some one else (see CWESCs) LOGICALLY ASSIGNED'
                  7='(7) Inc. from R & other(s) equally (see CWESCs) LOG AS'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cwesc1ff  9='(9) Head of Household' 10='(10) Spouse' 20='(20) Parent/Guardian'
                  50='(50) Grandparent/Great+ Grandparent' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin'
                  85='(85) Landlord/Home Owner'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  109='(109) Male Head of Household' 110='(110) Husband' 111='(111) Ex-Husband'
                  120='(120) Father/Male Guardian' 121='(121) Step/Adopted/Foster Father'
                  122='(122) Father In-Law/Step Father In-Law' 130='(130) Son'
                  132='(132) Son In-Law' 133='(133) Grandson' 140='(140) Brother/Half Brother'
                  141='(141) Step/Adopted/Foster Brother' 142='(142) Brother In-Law'
                  150='(150) Grandfather/Great+ Grandfather'
                  160='(160) Male Live-In Partner'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion' 170='(170) Uncle'
                  171='(171) Male Cousin' 181='(181) Other Male God Relative'
                  190='(190) Other Male Relative' 191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother'
                  222='(222) Mother In-Law/Step Mother In-Law' 230='(230) Daughter'
                  231='(231) Step/Adopted/Foster Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 241='(241) Step/Adopted/Foster Sister'
                  242='(242) Sister In-Law' 250='(250) Grandmother/Great+ Grandmother'
                  260='(260) Female Live-In Partner'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 271='(271) Female Cousin' 272='(272) Niece'
                  285='(285) Female Landlord/Home Owner'
                  291='(291) Other Female Non-Relative'
                  292='(292) Other Female, Relation Unspecified' 315='(315) In-Laws'
                  320='(320) Parents/Guardians'
                  350='(350) Grandparents/Great+ Grandparents'
                  361='(361) Friends/Roommates/Companions' 371='(371) Cousins'
                  390='(390) Other Relatives, Gender not specified'
                  392='(392) Others, Relation and Gender Unspecified' 430='(430) Sons'
                  442='(442) Brothers In-Law' 540='(540) Sisters/Half Sisters'
                  985='(985) BAD DATA Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cwesc2ff  20='(20) Parent/Guardian' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion'
                  92='(92) Other, Relation and Gender Unspecified' 110='(110) Husband'
                  120='(120) Father/Male Guardian' 121='(121) Step/Adopted/Foster Father'
                  140='(140) Brother/Half Brother' 142='(142) Brother In-Law'
                  150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion' 170='(170) Uncle'
                  191='(191) Other Male Non-Relative' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother' 230='(230) Daughter'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother' 270='(270) Aunt'
                  291='(291) Other Female Non-Relative' 315='(315) In-Laws'
                  392='(392) Others, Relation and Gender Unspecified'
                  540='(540) Sisters/Half Sisters' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE fullpart  1='(1) Full-time' 2='(2) Part-time'
                  3='(3) Chief source of income does not work'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE educ      0='(0) No schooling' 1='(1) First Grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh Grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year college'
                  14='(14) 2 years college' 15='(15) 3 years college'
                  16='(16) 4 years college' 17='(17) Graduate/professional school'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gradhs    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY IMPUTED (from DIPLOMA)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE diploma   1='(1) High school diploma' 2='(2) GED certificate'
                  3='(3) Neither of the above'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE enrolld   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE schplans  1='(1) Has plans to enroll in a school in future'
                  2='(2) Has completed all schooling'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE student   1='(1) A full-time student' 2='(2) A part-time student'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE schdays   89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skipped   89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE miles     99989='(99989) LEGITIMATE SKIP Logically assigned'
                  99991='(99991) HAS NEVER DRIVEN A MOTOR VEHICLE'
                  99994='(99994) DON''T KNOW' 99997='(99997) REFUSED'
                  99998='(99998) BLANK (NO ANSWER)' 99999='(99999) LEGITIMATE SKIP' ;
  VALUE accid     1='(1) Yes' 2='(2) No' 3='(3) Did not drive in past 12 months'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE totpeop   97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mother    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE father    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stepmom   0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stepdad   0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE spouse    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inlaw     0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ownchild  0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stepchld  0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE brosis    0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othrel    0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE friends   0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othernon  0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE movdaway  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dorm      94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE milbase   94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE hosp      94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE othgph    85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE othgphsp  1='(1) Own dwelling' 2='(2) Married'
                  3='(3) (Moved to)another dwelling,ownership not specified'
                  4='(4) (Moved to) apartment, ownership not specified'
                  7='(7) Foster home'
                  8='(8) Nursing home/home for handicapped/retirement home'
                  9='(9) Died' 10='(10) Lives out of state/city/county'
                  11='(11) Staying/living with a friend'
                  12='(12) Moved away for job or job training(incl. military)'
                  14='(14) Overseas/out of country'
                  15='(15) Lives with mother/father/relatives'
                  17='(17) With other children in school group housing'
                  18='(18) Group housing in college' 20='(20) Hotel'
                  21='(21) Group home/halfway house/shelter/tx. or rehab.'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE service   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE milstat   2='(2) In a Reserves component'
                  3='(3) Separated/retired from Reserves or active duty'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE telno     94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE moves     94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nofamres  0='(0) Some relative(s) do(es) or may reside in household'
                  1='(1) No relative resides in household' ;
  VALUE proxable  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE proxyrel  1='(1) Respondent''s spouse/live-in partner'
                  2='(2) Respondent''s father' 3='(3) Respondent''s mother'
                  4='(4) Respondent''s brother' 5='(5) Respondent''s sister'
                  6='(6) Other family member, relation not specified'
                  20='(20) Parent/Guardian' 50='(50) Grandparent/Great+ Grandparent'
                  60='(60) Live-In Partner' 61='(61) Friend/Roommate/Companion'
                  71='(71) Cousin' 91='(91) Other Non-Relative, Gender not specified'
                  110='(110) Husband' 120='(120) Father/Male Guardian'
                  121='(121) Step/Adopted/Foster Father' 130='(130) Son' 132='(132) Son In-Law'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  170='(170) Uncle' 210='(210) Wife' 220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother' 230='(230) Daughter'
                  231='(231) Step/Adopted/Foster Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 291='(291) Other Female Non-Relative'
                  321='(321) Step/Adopted/Foster Parents'
                  350='(350) Grandparents/Great+ Grandparents'
                  989='(989) LEGITIMATE SKIP Logically assigned'
                  996='(996) MULTIPLE RESPONSE' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE proxhome  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE proxjoin  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE medicare  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE medicaid  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE champus   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE prvhltin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ownhltin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE grphltin  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltinalc  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltindrg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltinmnt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE whoanshi  1='(1) Sample member'
                  2='(2) Proxy, relationship to sample member not specified'
                  10='(10) Spouse' 20='(20) Parent/Guardian'
                  50='(50) Grandparent/Great+ Grandparent' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified' 110='(110) Husband'
                  120='(120) Father/Male Guardian' 121='(121) Step/Adopted/Foster Father'
                  130='(130) Son' 132='(132) Son In-Law' 140='(140) Brother/Half Brother'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  160='(160) Male Live-In Partner' 170='(170) Uncle'
                  191='(191) Other Male Non-Relative' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother' 230='(230) Daughter'
                  231='(231) Step/Adopted/Foster Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 291='(291) Other Female Non-Relative'
                  320='(320) Parents/Guardians'
                  350='(350) Grandparents/Great+ Grandparents' 994='(994) DON''T KNOW'
                  996='(996) MULTIPLE RESPONSE' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE job       1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hours     985='(985) BAD DATA Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE work      1='(1) Worked only for an employer' 2='(2) Was self-employed only'
                  3='(3) Self-employed and working for an employer'
                  4='(4) Did not work during the month'
                  5='(5) Did work during the month LOGICALLY IMPUTED'
                  6='(6) Did not work during the month LOGICALLY IMPUTED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wag1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE awag1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE weeks     94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE soc1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE asoc1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE ssi1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE assi1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE pub1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE afdc1fff  1='(1) Income from AFDC/ADC' 2='(2) Income from other'
                  3='(3) Income from both' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wel1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE awel1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE int1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE aint1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE chd1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE achd1fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE oth1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE aoth1fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE famlyres  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wag2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE awag2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE soc2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE asoc2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE ssi2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE assi2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE pub2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE afdc2fff  1='(1) Income from AFDC/ADC' 2='(2) Income from other'
                  3='(3) Income from both'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wel2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE awel2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE int2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE aint2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE chd2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE achd2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE oth2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE aoth2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE whoansin  1='(1) Sample member'
                  2='(2) Proxy, relationship to sample member not specified'
                  10='(10) Spouse' 20='(20) Parent/Guardian' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin'
                  91='(91) Other Non-Relative, Gender not specified' 110='(110) Husband'
                  120='(120) Father/Male Guardian' 121='(121) Step/Adopted/Foster Father'
                  130='(130) Son' 132='(132) Son In-Law' 133='(133) Grandson'
                  140='(140) Brother/Half Brother' 142='(142) Brother In-Law'
                  150='(150) Grandfather/Great+ Grandfather'
                  160='(160) Male Live-In Partner'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion' 170='(170) Uncle'
                  210='(210) Wife' 220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother'
                  222='(222) Mother In-Law/Step Mother In-Law' 230='(230) Daughter'
                  231='(231) Step/Adopted/Foster Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 291='(291) Other Female Non-Relative'
                  320='(320) Parents/Guardians' 321='(321) Step/Adopted/Foster Parents'
                  350='(350) Grandparents/Great+ Grandparents'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  996='(996) MULTIPLE RESPONSE' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE fstamp    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE peopfd    85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE food      1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE afood     999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE bap       1='(1) AM' 2='(2) PM' 98='(98) BLANK (NO ANSWER)' ;
  VALUE eap       1='(1) AM' 2='(2) PM' 96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE langver   1='(1) English' 2='(2) Spanish' 98='(98) BLANK (NO ANSWER)' ;
  VALUE undint    1='(1) No difficulty-no language or reading problem'
                  2='(2) Just a little difficulty-almost no lang/readg prob'
                  3='(3) Fair amount of difficulty-some lang/reading prob'
                  4='(4) A lot of difficulty-considerable lang/reading prob'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very cooperative' 2='(2) Fairly cooperative'
                  3='(3) Not very cooperative' 4='(4) Openly hostile'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private-no one present/able to overhear'
                  3='(3) Minor distractions'
                  5='(5) Person(s) in room or listening 1/3 of the time'
                  7='(7) Serious interruptions more than half the time'
                  9='(9) Constant presence of other person(s)'
                  85='(85) BAD DATA Logically assigned' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ppres     1='(1) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE spres     2='(2) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE parpres   3='(3) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE oarpres   4='(4) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE oapres    5='(5) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE cpres     6='(6) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE opresnsp  7='(7) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE opresspa  9='(9) Head of Household' 10='(10) Spouse' 20='(20) Parent/Guardian'
                  37='(37) Child, Relation Unspecified' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin'
                  83='(83) Nurse/Health Care Aide/Home Care Worker'
                  84='(84) Neighbor/Co-Worker/Visitor' 85='(85) Landlord/Home Owner'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified' 110='(110) Husband'
                  120='(120) Father/Male Guardian' 121='(121) Step/Adopted/Foster Father'
                  130='(130) Son' 131='(131) Step/Adopted/Foster Son'
                  140='(140) Brother/Half Brother'
                  141='(141) Step/Adopted/Foster Brother'
                  150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion' 170='(170) Uncle'
                  191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother'
                  222='(222) Mother In-Law/Step Mother In-Law' 230='(230) Daughter'
                  231='(231) Step/Adopted/Foster Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 280='(280) Female God Child/God Daughter'
                  292='(292) Other Female, Relation Unspecified'
                  337='(337) Children, Relation Unspecified' 340='(340) Siblings'
                  350='(350) Grandparents/Great+ Grandparents'
                  361='(361) Friends/Roommates/Companions' 371='(371) Cousins'
                  384='(384) Neighbors/Co-Workers/Visitors'
                  390='(390) Other Relatives, Gender not specified'
                  391='(391) Other Non-Relatives, Gender not specified'
                  392='(392) Others, Relation and Gender Unspecified' 430='(430) Sons'
                  440='(440) Brothers/Half Brothers'
                  461='(461) Male Fiances/Boyfriends/Roommates/Companions'
                  492='(492) Other Males, Relation Unspecified'
                  540='(540) Sisters/Half Sisters'
                  561='(561) Female Fiancees/Girlfriends/Roommates/Companions'
                  900='(900) Not A Person' 985='(985) BAD DATA Logically assigned'
                  994='(994) DON''T KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE opresspb  9='(9) Head of Household' 33='(33) Grandchild'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin'
                  84='(84) Neighbor/Co-Worker/Visitor' 170='(170) Uncle' 230='(230) Daughter'
                  240='(240) Sister/Half Sister'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 272='(272) Niece'
                  292='(292) Other Female, Relation Unspecified'
                  330='(330) Own Children/Own Half Children'
                  337='(337) Children, Relation Unspecified'
                  384='(384) Neighbors/Co-Workers/Visitors'
                  390='(390) Other Relatives, Gender not specified'
                  392='(392) Others, Relation and Gender Unspecified'
                  900='(900) Not A Person' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE whomarkd  1='(1) Respondent marked ALL the Answer Sheet responses'
                  2='(2) Interviewer marked All the Answer Sheet responses'
                  3='(3) Combination of respondent and F.I.BLANK (NO ANSWER'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE quarter   1='(1) Quarter' 2='(2) Quarter' 3='(3) Quarter' 4='(4) Quarter' ;
  VALUE famskip   0='(0) Respondent has other family members in household'
                  1='(1) Respondent didn''t have other family in household'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pden      1='(1) Segment in a MSA with 1 million or more persons'
                  2='(2) Segment in a MSA with fewer than 1 million persons'
                  3='(3) Segment not in MSA' ;
  VALUE gqtype    1='(1) Halfway House' 2='(2) Boarding House' 3='(3) College Dorm'
                  4='(4) Shelter' 5='(5) Other' 9='(9) Not Group Quarters' ;
  VALUE pden2fff  1='(1) Segment in MSA with 1 million or more persons'
                  2='(2) Segm. in a MSA from 250000 to 999999 persons'
                  3='(3) Segment in a MSA with fewer than 250000 persons'
                  4='(4) Segment not in a MSA and not in a rural area'
                  5='(5) Segment not in a MSA and in a rural area' ;
  VALUE dc        1='(1) Low SES - DC' 2='(2) Not Low SES - DC' 9='(9) NOT IN DC' ;
  VALUE chicago   1='(1) Low SES - CHICAGO' 2='(2) Not Low SES - CHICAGO'
                  9='(9) NOT IN CHICAGO' ;
  VALUE denver    1='(1) Low SES - DENVER' 2='(2) Not Low SES - DENVER'
                  9='(9) NOT IN DENVER' ;
  VALUE la        1='(1) Low SES - LA' 2='(2) Not Low SES - LA' 9='(9) NOT IN LA' ;
  VALUE miami     1='(1) Low SES - MIAMI' 2='(2) Not Low SES - MIAMI'
                  9='(9) NOT IN MIAMI' ;
  VALUE newyork   1='(1) Low SES - NEW YORK' 2='(2) Not Low SES - NEW YORK'
                  9='(9) NOT IN NEW YORK' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE division  1='(1) New England' 2='(2) Middle Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central' 8='(8) Mountain'
                  9='(9) Pacific' ;
  VALUE cencty    1='(1) Yes' 2='(2) No' 3='(3) Not in any of the 6 metropolitan areas' ;
  VALUE urbare    1='(1) Yes' 2='(2) No' 3='(3) Not in any of the 6 metropolitan areas'
                  9='(9) Data suppressed for reasons of confidentiality' ;
  VALUE metro     1='(1) Chicago Metropolitan area' 2='(2) Denver Metropolitan area'
                  3='(3) Los Angeles Metropolitan area'
                  4='(4) Miami Metropolitan area' 5='(5) New York Metropolitan area'
                  6='(6) Washington, D.C. Metropolitan area'
                  9='(9) Not in any of the 6 Metropolitan areas' ;
  VALUE centralc  1='(1) Sample segm. within a central city of metro area'
                  2='(2) Sam. segm. not within a central city of metro area'
                  3='(3) Sample segment not within a MSA' ;
  VALUE iiage     1='(1) Age from birthdate' 2='(2) Age from cover of questionnaire'
                  3='(3) Age from roster'
                  4='(4) Age statistically imputed using age gr from roster' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex from questionnaire'
                  2='(2) Sex from relationship on roster' 3='(3) Sex from roster'
                  4='(4) Sex statistically imputed' ;
  VALUE irrace    1='(1) American indian or Alaskan native'
                  2='(2) Asian or Pacific islander' 3='(3) Black' 4='(4) White' ;
  VALUE iirace    1='(1) Race from questionnaire'
                  2='(2) Race from interview observation' 3='(3) Race from roster'
                  4='(4) Race statis imputed using race - Other on roster'
                  5='(5) Race statistically imputed, no infor. from roster' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Nonhispanic' ;
  VALUE iihoind   1='(1) Hispanicity derived from questionnaire'
                  2='(2) Hispanicity derived from roster' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iihogrp   1='(1) Hispanic-Origin Group taken from questionnaire'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispanic' ;
  VALUE irhogrpf  1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  5='(5) Central American' 6='(6) South American' 7='(7) Caribbean'
                  99='(99) LEGITIMATE SKIP Respondent is not hispanic' ;
  VALUE iihogrpf  1='(1) Hispanic-Origin Group taken from questionnaire'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispanic' ;
  VALUE irmarit   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or Separated'
                  4='(4) Never Married' 99='(99) LEGITIMATE SKIP' ;
  VALUE iimarit   1='(1) Questionnaire data'
                  2='(2) Logically imputed data from questionnaire'
                  4='(4) Logically imputed data from roster'
                  5='(5) Statistically imputed data'
                  6='(6) Logically imputed from relationship on roster'
                  9='(9) LEGITIMATE SKIP (less than or = 14 years old)' ;
  VALUE ireduc    0='(0) No schooling' 1='(1) First grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year of college'
                  14='(14) Two years of college' 15='(15) Three years of college'
                  16='(16) Four years of college'
                  17='(17) Graduate/professional school' ;
  VALUE iieduc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irhsgrad  1='(1) Yes, graduated from high school'
                  2='(2) No, did not graduate from high school' ;
  VALUE iihsgrad  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irworkst  1='(1) Working full-time, 35 hours or more a week'
                  2='(2) Working part-time, less than 35 hours a week'
                  3='(3) Have job but out: illness/leave/furlough/strike'
                  4='(4) Unemployed or laid off and looking for work'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work' 10='(10) Other, in labor force'
                  11='(11) Other, not in labor force' ;
  VALUE iiworkst  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpinsur  1='(1) Yes, respondent does have private health insurance'
                  2='(2) No, respondent does not have private health insur.' ;
  VALUE iipinsur  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinsur   1='(1) Yes, respondent does have health insurance'
                  2='(2) No, respondent does not have health insurance' ;
  VALUE iiinsur   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irwag1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiwag1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irawag1f  0='(0) Zero income received' ;
  VALUE iiawag1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irsoc1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisoc1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irasoc1f  0='(0) Zero income received' ;
  VALUE iiasoc1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irssi1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iissi1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irassi1f  0='(0) Zero income received' ;
  VALUE iiassi1f  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE irwel1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiwel1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irawel1f  0='(0) Zero income received' ;
  VALUE iiawel1f  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE irint1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiint1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iraint1f  0='(0) Zero income received' ;
  VALUE iiaint1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irchd1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iichd1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irachd1f  0='(0) Zero income received' ;
  VALUE iiachd1f  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE iroth1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iioth1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iraoth1f  0='(0) Zero income received' ;
  VALUE iiaoth1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irwag2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiwag2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irawag2f  0='(0) Zero income received' ;
  VALUE iiawag2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irsoc2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisoc2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irasoc2f  0='(0) Zero income received' ;
  VALUE iiasoc2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irssi2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iissi2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irassi2f  0='(0) Zero income received' ;
  VALUE iiassi2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irwel2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiwel2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irawel2f  0='(0) Zero income received' ;
  VALUE iiawel2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irint2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiint2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iraint2f  0='(0) Zero income received' ;
  VALUE iiaint2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irchd2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iichd2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irachd2f  0='(0) Zero income received' ;
  VALUE iiachd2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iroth2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iioth2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iraoth2f  0='(0) Zero income received' ;
  VALUE iiaoth2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irfood    1='(1) Yes' 2='(2) No' ;
  VALUE iifood    1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irafood   0='(0) Zero income received' ;
  VALUE iiafood   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iralcrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjrc    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircocrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsedrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irtrnrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used tranquilizers' ;
  VALUE iitrnrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstmrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used stimulants' ;
  VALUE iistmrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iranlrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used analgesics' ;
  VALUE iianlrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircigrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irotbrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used smokeless tobacco' ;
  VALUE iiotbrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irinhrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used inhalants' ;
  VALUE iiinhrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircrkrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used crack' ;
  VALUE iicrkrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used hallucinogens' ;
  VALUE iihalrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpcprc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iricerc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 9='(9) Never used ice' ;
  VALUE iiicerc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstrrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used anabolic steroids' ;
  VALUE iistrrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iralcfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iialcfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjfq    1='(1) Used several times per day in past year'
                  2='(2) Used daily in past year'
                  3='(3) Used almost daily in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used several times per month in past year'
                  6='(6) Used 1-2 times per month in past year'
                  7='(7) Used every other month in past year'
                  8='(8) Used 3-5 times in past year'
                  9='(9) Used 1-2 times in past year'
                  10='(10) Never used or did not use in the past year' ;
  VALUE iimjfq    1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircocfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times per month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iicocfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsedfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iisedfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irtrnfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iitrnfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irstmfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iistmfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iranlfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iianlfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irotbfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iiotbfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinhfq   1='(1) Use daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iiinhfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iihalfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE catage    1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35+ years' ;
  VALUE catag2ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26+ years' ;
  VALUE catag3ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35-49 years' 5='(5) 50+ years' ;
  VALUE race      1='(1) White (IRRACE = 4 and IRHOIND = 2)'
                  2='(2) Black (IRRACE = 3 and IRHOIND = 2)'
                  3='(3) Hispanic (IRHOIND = 1)'
                  4='(4) Other (IRRACE = 1-2 and IRHOIND = 2)' ;
  VALUE hisprace  1='(1) Hispanic' 2='(2) Nonhispanic Black' 3='(3) Nonhispanic Nonblack' ;
  VALUE educcatf  1='(1) Less than high school (IREDUC=0-11 and IRAGE=>18)'
                  2='(2) High school graduate (IREDUC = 12 and IRAGE=>18)'
                  3='(3) Some college (IREDUC = 13-15 and IRAGE => 18)'
                  4='(4) College graduate (IREDUC = 16-17 and IRAGE => 18)'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE empstatf  1='(1) Full=time (IRWORKST =1,3 and IRAGE => 18)'
                  2='(2) Part-time (IRWORKST = 2 and IRAGE => 18)'
                  3='(3) Unemployed (IRWORKST = 4,5,10 and IRAGE => 18)'
                  4='(4) Other (IRWORKST = 6-9,11 and IRAGE => 18)'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE iiindinc  1='(1) All personal income sources from questionnaire'
                  3='(3) At least 1 of sources were stat or logic imputed' ;
  VALUE indcat    1='(1) $0' 2='(2) $1-$4,999' 3='(3) $5,000-$6,999' 4='(4) $7,000-$8,999'
                  5='(5) $9,000-$11,999' 6='(6) $12,000-$14,999' 7='(7) $15,000-$19,999'
                  8='(8) $20,000-$24,999' 9='(9) $25,000-$29,999'
                  10='(10) $30,000-$39,999' 11='(11) $40,000-$49,999'
                  12='(12) $50,000-$74,999' 13='(13) $75,000+' ;
  VALUE perinc    1='(1) $0-$8,999' 2='(2) $9,000-$19,999' 3='(3) $20,000-$39,999'
                  4='(4) $40,000-$74,999' 5='(5) $75,000+' ;
  VALUE perinc2f  1='(1) $0-9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' ;
  VALUE perinc3f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' 8='(8) 12-17 Years Old' ;
  VALUE totinc    0='(0) No family income' ;
  VALUE iitotinc  1='(1) All income sources from questionnaire'
                  3='(3) At least 1 of sources were stat or logic imputed' ;
  VALUE totcat    1='(1) $0' 2='(2) $1-$4,999' 3='(3) $5,000-$6,999' 4='(4) $7,000-$8,999'
                  5='(5) $9,000-$11,999' 6='(6) $12,000-$14,999' 7='(7) $15,000-$19,999'
                  8='(8) $20,000-$24,999' 9='(9) $25,000-$29,999'
                  10='(10) $30,000-$39,999' 11='(11) $40,000-$49,999'
                  12='(12) $50,000-$74,999' 13='(13) $75,000+' ;
  VALUE faminc    1='(1) $0-$8,999' 2='(2) $9,000-$19,999' 3='(3) $20,000-$39,999'
                  4='(4) $40,000-$74,000' 5='(5) $75,000+' ;
  VALUE faminc2f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' ;
  VALUE faminc3f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' 8='(8) 12-17 Years old' ;
  VALUE welfare   1='(1) Yes, respondent or another fam member on welfare'
                  2='(2) No, there was no one in the family on welfare' ;
  VALUE halflag   0='(0) Never used (IRHALRC = 9)' 1='(1) Ever used (IRHALRC = 1-5)' ;
  VALUE halyr     0='(0) Did not use in the past year (IRHALRC = 4-5,9)'
                  1='(1) Used within the past year (IRHALRC = 1-3)' ;
  VALUE halmon    0='(0) Did not use in the past month (IRHALRC = 2-5,9)'
                  1='(1) Used within the past month (IRHALRC = 1)' ;
  VALUE pcpflag   0='(0) Never used (IRPCPRC = 9)' 1='(1) Ever used (IRPCPRC = 1-5)' ;
  VALUE pcpyr     0='(0) Did not use in the past year (IRPCPRC = 4-5,9)'
                  1='(1) Used within the past year (IRPCPRC = 1-3)' ;
  VALUE pcpmon    0='(0) Did not use in the past month (IRPCPRC = 2-5,9)'
                  1='(1) Used within the past month (IRPCPRC = 1)' ;
  VALUE stmflag   0='(0) Never used (IRSTMRC = 9)' 1='(1) Ever used (IRSTMRC = 1-5)' ;
  VALUE stmyr     0='(0) Did not use in the past year (IRSTMRC = 4-5,9)'
                  1='(1) Used within the past year (IRSTMRC = 1-3)' ;
  VALUE stmmon    0='(0) Did not use in the past month (IRSTMRC = 2-5,9)'
                  1='(1) Used within the past month (IRSTMRC = 1)' ;
  VALUE sedflag   0='(0) Never used (IRSEDRC = 9)' 1='(1) Ever used (IRSEDRC = 1-5)' ;
  VALUE sedyr     0='(0) Did not use in the past year (IRSEDRC = 4-5,9)'
                  1='(1) Used within the past year (IRSEDRC = 1-3)' ;
  VALUE sedmon    0='(0) Did not use in the past month (IRSEDRC = 2-5,9)'
                  1='(1) Used within the past month (IRSEDRC = 1)' ;
  VALUE trqflag   0='(0) Never used (IRTRNRC = 9)' 1='(1) Ever used (IRTRNRC = 1-5)' ;
  VALUE trqyr     0='(0) Did not use in the past year (IRTRNRC = 4-5,9)'
                  1='(1) Used within the past year (IRTRNRC = 1-3)' ;
  VALUE trqmon    0='(0) Did not use in the past month (IRTRNRC = 2-5,9)'
                  1='(1) Used within the past month (IRTRNRC = 1)' ;
  VALUE anlflag   0='(0) Never used (IRANLRC = 9)' 1='(1) Ever used (IRANLRC = 1-5)' ;
  VALUE anlyr     0='(0) Did not use in the past year (IRANLRC = 4-5,9)'
                  1='(1) Used within the past year (IRANLRC = 1-3)' ;
  VALUE anlmon    0='(0) Did not use in the past month (IRANLRC = 2-5,9)'
                  1='(1) Used within the past month (IRANLRC = 1)' ;
  VALUE alcflag   0='(0) Never used (IRALCRC = 9)' 1='(1) Ever used (IRALCRC = 1-5)' ;
  VALUE alcyr     0='(0) Did not use in the past year (IRALCRC = 4-5,9)'
                  1='(1) Used within the past year (IRALCRC = 1-3)' ;
  VALUE alcmon    0='(0) Did not use in the past month (IRALCRC = 2-5,9)'
                  1='(1) Used within the past month (IRALCRC = 1)' ;
  VALUE cigflag   0='(0) Never used (IRCIGRC = 9)' 1='(1) Ever used (IRCIGRC = 1-5)' ;
  VALUE cigyr     0='(0) Did not use in the past year (IRCIGRC = 4-5,9)'
                  1='(1) Used within the past year (IRCIGRC = 1-3)' ;
  VALUE cigmon    0='(0) Did not use in the past month (IRCIGRC = 2-5,9)'
                  1='(1) Used within the past month (IRCIGRC = 1)' ;
  VALUE smkflag   0='(0) Never used (IROTBRC = 9)' 1='(1) Ever used (IROTBRC = 1-5)' ;
  VALUE smkyr     0='(0) Did not use in the past year (IROTBRC = 4-5,9)'
                  1='(1) Used within the past year (IROTBRC = 1-3)' ;
  VALUE smkmon    0='(0) Did not use in the past month (IROTBRC = 2-5,9)'
                  1='(1) Used within the past month (IROTBRC = 1)' ;
  VALUE herflag   0='(0) Never used (IRHERRC = 9)' 1='(1) Ever used (IRHERRC = 1-5)' ;
  VALUE heryr     0='(0) Did not use in the past year (IRHERRC = 4-5,9)'
                  1='(1) Used within the past year (IRHERRC = 1-3)' ;
  VALUE hermon    0='(0) Did not use in the past month (IRHERRC = 2-5,9)'
                  1='(1) Used within the past month (IRHERRC = 1)' ;
  VALUE strflag   0='(0) Never used (IRSTRRC = 9)' 1='(1) Ever used (IRSTRRC = 1-5)' ;
  VALUE stryr     0='(0) Did not use in the past year (IRSTRRC = 4-5,9)'
                  1='(1) Used within the past year (IRSTRRC = 1-3)' ;
  VALUE strmon    0='(0) Did not use in the past month (IRSTRRC = 2-5,9)'
                  1='(1) Used within the past month (IRSTRRC = 1)' ;
  VALUE mrjflag   0='(0) Never used (IRMJRC = 9)' 1='(1) Ever used (IRMJRC = 1-6)' ;
  VALUE mrjyr     0='(0) Did not use in the past year (IRMJRC = 5-6,9)'
                  1='(1) Used within the past year (IRMJRC = 1-4)' ;
  VALUE mrjmon    0='(0) Did not use in the past month (IRMJRC = 3-6,9)'
                  1='(1) Used within the past month (IRMJRC = 1-2)' ;
  VALUE cocflag   0='(0) Never used (IRCOCRC = 9)' 1='(1) Ever used (IRCOCRC = 1-6)' ;
  VALUE cocyr     0='(0) Did not use in the past year (IRCOCRC = 5-6,9)'
                  1='(1) Used within the past year (IRCOCRC = 1-4)' ;
  VALUE cocmon    0='(0) Did not use in the past month (IRCOCRC = 3-6,9)'
                  1='(1) Used within the past month (IRCOCRC = 1-2)' ;
  VALUE crkflag   0='(0) Never used (IRCRKRC = 9)' 1='(1) Ever used (IRCRKRC = 1-6)' ;
  VALUE crkyr     0='(0) Did not use in the past year (IRCRKRC= 5-6,9)'
                  1='(1) Used within the past year (IRCRKRC = 1-4)' ;
  VALUE crkmon    0='(0) Did not use in the past month (IRCRKRC = 3-6,9)'
                  1='(1) Used within the past month (IRCRKRC = 1-2)' ;
  VALUE inhflag   0='(0) Never used (IRINHRC = 9)' 1='(1) Ever used (IRINHRC = 1-6)' ;
  VALUE inhyr     0='(0) Did not use in the past year (IRINHRC = 5-6,9)'
                  1='(1) Used within the past year (IRINHRC = 1-4)' ;
  VALUE inhmon    0='(0) Did not use in the past month (IRINHRC = 3-6,9)'
                  1='(1) Used within the past month (IRINHRC = 1-2)' ;
  VALUE iceflag   0='(0) Never used (IRICERC = 9)' 1='(1) Ever used (IRICERC = 1-6)' ;
  VALUE iceyr     0='(0) Did not use in the past year (IRICERC = 4-6,9)'
                  1='(1) Used within the past year (IRICERC = 1-3)' ;
  VALUE icemon    0='(0) Did not use in the past month (IRICERC = 2-6,9)'
                  1='(1) Used within the past month (IRICERC = 1)' ;
  VALUE needlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE VAR BLANK' ;
  VALUE ndl90rec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE VAR BLANK' ;
  VALUE nedflagf  0='(0) Never used (NDL90REC=91,98)'
                  1='(1) Ever used (NDL90REC=1-9)' ;
  VALUE nedyr3ff  0='(0) Never used (NDL90REC=4-6,9,91,98)'
                  1='(1) Ever used (NDL90REC=1-3,8)' ;
  VALUE halyrf    0='(0) Never used or did not use in past year (IRHALFQ=9)'
                  1='(1) Any use within the past year (IRHALFQ=1-8)' ;
  VALUE halmonf   0='(0) Did not use monthly/more past year (IRHALFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRHALFQ=1-5)' ;
  VALUE halwkf    0='(0) Did not use weekly or more past year (IRHALFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRHALFQ=1-3)' ;
  VALUE haloccf   0='(0) Used monthly/more or none in pst yr(IRHALFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRHALFQ=6-8)' ;
  VALUE haldlyf   0='(0) Did not use daily/almost daily pst yr(IRHALFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRHALFQ=1-2)' ;
  VALUE stmyrf    0='(0) Never used or did not use in past year (IRSTMFQ=9)'
                  1='(1) Any use within the past year (IRSTMFQ=1-8)' ;
  VALUE stmmonf   0='(0) Did not use monthly/more past year (IRSTMFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRSTMFQ=1-5)' ;
  VALUE stmwkf    0='(0) Did not use weekly or more past year (IRSTMFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRSTMFQ=1-3)' ;
  VALUE stmoccf   0='(0) Used monthly/more or none in pst yr(IRSTMFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRSTMFQ=6-8)' ;
  VALUE stmdlyf   0='(0) Did not use daily/almost daily pst yr(IRSTMFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRSTMFQ=1-2)' ;
  VALUE sedyrf    0='(0) Never used or did not use in past year (IRSEDFQ=9)'
                  1='(1) Any use within the past year (IRSEDFQ=1-8)' ;
  VALUE sedmonf   0='(0) Did not use monthly/more past year (IRSEDFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRSEDFQ=1-5)' ;
  VALUE sedwkf    0='(0) Did not use weekly or more past year (IRSEDFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRSEDFQ=1-3)' ;
  VALUE sedoccf   0='(0) Used monthly/more or none in pst yr(IRSEDFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRSEDFQ=6-8)' ;
  VALUE seddlyf   0='(0) Did not use daily/almost daily pst yr(IRSEDFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRSEDFQ=1-2)' ;
  VALUE trqyrf    0='(0) Never used or did not use in past year (IRTRNFQ=9)'
                  1='(1) Any use within the past year (IRTRNFQ=1-8)' ;
  VALUE trqmonf   0='(0) Did not use monthly/more past year (IRTRNFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRTRNFQ=1-5)' ;
  VALUE trqwkf    0='(0) Did not use weekly or more past year (IRTRNFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRTRNFQ=1-3)' ;
  VALUE trqoccf   0='(0) Used monthly/more or none in pst yr(IRTRNFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRTRNFQ=6-8)' ;
  VALUE trqdlyf   0='(0) Did not use daily/almost daily pst yr(IRTRNFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRTRNFQ=1-2)' ;
  VALUE anlyrf    0='(0) Never used or did not use in past year (IRANLFQ=9)'
                  1='(1) Any use within the past year (IRANLFQ=1-8)' ;
  VALUE anlmonf   0='(0) Did not use monthly/more past year (IRANLFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRANLFQ=1-5)' ;
  VALUE anlwkf    0='(0) Did not use weekly or more past year (IRANLFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRANLFQ=1-3)' ;
  VALUE anloccf   0='(0) Used monthly/more or none in pst yr(IRANLFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRANLFQ=6-8)' ;
  VALUE anldlyf   0='(0) Did not use daily/almost daily pst yr(IRANLFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRANLFQ=1-2)' ;
  VALUE alcyrf    0='(0) Never used or not used in past year (IRALCFQ=9)'
                  1='(1) Any use within the past year (IRALCFQ=1-8)' ;
  VALUE alcmonf   0='(0) Did not use monthly/more past year (IRALCFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRALCFQ=1-5)' ;
  VALUE alcwkf    0='(0) Did not use weekly or more past year (IRALCFQ=4-9)'
                  1='(1) Used weekly or more in past year (IRALCFQ=1-3)' ;
  VALUE alcoccf   0='(0) Used monthly/more or none in pst yr(IRALCFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRALCFQ=6-8)' ;
  VALUE alcdlyf   0='(0) Did not use daily/almost daily pst yr(IRALCFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRALCFQ=1-2)' ;
  VALUE smkyrf    0='(0) Never used or did not use in past year (IROTBFQ=9)'
                  1='(1) Any use within the past year (IROTBFQ=1-8)' ;
  VALUE smkmonf   0='(0) Did not use monthly/more past year (IROTBFQ=6-9)'
                  1='(1) Used monthly or more often past year (IROTBFQ=1-5)' ;
  VALUE smkwkf    0='(0) Did not use weekly or more past year (IROTBFQ=4-9)'
                  1='(1) Used weekly or more often past year (IROTBFQ=1-3)' ;
  VALUE smkoccf   0='(0) Used monthly/more or none in pst yr(IROTBFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IROTBFQ=6-8)' ;
  VALUE smkdlyf   0='(0) Did not use daily/almost daily pst yr(IROTBFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IROTBFQ=1-2)' ;
  VALUE mrjyrf    0='(0) Never used or did not use in past year (IRMJFQ=10)'
                  1='(1) Any use within the past year (IRMJFQ=1-9)' ;
  VALUE mrjmonf   0='(0) Did not use monthly/more past year (IRMJFQ=7-10)'
                  1='(1) Used monthly or more in past year (IRMJFQ=1-6)' ;
  VALUE mrjwkf    0='(0) Did not use weekly/more past year (IRMJFQ=5-10)'
                  1='(1) Used weekly or more in past year (IRMJFQ=1-4)' ;
  VALUE mrjoccf   0='(0) Used monthly/more or none in pst yr(IRMJFQ=1-6,10)'
                  1='(1) Used past year but less than monthly (IRMJFQ=7-9)' ;
  VALUE mrjdlyf   0='(0) Did not use daily/almost daily pst yr(IRMJFQ=4-10)'
                  1='(1) Used daily/almost daily in past year (IRMJFQ=1-3)' ;
  VALUE cocyrf    0='(0) Never used or did not use in past year (IRCOCFQ=9)'
                  1='(1) Any use within the past year (IRCOCFQ = 1-8)' ;
  VALUE cocmonf   0='(0) Did not use monthly/more past year (IRCOCFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRCOCFQ=1-5)' ;
  VALUE cocwkf    0='(0) Did not use weekly or more past year (IRCOCFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRCOCFQ=1-3)' ;
  VALUE cococcf   0='(0) Used monthly/more or none in pst yr(IRCOCFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRCOCFQ=6-8)' ;
  VALUE cocdlyf   0='(0) Did not use daily/almost daily pst yr(IRCOCFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRCOCFQ=1-2)' ;
  VALUE inhyrf    0='(0) Never used or did not use in past year (IRINHFQ=9)'
                  1='(1) Any use within the past year (IRINHFQ=1-8)' ;
  VALUE inhmonf   0='(0) Did not use monthly/more past year (IRINHFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRINHFQ=1-5)' ;
  VALUE inhwkf    0='(0) Did not use weekly or more past year (IRINHFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRINHFQ=1-3)' ;
  VALUE inhoccf   0='(0) Used monthly/more or none in pst yr(IRINHFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRINHFQ=6-8)' ;
  VALUE inhdlyf   0='(0) Did not use daily/almost daily pst yr(IRINHFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRINHFQ=1-2)' ;
  VALUE psyflagf  0='(0) Never used (ALL SOURCE VARIABLES = 9)'
                  1='(1) Ever used (ANY SOURCE VARIABLE < 9)' ;
  VALUE psyyr2ff  0='(0) Did not use within past year (ALL SOURCE VARS > 3)'
                  1='(1) Used in past year (ANY SOURCE VARIABLE < 4)' ;
  VALUE psymon2f  0='(0) Did not use in past month (ALL SOURCE VARS > 1)'
                  1='(1) Used in past month (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumflag   0='(0) Never used (ALL SOURCE VARIABLES = 0)'
                  1='(1) Ever used (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumyr     0='(0) Did not use in past year (ALL SOURCE VARS =0)'
                  1='(1) Used in past year (ANY SOURCE VARIABLE = 1)' ;
  VALUE summon    0='(0) Did not use in past month (ALL SOURCE VARS = 0)'
                  1='(1) Used in past month (ANY SOURCE VARIABLE = 1)' ;
  VALUE mjoflag   0='(0) Never used MJ/has used both MJ & anothr illct drug'
                  1='(1) Marijuana is only (illicit) drug ever used' ;
  VALUE mjoyr2ff  0='(0) MJ not used past yr/Used MJ & othr drug past yr'
                  1='(1) Marijuana is only (illicit) drug in past year' ;
  VALUE mjomon2f  0='(0) MJ not used past mnth/Used MJ & othr drug past mo'
                  1='(1) Marijuana only (illicit) drug in past month' ;
  VALUE iemflag   0='(0) Never used drug/used only marijuana'
                  1='(1) Illicit drug except for marijuana are ever used' ;
  VALUE iemyr     0='(0) Never used drug/used only marijuana past year'
                  1='(1) Illicit drug except for marijuana used past year' ;
  VALUE iemmon    0='(0) Never used drug/used only marijuana past month'
                  1='(1) Illicit drug except for marijuana used past month' ;
  VALUE hsphconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less than 50 pcnt'
                  3='(3) Less than 10 percent' ;
  VALUE hsppconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less than 50 pcnt'
                  3='(3) Less than 10 percent' ;
  VALUE ownoconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less than 50 pcnt'
                  3='(3) Less than 10 pcnt' ;
  VALUE uclass9f  0='(0) Above poverty level' 1='(1) Below poverty level' ;
  VALUE qc06ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE qc09ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED SMOKELESS TOBACCO'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE al02ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE se04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tr04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE st04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE st07ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  93='(93) NEVER USED AMPHETAMINES WITH A NEEDLE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE an04ffff  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mj04ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE in04ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED INHALANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cc04ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED COCAINE'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cc11ffff  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 91='(91) NEVER USED COCAINE'
                  93='(93) NEVER USED COCAINE WITH A NEEDLE' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ck01ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or months ago but less than 6 months ago'
                  4='(4) 6 or months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED CRACK'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ls05ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ls08ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED PCP' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE he04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HEROIN' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE he07ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HEROIN' 93='(93) NEVER USED HEROIN WITH A NEEDLE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nd02ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than a year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  91='(91) NEVER USED ANY DRUG FOR NONMEDICAL REASONS'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sp04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 91='(91) NEVER USED ICE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sp08ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) More than 6 months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED ANABOLIC STEROIDS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjtot2ff  1='(1) Never used marijuana (MJTOT = 81,91)'
                  2='(2) 1-2 times (MJTOT = 1)' 3='(3) 3-10 times (MJTOT = 2,3)'
                  4='(4) 11-99 times (MJTOT = 4,5)'
                  5='(5) 100 or more times (MJTOT = 6,7)'
                  6='(6) Unknown (MJTOT = 85,94,97,98)' ;
  VALUE coctot2f  1='(1) Never used cocaine (COCTOT = 81,91)'
                  2='(2) 1-2 times (COCTOT = 1)' 3='(3) 3-10 times (COCTOT = 2,3)'
                  4='(4) 11-99 times (COCTOT = 4,5)'
                  5='(5) 100 or more times (COCTOT = 6,7)'
                  6='(6) Unknown (COCTOT = 85,97,98)' ;
  VALUE mjtot3ff  1='(1) 1-2 times (MJTOT2 = 2)' 2='(2) 3-10 times (MJTOT2 = 3)'
                  3='(3) 11-99 times (MJTOT2 = 4)'
                  4='(4) 100 or more times (MJTOT2 = 5)'
                  5='(5) Never used marijuana (MJTOT2 = 1)' ;
  VALUE coctot3f  1='(1) 1-2 times (COCTOT2 = 2)' 2='(2) 3-10 times (COCTOT2 = 3)'
                  3='(3) 11-99 times (COCTOT2 = 4)'
                  4='(4) 100 or more times (COCTOT2 = 5)'
                  5='(5) Never used cocaine (COCTOT2 = 1)' ;
  VALUE mjdy30af  1='(1) None/never used marijuana (MJDAY30A = 0,81,91,93)'
                  2='(2) 1-2 days (MJDAY30A = 1-2)' 3='(3) 3-4 days (MJDAY30A = 3-4)'
                  4='(4) 5-19 days (MJDAY30A = 5-19)'
                  5='(5) 20-30 days (MJDAY30A = 20-30)'
                  6='(6) Unknown (MJDAY30A = 85,94,95,98)' ;
  VALUE alcdaysf  1='(1) None or never used alcohol (ALCDAYS = 0,81,91,93)'
                  2='(2) 1-2 days (ALCDAYS = 1-2)' 3='(3) 3-4 days (ALCDAYS = 3-4)'
                  4='(4) 5-19 days (ALCDAYS = 5-19)'
                  5='(5) 20-30 days (ALCDAYS = 20-31)'
                  6='(6) Don''t know, bad data, or blank (no answer)' ;
  VALUE mrjmon2f  1='(1) Did not use in past month (MRJMON = 0)'
                  2='(2) Used within the past month (MRJMON = 1)' ;
  VALUE alcmon2f  1='(1) Did not use in the past month (ALCMON = 0)'
                  2='(2) Used within the past month (ALCMON = 1)' ;
  VALUE cigmon2f  1='(1) Did not use in past month (CIGMON = 0)'
                  2='(2) Used within past month (CIGMON = 1)' ;
  VALUE lsd2ffff  0='(0) Never used hallucinogens (LSD = 2,81,91,97,98)'
                  1='(1) Ever used LSD (LSD = 1)' ;
  VALUE peyote2f  0='(0) Never used hallucinogens (PEYOTE = 2,81,91,97,98)'
                  1='(1) Ever used Peyote (PEYOTE = 1)' ;
  VALUE mesc2fff  0='(0) Never used hallucinogens (MESC = 2,81,91,97,98)'
                  1='(1) Ever used Mescaline (MESC = 1)' ;
  VALUE psilcy2f  0='(0) Never used hallucinogens (PSILCY = 2,81,91,97,98)'
                  1='(1) Ever used Psilocybin (PSILCY = 1)' ;
  VALUE ecstasyf  0='(0) Never used hallucinogens (ECSTASY=2,81,91,97,98)'
                  1='(1) Ever used Ecstasy (ECSTASY=1)' ;
  VALUE gas2ffff  0='(0) Never inhaled (GAS = 2,81,91,98)'
                  1='(1) Ever inhaled (GAS = 1,3)' ;
  VALUE lgas2fff  0='(0) Never inhaled (LGAS=2,81,91,98)'
                  1='(1) Ever inhaled (LGAS=1,3)' ;
  VALUE sppaintf  0='(0) Never inhaled (SPPAINT = 2,81,91,98)'
                  1='(1) Ever inhaled (SPPAINT = 1,3)' ;
  VALUE aeros2ff  0='(0) Never inhaled (AEROS = 2,81,91,98)'
                  1='(1) Ever inhaled (AEROS = 1,3)' ;
  VALUE glue2fff  0='(0) Never inhaled (GLUE = 2,81,91,98)'
                  1='(1) Ever inhaled (GLUE = 1,3)' ;
  VALUE solventf  0='(0) Never inhaled (SOLVENT = 2,81,91,98)'
                  1='(1) Ever inhaled (SOLVENT = 1,3)' ;
  VALUE amylnitf  0='(0) Never inhaled (AMYLNIT = 2,81,91,98)'
                  1='(1) Ever inhaled (AMYLNIT = 1,3)' ;
  VALUE ether2ff  0='(0) Never inhaled (ETHER = 2,81,91,98)'
                  1='(1) Ever inhaled (ETHER = 1,3)' ;
  VALUE nitoxidf  0='(0) Never inhaled (NITOXID = 2,81,91,98)'
                  1='(1) Ever inhaled (NITOXID = 1,3)' ;
  VALUE cleflu2f  0='(0) Never inhaled (CLEFLU = 2,81,91,98)'
                  1='(1) Ever inhaled (CLEFLU = 1,3)' ;
  VALUE cocsni0f  0='(0) Never/no use pst 12 mos(COCSNIFF=2,81,83,91,93,97)'
                  1='(1) Sniffed/snorted in past 12 months (COCSNIFF = 1)' ;
  VALUE freebasf  0='(0) Never/no use pst 12 mos(FREEBASE=2,81,83,91,93,97)'
                  1='(1) Freebased in past 12 months (FREEBASE = 1,3)' ;
  VALUE cocswalf  0='(0) Never/no use pst 12 mos(COCSWAL=2,81,83,91,93,97)'
                  1='(1) Swallowed/drank in past 12 months (COCSWAL = 1)' ;
  VALUE cociv2ff  0='(0) Never/no use past 12 mos (COCIV=2,81,83,91,93,97)'
                  1='(1) Injected in the past 12 months (COCIV = 1,3)' ;
  VALUE mjdy300f  1='(1) 1-2 days (MJDAY30A2 = 2)' 2='(2) 3-4 days (MJDAY30A2 = 3)'
                  3='(3) 5-19 days (MJDAY30A2 = 4)'
                  4='(4) 20-30 days (MJDAY30A2 = 5)'
                  5='(5) None or never used marijuana (MJDAY30A2 = 1)' ;
  VALUE alcday0f  1='(1) None or never used alcohol (ALCDAYS2 = 1)'
                  2='(2) 1-4 days (ALCDAYS2 = 2-3)' 3='(3) 5-19 days (ALCDAYS2 = 4)'
                  4='(4) 20-30 days (ALCDAYS2 = 5)' ;
  VALUE drinkerf  0='(0) Never/no ALC use (ALCMON=0 and DR5DAY=0,81,91,93)'
                  1='(1) Alcohol use (ALCMON = 1 and DR5DAY = 0-30)' ;
  VALUE hvydrk2f  0='(0) Never/no heavy use (DR5DAY=0-4,81,91,93)'
                  1='(1) Heavy alcohol use (DR5DAY = 5-30)' ;
  VALUE avcig2ff  1='(1) None/never smoked cigarettes (AVCIG=81,89,91,99)'
                  2='(2) Currently smoke < a pack per day (AVCIG = 1-3)'
                  3='(3) Currently smoke a pack or more per day (AVCIG=4-6)' ;
  VALUE racesex   1='(1) White male (SEX = 1 and RACE = 1)'
                  2='(2) Black male (SEX = 1 and RACE = 2)'
                  3='(3) Hispanic male (SEX = 1 and RACE = 3)'
                  4='(4) White female (SEX = 2 and RACE = 1)'
                  5='(5) Black female (SEX = 2 and RACE = 2)'
                  6='(6) Hispanic female (SEX = 2 and RACE = 3)' ;
  VALUE notmarj   0='(0) No (ALL SOURCE VARIABLES = 0)'
                  1='(1) Yes (ANY SOURCE VARIABLES = 1)' ;
  VALUE cocway2f  0='(0) Never/no use past 12 months (COCWAY=2,81,83,91,93)'
                  1='(1) Used other ways past 12 months (COCWAY=1,3,6-9)' ;
  VALUE racesexf  1='(1) White male (SEX=1 and RACE=1)'
                  2='(2) Black male (SEX=1 and RACE=2)'
                  3='(3) Hispanic male (SEX=1 and RACE=3)'
                  4='(4) Other male (SEX=1 and RACE=4)'
                  5='(5) White female (SEX=2 and RACE=1)'
                  6='(6) Black female (SEX=2 and RACE=2)'
                  7='(7) Hispanic female (SEX=2 and RACE=3)'
                  8='(8) Other female (SEX=2 and RACE=4)' ;
  VALUE ircdcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used pst yr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used past'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used pst yr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used pst yr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwscig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwsalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwsmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwscoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE avcig3ff  0='(0) None/never/< pack a day (AVCIG=1-3,81,89,91,98,99)'
                  1='(1) Currently smoke a pack or more per day (AVCIG=4-6)' ;
  VALUE alcprobs  0='(0) No' 1='(1) Yes' ;
  VALUE mjprobs   0='(0) No' 1='(1) Yes' ;
  VALUE cocprobs  0='(0) No' 1='(1) Yes' ;
  VALUE cigprobs  0='(0) No' 1='(1) Yes' ;
  VALUE iralcagg  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcarg  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcabs  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralchig  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcjob  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcmat  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcrel  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcfrd  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralctos  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralchol  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcdru  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcint  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcrem  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcqui  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcmor  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcsho  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcalo  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcbrk  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE irnobooz  1='(1) No use of alcohol in the past year'
                  2='(2) Used alcohol in the past year' ;
  VALUE anyalc    0='(0) No' 1='(1) Yes' ;
  VALUE threalc   0='(0) No' 1='(1) Yes' ;
  VALUE drunkyrf  0='(0) Unknown (DRUNKYR = 85,96,97,98)'
                  1='(1) Drunk more than twice a month (DRUNKYR = 1-4)'
                  2='(2) Drunk twice a month or less (DRUNKYR = 5-8)'
                  3='(3) Never drunk in past year (DRUNKYR = 9)' ;
  VALUE irdep     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irarg     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE iraln     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE iranx     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irhlt     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irntk     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irups     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irlsw     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irssp     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE ircpe     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE iremg     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irdep1ff  116='(116) Methaqualone, Parest, Quaalude, Sopor' 201='(201) Valium'
                  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin' 313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 375='(375) sic'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  501='(501) Lighter fluids, Gasoline' 502='(502) Spray paints'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 557='(557) Hagwash'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones I''ve tried' 809='(809) Pills' 810='(810) Hemp'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco' 869='(869) sic'
                  874='(874) Premarin' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep2ff  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack, rock'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep3ff  339='(339) Amphetamines (speed generically)'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)' 803='(803) Marijuana' 804='(804) Hashish'
                  805='(805) Cocaine, Coke' 806='(806) Crack, rock' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep4ff  415='(415) Codeine' 601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 809='(809) Pills' 999='(999) LEGITIMATE SKIP' ;
  VALUE irdep5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg1ff  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 415='(415) Codeine' 440='(440) Soma' 557='(557) Hagwash'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones I''ve tried' 810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 824='(824) Steroids' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg2ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 324='(324) Uppers'
                  332='(332) Ephedrine (HCl)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  408='(408) Dilaudid' 601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg3ff  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg4ff  508='(508) Nitrous oxide, whippets, dentist gas'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irarg5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln1ff  201='(201) Valium' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 241='(241) Prozac'
                  312='(312) Ionamin' 322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth' 401='(401) Darvon'
                  406='(406) Oxycodone, Percodan, Roxicet' 408='(408) Dilaudid'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 707='(707) Black Tar' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 808='(808) All of the ones I''ve tried' 809='(809) Pills'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln2ff  209='(209) Xanax' 324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  434='(434) Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin.'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  840='(840) Cough medicine (contents not specified)'
                  848='(848) Liquid vitamin <OTC>' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln3ff  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 807='(807) Alcohol'
                  809='(809) Pills' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx1ff  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 247='(247) Adapin, Doxepin, Sinequan' 271='(271) Zoloft'
                  301='(301) Dexedrine' 309='(309) Didrex' 312='(312) Ionamin'
                  313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine' 336='(336) Diet pills'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  354='(354) Vivarin <OTC>' 355='(355) Crystal meth' 375='(375) sic'
                  408='(408) Dilaudid' 415='(415) Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  435='(435) Tylenol, Tylenol Extra-Strength <OTC>'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 557='(557) Hagwash'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) Phencyclidine (angel dust, PCP)'
                  606='(606) Ecstasy (MDMA), X-TC'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones I''ve tried' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 873='(873) Contraceptives, Feutal, Ortho Novum'
                  998='(998) BLANK (NOT ANSWERED)' 999='(999) LEGITIMATE SKIP' ;
  VALUE iranx2ff  120='(120) Downers' 322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilcybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx3ff  326='(326) White cross' 702='(702) Heroin' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 803='(803) Marijuana'
                  807='(807) Alcohol' 809='(809) Pills' 999='(999) LEGITIMATE SKIP' ;
  VALUE iranx5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt1ff  209='(209) Xanax' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 362='(362) Benadryl' 408='(408) Dilaudid'
                  501='(501) Gasoline or lighter fluids' 557='(557) Hagwash'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 639='(639) Cloves, Nutmet'
                  702='(702) Heroin' 704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 870='(870) sic' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt2ff  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  506='(506) Amyl nitrate, poppers, locker rm odorizer,rush'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  865='(865) Diuretics, Water pills' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt3ff  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  702='(702) Heroin' 803='(803) Marijuana' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt4ff  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk1ff  116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 241='(241) Prozac'
                  247='(247) Adapin, Doxepin, Sinequan' 271='(271) Zoloft' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 354='(354) Vivarin <OTC>' 355='(355) Crystal meth'
                  401='(401) Darvon' 407='(407) Demerol' 408='(408) Dilaudid'
                  409='(409) Tylenol with Codeine, Tylenol' 418='(418) Methadone'
                  501='(501) Gasoline or lighter fluids' 502='(502) Spray paints'
                  504='(504) Shoeshine liq, glue,toluene,SuperGlue,rubber cem..'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, felt-tip pens, ink pens'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 609='(609) sic'
                  702='(702) Heroin' 704='(704) Dope' 705='(705) Speel Ball (heroin + cocaine)'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 815='(815) Coffee'
                  823='(823) sic'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  873='(873) Contraceptives, Feutal, Ortho Novum'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE irntk2ff  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  407='(407) Demerol' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  506='(506) Amyl nitrate, poppers, locker rm odorizer,rush'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk3ff  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid, white lightning)' 602='(602) Peyote'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk4ff  415='(415) Codeine' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk5ff  201='(201) Valium' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  803='(803) sic' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups1ff  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  409='(409) Tylenol with Codeine, Tylenol'
                  434='(434) Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin.'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones I''ve tried' 810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 824='(824) Steroids'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups2ff  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed generically)' 408='(408) Dilaudid'
                  434='(434) Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin.'
                  508='(508) Notrous oxide, whippets, dentist gas'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 809='(809) Pills' 811='(811) Muscle relaxers'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  815='(815) Coffee' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups3ff  437='(437) Parafon Forte' 601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  809='(809) Pills' 813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw1ff  201='(201) Valium' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)' 324='(324) Uppers'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  501='(501) Gasoline or lighter fluids'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 815='(815) Coffee'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw2ff  408='(408) Dilaudid' 508='(508) Nitrous oxide, whippets, dentist gas'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw3ff  339='(339) Amphetamines (speed generically)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  804='(804) Hashish' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 805='(805) Cocaine, Coke'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp1ff  312='(312) Ionamin' 322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  707='(707) Black Tar' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE irssp2ff  322='(322) Methamphetamine (speed or ice or crank)'
                  408='(408) Dilaudid' 601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp3ff  339='(339) Amphetamines (speed generically)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irssp5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe1ff  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 809='(809) Pills'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  818='(818) Nicotine' 824='(824) Steroids' 877='(877) Methozolamide'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe2ff  239='(239) Elavil' 408='(408) Dilaudid'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe3ff  339='(339) Amphetamines (speed generically)' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe5ff  607='(607) OTHER HAllucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg1ff  108='(108) Carbrital, Nembutal' 209='(209) Xanax' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  430='(430) Aspirin, Ecotrin, Empiron <OTC>' 435='(435) Tylenol'
                  503='(503) Other aerosol sprays' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 606='(606) sic'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 815='(815) Coffee'
                  858='(858) Antibiotic' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg2ff  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg3ff  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg4ff  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE iras13ff  1='(1) Never used any of the substances listed'
                  2='(2) Used one or more of the listed substances' ;
  VALUE depcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE depalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE depmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE depcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE argcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE argalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE argmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE argcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE alncig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE alnalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE alnmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE alncoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE anxcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE anxalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE anxmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE anxcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE hltcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE hltalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE hltmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE hltcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE ntkcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE ntkalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE ntkmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE ntkcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE upscig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE upsalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE upsmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE upscoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE lswcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE lswalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE lswmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE lswcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE sspcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE sspalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE sspmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE sspcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE cpecig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE cpealc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE cpemrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE cpecoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE emcig2ff  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE emalc2ff  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE emmrj2ff  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE emcoc2ff  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE prb1cig   0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE prb1alc   0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE prb1mrj   0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE prb1coc   0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE prb2cig   0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE prb2alc   0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE prb2mrj   0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE prb2coc   0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE prb3cig   0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE prb3alc   0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE prb3mrj   0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE prb3coc   0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE anyprob   0='(0) No' 1='(1) Yes' ;
  VALUE twoprob   0='(0) No' 1='(1) Yes' ;
  VALUE threprob  0='(0) No' 1='(1) Yes' ;
  VALUE alconlyl  0='(0) No' 1='(1) Yes (ALCFLAG=1 AND SUMFLAG=0)' ;
  VALUE alconlyy  0='(0) No' 1='(1) Yes (ALCYR=1 AND SUMYR=0)' ;
  VALUE alconlym  0='(0) No' 1='(1) Yes (ALCMON=1 AND SUMMON=0)' ;
  VALUE illonlyl  0='(0) No' 1='(1) Yes (SUMFLAG=1 AND ALCFLAG=0)' ;
  VALUE illonlyy  0='(0) No' 1='(1) Yes (SUMYR=1 AND ALCYR=0)' ;
  VALUE illonlym  0='(0) No' 1='(1) Yes (SUMMON=1 AND ALCMON=0)' ;
  VALUE mrjonlyl  0='(0) No' 1='(1) Yes (MJOFLAG=1 AND ALCFLAG=0)' ;
  VALUE mrjonlyy  0='(0) No' 1='(1) Yes (MJOYR2=1 AND ALCYR=0)' ;
  VALUE mrjonlym  0='(0) No' 1='(1) Yes (MJOMON2=1 AND ALCMON=0)' ;
  VALUE psyonlyl  0='(0) No' 1='(1) Yes (PSYFLAG2=1 AND ALL OTHER SOURCE VARS=0)' ;
  VALUE psyonlyy  0='(0) No' 1='(1) Yes (PSYYR2=1 AND ALL OTHER SOURCE VARS=0)' ;
  VALUE psyonlym  0='(0) No' 1='(1) Yes (PSYMON2=1 AND ALL OTHER SOURCE VARS=0)' ;
  VALUE othonlyl  0='(0) No'
                  1='(1) Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR SOURCE VAR=1)' ;
  VALUE othonlyy  0='(0) No'
                  1='(1) Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR SOURCE VAR=1)' ;
  VALUE othonlym  0='(0) No'
                  1='(1) Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR SOURCE VAR=1)' ;
  VALUE alcilll   0='(0) No' 1='(1) Yes (ALCFLAG=1 AND SUMFLAG=1)' ;
  VALUE alcilly   0='(0) No' 1='(1) Yes (ALCYR=1 AND SUMYR=1)' ;
  VALUE alcillm   0='(0) No' 1='(1) Yes (ALCMON=1 AND SUMMON=1)' ;
  VALUE alcmrjl   0='(0) No'
                  1='(1) Yes (ALCFLAG,MRJFLAG=1 AND ALL OTHER SOURCE VAR=0)' ;
  VALUE alcmrjy   0='(0) No'
                  1='(1) Yes (ALCYR AND MRJYR=1 AND ALL OTHER SOURCE VAR=0)' ;
  VALUE alcmrjm   0='(0) No'
                  1='(1) Yes (ALCMON & MRJMON=1 AND ALL OTHER SOURCE VAR=0)' ;
  VALUE alcpsyl   0='(0) No'
                  1='(1) Yes (ALCFLAG,PSYFLAG2=1 & ALL OTHER SOURCE VAR=0)' ;
  VALUE alcpsyy   0='(0) No'
                  1='(1) Yes (ALCYR & PSYYR2=1 AND ALL OTHER SOURCE VAR=0)' ;
  VALUE alcpsym   0='(0) No'
                  1='(1) Yes (ALCMON & PSYMON2=1 & ALL OTHER SOURCE VAR=0)' ;
  VALUE alcothl   0='(0) No' 1='(1) Yes (ALCFLAG=1 & NEXT 2 VAR=0 & ANY OTHER VAR=1)' ;
  VALUE alcothy   0='(0) No' 1='(1) Yes (ALCYR=1 & NEXT 2 VAR=0 & ANY OTHER VAR=1)' ;
  VALUE alcothm   0='(0) No' 1='(1) Yes (ALCMON=1 & NEXT 2 VAR=0 & ANY OTHER VAR=1)' ;
  VALUE sub1lif   0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub2lif   0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub3lif   0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE sub1yr    0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub2yr    0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub3yr    0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE sub1mon   0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub2mon   0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub3mon   0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE chancmjf  0='(0) Did not have a chance to use marijuana'
                  1='(1) Had a chance to use marijuana' 94='(94) UNKNOWN' ;
  VALUE chancocf  0='(0) Did not have a chance to use cocaine'
                  1='(1) Had a chance to use cocaine' 94='(94) UNKNOWN' ;
  VALUE chanhalf  0='(0) Did not have a chance to use hallucinogens'
                  1='(1) Had a chance to use hallucinogens' 94='(94) UNKNOWN' ;
  VALUE chanherf  0='(0) Did not have a chance to use heroin'
                  1='(1) Had a chance to use heroin' 94='(94) UNKNOWN' ;
  VALUE trmthlpf  0='(0) No (TRMTHELP=2)' 1='(1) Yes (TRMTHELP=1)' ;
  VALUE drnkhlpf  0='(0) No (DRNKHELP=2)' 1='(1) Yes (DRNKHELP=1)' ;
  VALUE dralhelp  0='(0) No (see note above)' 1='(1) Yes (TRMTHLP2=1 or DRNKHLP2=1)' ;
  VALUE rurorurb  1='(1) Rural' 2='(2) Urban' ;
  VALUE pblackhh  1='(1) Greater than or equal to 50 percent'
                  2='(2) Greater than or equal to 10 percent,'
                  3='(3) Less than 10 percent' ;
  VALUE pblackp   1='(1) Greater than or equal to 50 percent'
                  2='(2) Greater than or equal to 10 percent,'
                  3='(3) Less than 10 percent' ;
  VALUE ppoverty  1='(1) 0 - 2.65 percent' 2='(2) 2.66 - 5.12 percent'
                  3='(3) 5.13 - 9.02 percent' 4='(4) 9.03 - 16.15 percent'
                  5='(5) 16.16 percent or more' ;
  VALUE powned    1='(1) 0 - 50.25 percent' 2='(2) 50.26 - 67.58 percent'
                  3='(3) 67.59 - 76.38 percent' 4='(4) 76.39 - 83.96 percent'
                  5='(5) 83.97 percent or more' ;
  VALUE prented   1='(1) 0 - 16.04 percent' 2='(2) 16.05 - 23.62 percent'
                  3='(3) 23.63 - 32.42 percent' 4='(4) 32.43 - 49.75 percent'
                  5='(5) 49.75 percent or more' ;
  VALUE ownedave  1='(1) 0 - $44,777' 2='(2) $44,778 - $60,832' 3='(3) $60,833 - $85,121'
                  4='(4) $85,122 - $142,831' 5='(5) $142,832 or more' ;
  VALUE rentave   1='(1) 0 - $315.81' 2='(2) $315.82 - $393.95' 3='(3) $393.96 - $476.96'
                  4='(4) $476.97 - $619.72' 5='(5) $619.72 or more' ;
  VALUE irkids    0='(0) None' 1='(1) One' 2='(2) Two' 3='(3) Three' 4='(4) Four' 5='(5) Five'
                  6='(6) Six or more' ;
  VALUE cweocc2f  990='(990) INDUSTRY NOT REPORTED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE roccup2f  990='(990) OCCUPATION NOT REPORTED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cwebus2f  990='(990) INDUSTRY NOT REPORTED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE businesf  990='(990) INDUSTRY NOT REPORTED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CIGTRY >= 981) THEN CIGTRY = .;
   IF (CIG5PK >= 81) THEN CIG5PK = .;
   IF (CIGAGE >= 981) THEN CIGAGE = .;
   IF (CIGYRS >= 981) THEN CIGYRS = .;
   IF (PACKS >= 81) THEN PACKS = .;
   IF (CIGREC >= 81) THEN CIGREC = .;
   IF (AVCIG >= 81) THEN AVCIG = .;
   IF (CIGTIME >= 9981) THEN CIGTIME = .;
   IF (SNUFREC >= 81) THEN SNUFREC = .;
   IF (OTHTOB >= 81) THEN OTHTOB = .;
   IF (ALCTRY >= 981) THEN ALCTRY = .;
   IF (ALCREC >= 81) THEN ALCREC = .;
   IF (ALCAGE >= 981) THEN ALCAGE = .;
   IF (ALCDAYS >= 81) THEN ALCDAYS = .;
   IF (NODR30A >= 81) THEN NODR30A = .;
   IF (DR5DAY >= 81) THEN DR5DAY = .;
   IF (MODR30A >= 81) THEN MODR30A = .;
   IF (MODR30DY >= 81) THEN MODR30DY = .;
   IF (ALCPAT >= 81) THEN ALCPAT = .;
   IF (DRUNKYR >= 81) THEN DRUNKYR = .;
   IF (ALCBEER >= 81) THEN ALCBEER = .;
   IF (ALCWINE >= 81) THEN ALCWINE = .;
   IF (ALCLIQR >= 81) THEN ALCLIQR = .;
   IF (ALCVARY >= 81) THEN ALCVARY = .;
   IF (NOSEDAT >= 81) THEN NOSEDAT = .;
   IF (BUTISOL >= 81) THEN BUTISOL = .;
   IF (BUTICAPS >= 81) THEN BUTICAPS = .;
   IF (AMYTAL >= 81) THEN AMYTAL = .;
   IF (MEBARAL >= 81) THEN MEBARAL = .;
   IF (PLACIDYL >= 81) THEN PLACIDYL = .;
   IF (DORIDEN >= 81) THEN DORIDEN = .;
   IF (NOLUDAR >= 81) THEN NOLUDAR = .;
   IF (NEMBUTAL >= 81) THEN NEMBUTAL = .;
   IF (SECONAL >= 81) THEN SECONAL = .;
   IF (TUINAL >= 81) THEN TUINAL = .;
   IF (DALMANE >= 81) THEN DALMANE = .;
   IF (RESTORIL >= 81) THEN RESTORIL = .;
   IF (HALCION >= 81) THEN HALCION = .;
   IF (AMOBARB >= 81) THEN AMOBARB = .;
   IF (PHENOBAR >= 81) THEN PHENOBAR = .;
   IF (METHAQ >= 81) THEN METHAQ = .;
   IF (CHHYD >= 81) THEN CHHYD = .;
   IF (PENTOB >= 81) THEN PENTOB = .;
   IF (SECOB >= 81) THEN SECOB = .;
   IF (SEDNEWA >= 981) THEN SEDNEWA = .;
   IF (SEDNEWB >= 981) THEN SEDNEWB = .;
   IF (SEDNEWC >= 981) THEN SEDNEWC = .;
   IF (SEDNEWD >= 981) THEN SEDNEWD = .;
   IF (SEDNEWE >= 981) THEN SEDNEWE = .;
   IF (SEDNOSP >= 81) THEN SEDNOSP = .;
   IF (SEDDKNAM >= 81) THEN SEDDKNAM = .;
   IF (SEDAGE >= 981) THEN SEDAGE = .;
   IF (SEDTOT >= 81) THEN SEDTOT = .;
   IF (SEDREC >= 81) THEN SEDREC = .;
   IF (SEDYRFRQ >= 81) THEN SEDYRFRQ = .;
   IF (TRNREAD >= 81) THEN TRNREAD = .;
   IF (NOTRANQ >= 81) THEN NOTRANQ = .;
   IF (VALIUM >= 81) THEN VALIUM = .;
   IF (LIBRIUM >= 81) THEN LIBRIUM = .;
   IF (LIMBTROL >= 81) THEN LIMBTROL = .;
   IF (MENRIUM >= 81) THEN MENRIUM = .;
   IF (SERAX >= 81) THEN SERAX = .;
   IF (TRANXENE >= 81) THEN TRANXENE = .;
   IF (ATIVAN >= 81) THEN ATIVAN = .;
   IF (CENTRAX >= 81) THEN CENTRAX = .;
   IF (XANAX >= 81) THEN XANAX = .;
   IF (PAXIPAM >= 81) THEN PAXIPAM = .;
   IF (BUSPAR >= 81) THEN BUSPAR = .;
   IF (MILTOWN >= 81) THEN MILTOWN = .;
   IF (EQUANIL >= 81) THEN EQUANIL = .;
   IF (DEPROL >= 81) THEN DEPROL = .;
   IF (VISTAR >= 81) THEN VISTAR = .;
   IF (ATARAX >= 81) THEN ATARAX = .;
   IF (DURRAX >= 81) THEN DURRAX = .;
   IF (DIAZEPAM >= 81) THEN DIAZEPAM = .;
   IF (SKLY >= 81) THEN SKLY = .;
   IF (MEPROB >= 81) THEN MEPROB = .;
   IF (TRNEWA >= 981) THEN TRNEWA = .;
   IF (TRNEWB >= 981) THEN TRNEWB = .;
   IF (TRNEWC >= 981) THEN TRNEWC = .;
   IF (TRNEWD >= 981) THEN TRNEWD = .;
   IF (TRNEWE >= 981) THEN TRNEWE = .;
   IF (TRNOSP >= 81) THEN TRNOSP = .;
   IF (TRDKNAM >= 81) THEN TRDKNAM = .;
   IF (TRANAGE >= 981) THEN TRANAGE = .;
   IF (TRANTOT >= 81) THEN TRANTOT = .;
   IF (TRANREC >= 81) THEN TRANREC = .;
   IF (TRNYRFRQ >= 81) THEN TRNYRFRQ = .;
   IF (STMREAD >= 81) THEN STMREAD = .;
   IF (NOSTIMS >= 81) THEN NOSTIMS = .;
   IF (DEXED >= 81) THEN DEXED = .;
   IF (DEXAMYL >= 81) THEN DEXAMYL = .;
   IF (ESKAT >= 81) THEN ESKAT = .;
   IF (BENZ >= 81) THEN BENZ = .;
   IF (BIPHET >= 81) THEN BIPHET = .;
   IF (DESOXYN >= 81) THEN DESOXYN = .;
   IF (TENUATE >= 81) THEN TENUATE = .;
   IF (TEPANIL >= 81) THEN TEPANIL = .;
   IF (DIDREX >= 81) THEN DIDREX = .;
   IF (PLEGINE >= 81) THEN PLEGINE = .;
   IF (PRELUDIN >= 81) THEN PRELUDIN = .;
   IF (IONAMIN >= 81) THEN IONAMIN = .;
   IF (FASTIN >= 81) THEN FASTIN = .;
   IF (PONDIMIN >= 81) THEN PONDIMIN = .;
   IF (VORANIL >= 81) THEN VORANIL = .;
   IF (SANOREX >= 81) THEN SANOREX = .;
   IF (MAZANOR >= 81) THEN MAZANOR = .;
   IF (RITALIN >= 81) THEN RITALIN = .;
   IF (CYLERT >= 81) THEN CYLERT = .;
   IF (DETAMP >= 81) THEN DETAMP = .;
   IF (METHI >= 81) THEN METHI = .;
   IF (METHAMP >= 81) THEN METHAMP = .;
   IF (OBLA >= 81) THEN OBLA = .;
   IF (STIMNEWA >= 981) THEN STIMNEWA = .;
   IF (STIMNEWB >= 981) THEN STIMNEWB = .;
   IF (STIMNEWC >= 981) THEN STIMNEWC = .;
   IF (STIMNEWD >= 981) THEN STIMNEWD = .;
   IF (STIMNEWE >= 981) THEN STIMNEWE = .;
   IF (STIMNOSP >= 81) THEN STIMNOSP = .;
   IF (STMDKNAM >= 81) THEN STMDKNAM = .;
   IF (STIMAGE >= 981) THEN STIMAGE = .;
   IF (STIMTOT >= 81) THEN STIMTOT = .;
   IF (STIMREC >= 81) THEN STIMREC = .;
   IF (STMYRFRQ >= 81) THEN STMYRFRQ = .;
   IF (STNEEDLE >= 81) THEN STNEEDLE = .;
   IF (STNDLREC >= 81) THEN STNDLREC = .;
   IF (ANLREAD >= 81) THEN ANLREAD = .;
   IF (ANALNONE >= 81) THEN ANALNONE = .;
   IF (DARVON >= 81) THEN DARVON = .;
   IF (DOLENE >= 81) THEN DOLENE = .;
   IF (SK65A >= 81) THEN SK65A = .;
   IF (WYGESIC >= 81) THEN WYGESIC = .;
   IF (LEVODRO >= 81) THEN LEVODRO = .;
   IF (PERCODAN >= 81) THEN PERCODAN = .;
   IF (DEMEROL >= 81) THEN DEMEROL = .;
   IF (DILAUD >= 81) THEN DILAUD = .;
   IF (TYLCOD >= 81) THEN TYLCOD = .;
   IF (PHENCOD >= 81) THEN PHENCOD = .;
   IF (TALWIN >= 81) THEN TALWIN = .;
   IF (TALWINNX >= 81) THEN TALWINNX = .;
   IF (TALACEN >= 81) THEN TALACEN = .;
   IF (PROPOXY >= 81) THEN PROPOXY = .;
   IF (CODEINE >= 81) THEN CODEINE = .;
   IF (ANILERID >= 81) THEN ANILERID = .;
   IF (MORPHINE >= 81) THEN MORPHINE = .;
   IF (METHDON >= 81) THEN METHDON = .;
   IF (STADOL >= 81) THEN STADOL = .;
   IF (ANALNEWA >= 981) THEN ANALNEWA = .;
   IF (ANALNEWB >= 981) THEN ANALNEWB = .;
   IF (ANALNEWC >= 981) THEN ANALNEWC = .;
   IF (ANALNEWD >= 981) THEN ANALNEWD = .;
   IF (ANALNEWE >= 981) THEN ANALNEWE = .;
   IF (ANLNOSP >= 81) THEN ANLNOSP = .;
   IF (ANLDKNAM >= 81) THEN ANLDKNAM = .;
   IF (ANALAGE >= 981) THEN ANALAGE = .;
   IF (ANALTOT >= 81) THEN ANALTOT = .;
   IF (ANALREC >= 81) THEN ANALREC = .;
   IF (ANLYRFRQ >= 81) THEN ANLYRFRQ = .;
   IF (MJOPP >= 981) THEN MJOPP = .;
   IF (MJAGE >= 981) THEN MJAGE = .;
   IF (MJTOT >= 81) THEN MJTOT = .;
   IF (MJREC >= 81) THEN MJREC = .;
   IF (MJDAY30A >= 81) THEN MJDAY30A = .;
   IF (MJAV30A >= 81) THEN MJAV30A = .;
   IF (MJAV30B >= 81) THEN MJAV30B = .;
   IF (MJAMT30A >= 81) THEN MJAMT30A = .;
   IF (MJFRIEND >= 81) THEN MJFRIEND = .;
   IF (MJDEALER >= 81) THEN MJDEALER = .;
   IF (MJOTHSHR >= 81) THEN MJOTHSHR = .;
   IF (MJGIVEN >= 81) THEN MJGIVEN = .;
   IF (MJTRGOOD >= 81) THEN MJTRGOOD = .;
   IF (MJTRSERV >= 81) THEN MJTRSERV = .;
   IF (MJTRICK >= 81) THEN MJTRICK = .;
   IF (MJOBTNON >= 81) THEN MJOBTNON = .;
   IF (MJBUCK >= 9981.0) THEN MJBUCK = .;
   IF (MJYRFREQ >= 81) THEN MJYRFREQ = .;
   IF (MJJOINT >= 81) THEN MJJOINT = .;
   IF (MJPIPE >= 81) THEN MJPIPE = .;
   IF (MJBAKE >= 81) THEN MJBAKE = .;
   IF (MJCHEW >= 81) THEN MJCHEW = .;
   IF (MJWAY >= 81) THEN MJWAY = .;
   IF (MJLFDALY >= 81) THEN MJLFDALY = .;
   IF (INHREAD >= 81) THEN INHREAD = .;
   IF (GAS >= 81) THEN GAS = .;
   IF (LGAS >= 81) THEN LGAS = .;
   IF (SPPAINT >= 81) THEN SPPAINT = .;
   IF (AEROS >= 81) THEN AEROS = .;
   IF (GLUE >= 81) THEN GLUE = .;
   IF (SOLVENT >= 81) THEN SOLVENT = .;
   IF (AMYLNIT >= 81) THEN AMYLNIT = .;
   IF (ETHER >= 81) THEN ETHER = .;
   IF (NITOXID >= 81) THEN NITOXID = .;
   IF (CLEFLU >= 81) THEN CLEFLU = .;
   IF (INHNEWA >= 981) THEN INHNEWA = .;
   IF (INHNEWB >= 981) THEN INHNEWB = .;
   IF (INHNEWC >= 981) THEN INHNEWC = .;
   IF (INHNEWD >= 981) THEN INHNEWD = .;
   IF (INHNEWE >= 981) THEN INHNEWE = .;
   IF (INHNOSP >= 81) THEN INHNOSP = .;
   IF (INHDKNAM >= 81) THEN INHDKNAM = .;
   IF (INHAGE >= 981) THEN INHAGE = .;
   IF (INHTOT >= 81) THEN INHTOT = .;
   IF (INHREC >= 81) THEN INHREC = .;
   IF (GAS30A >= 81) THEN GAS30A = .;
   IF (LGAS30A >= 81) THEN LGAS30A = .;
   IF (SPPAN30A >= 81) THEN SPPAN30A = .;
   IF (AEROS30A >= 81) THEN AEROS30A = .;
   IF (GLUE30A >= 81) THEN GLUE30A = .;
   IF (SOLVN30A >= 81) THEN SOLVN30A = .;
   IF (AMLNT30A >= 81) THEN AMLNT30A = .;
   IF (ETHER30A >= 81) THEN ETHER30A = .;
   IF (NOX30A >= 81) THEN NOX30A = .;
   IF (CLFL30A >= 81) THEN CLFL30A = .;
   IF (INNEW30A >= 981) THEN INNEW30A = .;
   IF (INNEW30B >= 981) THEN INNEW30B = .;
   IF (INNEW30C >= 981) THEN INNEW30C = .;
   IF (INNEW30D >= 981) THEN INNEW30D = .;
   IF (INNEW30E >= 981) THEN INNEW30E = .;
   IF (IN30NOSP >= 81) THEN IN30NOSP = .;
   IF (INH30NO >= 81) THEN INH30NO = .;
   IF (INHDY30A >= 81) THEN INHDY30A = .;
   IF (INHYRFRQ >= 81) THEN INHYRFRQ = .;
   IF (INHPO >= 81) THEN INHPO = .;
   IF (INHQNC1 >= 81) THEN INHQNC1 = .;
   IF (INHQNC2 >= 81) THEN INHQNC2 = .;
   IF (INHQNC3 >= 81) THEN INHQNC3 = .;
   IF (INHQNC4 >= 81) THEN INHQNC4 = .;
   IF (INHQNC5 >= 81) THEN INHQNC5 = .;
   IF (INHQNC6 >= 81) THEN INHQNC6 = .;
   IF (INHQNC7 >= 81) THEN INHQNC7 = .;
   IF (INHQNC8 >= 81) THEN INHQNC8 = .;
   IF (INHQNC10 >= 81) THEN INHQNC10 = .;
   IF (INHANSY >= 81) THEN INHANSY = .;
   IF (COCOPP >= 981) THEN COCOPP = .;
   IF (COCAGE >= 981) THEN COCAGE = .;
   IF (COCTOT >= 81) THEN COCTOT = .;
   IF (COCREC >= 81) THEN COCREC = .;
   IF (COCUS30A >= 81) THEN COCUS30A = .;
   IF (COCAM30A >= 81) THEN COCAM30A = .;
   IF (CCFRIEND >= 81) THEN CCFRIEND = .;
   IF (CCDEALER >= 81) THEN CCDEALER = .;
   IF (CCOTHSHR >= 81) THEN CCOTHSHR = .;
   IF (CCGIVEN >= 81) THEN CCGIVEN = .;
   IF (CCTRGOOD >= 81) THEN CCTRGOOD = .;
   IF (CCTRSERV >= 81) THEN CCTRSERV = .;
   IF (CCSTOLE >= 81) THEN CCSTOLE = .;
   IF (CCTRICK >= 81) THEN CCTRICK = .;
   IF (CCOBTNON >= 81) THEN CCOBTNON = .;
   IF (COCBUCK >= 9981) THEN COCBUCK = .;
   IF (COCYRFRQ >= 81) THEN COCYRFRQ = .;
   IF (COCSNIFF >= 81) THEN COCSNIFF = .;
   IF (COCSWAL >= 81) THEN COCSWAL = .;
   IF (COCIV >= 81) THEN COCIV = .;
   IF (FREEBASE >= 81) THEN FREEBASE = .;
   IF (COCWAY >= 81) THEN COCWAY = .;
   IF (CONDLREC >= 81) THEN CONDLREC = .;
   IF (CCLFDALY >= 81) THEN CCLFDALY = .;
   IF (CRAKREC >= 81) THEN CRAKREC = .;
   IF (CRKAM30A >= 981) THEN CRKAM30A = .;
   IF (CKFRIEND >= 81) THEN CKFRIEND = .;
   IF (CKDEALER >= 81) THEN CKDEALER = .;
   IF (CKOTHSHR >= 81) THEN CKOTHSHR = .;
   IF (CKGIVEN >= 81) THEN CKGIVEN = .;
   IF (CKTRGOOD >= 81) THEN CKTRGOOD = .;
   IF (CKTRSERV >= 81) THEN CKTRSERV = .;
   IF (CKSTOLE >= 81) THEN CKSTOLE = .;
   IF (CKTRICK >= 81) THEN CKTRICK = .;
   IF (CKOBTNON >= 81) THEN CKOBTNON = .;
   IF (CRAKBUCK >= 9981) THEN CRAKBUCK = .;
   IF (CKLFDALY >= 81) THEN CKLFDALY = .;
   IF (HALREAD >= 81) THEN HALREAD = .;
   IF (LSD >= 81) THEN LSD = .;
   IF (PEYOTE >= 81) THEN PEYOTE = .;
   IF (MESC >= 81) THEN MESC = .;
   IF (PSILCY >= 81) THEN PSILCY = .;
   IF (PCP >= 81) THEN PCP = .;
   IF (ECSTASY >= 81) THEN ECSTASY = .;
   IF (HALNEWA >= 981) THEN HALNEWA = .;
   IF (HALNEWB >= 981) THEN HALNEWB = .;
   IF (HALNEWC >= 981) THEN HALNEWC = .;
   IF (HALNEWD >= 981) THEN HALNEWD = .;
   IF (HALNEWE >= 981) THEN HALNEWE = .;
   IF (HALNOSP >= 81) THEN HALNOSP = .;
   IF (HALDKNAM >= 81) THEN HALDKNAM = .;
   IF (HALLOPP >= 81) THEN HALLOPP = .;
   IF (HALLAGE >= 81) THEN HALLAGE = .;
   IF (HALLTOT >= 81) THEN HALLTOT = .;
   IF (HALLREC >= 81) THEN HALLREC = .;
   IF (HAL30USE >= 81) THEN HAL30USE = .;
   IF (HALYRFRQ >= 81) THEN HALYRFRQ = .;
   IF (PCPREC >= 81) THEN PCPREC = .;
   IF (HERREAD >= 81) THEN HERREAD = .;
   IF (HEROPP >= 81) THEN HEROPP = .;
   IF (HERAGE >= 81) THEN HERAGE = .;
   IF (HERTOT >= 81) THEN HERTOT = .;
   IF (HERREC >= 81) THEN HERREC = .;
   IF (HER30USE >= 81) THEN HER30USE = .;
   IF (HERNEEDL >= 81) THEN HERNEEDL = .;
   IF (HRNDLREC >= 81) THEN HRNDLREC = .;
   IF (HERSMOKE >= 81) THEN HERSMOKE = .;
   IF (HRSMKREC >= 81) THEN HRSMKREC = .;
   IF (HERSNIFF >= 81) THEN HERSNIFF = .;
   IF (HRSNFREC >= 81) THEN HRSNFREC = .;
   IF (DRGREAD >= 81) THEN DRGREAD = .;
   IF (CDCIG >= 81) THEN CDCIG = .;
   IF (CDALC >= 81) THEN CDALC = .;
   IF (CDSED >= 81) THEN CDSED = .;
   IF (CDTRAN >= 81) THEN CDTRAN = .;
   IF (CDSTM >= 81) THEN CDSTM = .;
   IF (CDANAL >= 81) THEN CDANAL = .;
   IF (CDMJ >= 81) THEN CDMJ = .;
   IF (CDINH >= 81) THEN CDINH = .;
   IF (CDCOC >= 81) THEN CDCOC = .;
   IF (CDHALL >= 81) THEN CDHALL = .;
   IF (CDHER >= 81) THEN CDHER = .;
   IF (CDOTHOP >= 81) THEN CDOTHOP = .;
   IF (CDNONE >= 81) THEN CDNONE = .;
   IF (UCDCIG >= 81) THEN UCDCIG = .;
   IF (UCDALC >= 81) THEN UCDALC = .;
   IF (UCDSED >= 81) THEN UCDSED = .;
   IF (UCDTRAN >= 81) THEN UCDTRAN = .;
   IF (UCDSTM >= 81) THEN UCDSTM = .;
   IF (UCDANAL >= 81) THEN UCDANAL = .;
   IF (UCDMJ >= 81) THEN UCDMJ = .;
   IF (UCDINH >= 81) THEN UCDINH = .;
   IF (UCDCOC >= 81) THEN UCDCOC = .;
   IF (UCDHALL >= 81) THEN UCDHALL = .;
   IF (UCDHER >= 81) THEN UCDHER = .;
   IF (UCDOTHOP >= 81) THEN UCDOTHOP = .;
   IF (UCDNONE >= 81) THEN UCDNONE = .;
   IF (EFFCIG >= 81) THEN EFFCIG = .;
   IF (EFFALC >= 81) THEN EFFALC = .;
   IF (EFFSED >= 81) THEN EFFSED = .;
   IF (EFFTRAN >= 81) THEN EFFTRAN = .;
   IF (EFFSTM >= 81) THEN EFFSTM = .;
   IF (EFFANAL >= 81) THEN EFFANAL = .;
   IF (EFFMJ >= 81) THEN EFFMJ = .;
   IF (EFFINH >= 81) THEN EFFINH = .;
   IF (EFFCOC >= 81) THEN EFFCOC = .;
   IF (EFFHALL >= 81) THEN EFFHALL = .;
   IF (EFFHER >= 81) THEN EFFHER = .;
   IF (EFFOTHOP >= 81) THEN EFFOTHOP = .;
   IF (EFFNONE >= 81) THEN EFFNONE = .;
   IF (UDAYCIG >= 81) THEN UDAYCIG = .;
   IF (UDAYALC >= 81) THEN UDAYALC = .;
   IF (UDAYSED >= 81) THEN UDAYSED = .;
   IF (UDAYTRAN >= 81) THEN UDAYTRAN = .;
   IF (UDAYSTM >= 81) THEN UDAYSTM = .;
   IF (UDAYANAL >= 81) THEN UDAYANAL = .;
   IF (UDAYMJ >= 81) THEN UDAYMJ = .;
   IF (UDAYINH >= 81) THEN UDAYINH = .;
   IF (UDAYCOC >= 81) THEN UDAYCOC = .;
   IF (UDAYHALL >= 81) THEN UDAYHALL = .;
   IF (UDAYHER >= 81) THEN UDAYHER = .;
   IF (UDAYOTH >= 81) THEN UDAYOTH = .;
   IF (UDAYNONE >= 81) THEN UDAYNONE = .;
   IF (DEPCIG >= 81) THEN DEPCIG = .;
   IF (DEPALC >= 81) THEN DEPALC = .;
   IF (DEPSED >= 81) THEN DEPSED = .;
   IF (DEPTRAN >= 81) THEN DEPTRAN = .;
   IF (DEPSTM >= 81) THEN DEPSTM = .;
   IF (DEPANAL >= 81) THEN DEPANAL = .;
   IF (DEPMJ >= 81) THEN DEPMJ = .;
   IF (DEPINH >= 81) THEN DEPINH = .;
   IF (DEPCOC >= 81) THEN DEPCOC = .;
   IF (DEPHALL >= 81) THEN DEPHALL = .;
   IF (DEPHER >= 81) THEN DEPHER = .;
   IF (DEPOTHOP >= 81) THEN DEPOTHOP = .;
   IF (DEPNONE >= 81) THEN DEPNONE = .;
   IF (WSCIG >= 81) THEN WSCIG = .;
   IF (WSALC >= 81) THEN WSALC = .;
   IF (WSSED >= 81) THEN WSSED = .;
   IF (WSTRAN >= 81) THEN WSTRAN = .;
   IF (WSSTM >= 81) THEN WSSTM = .;
   IF (WSANAL >= 81) THEN WSANAL = .;
   IF (WSMJ >= 81) THEN WSMJ = .;
   IF (WSINH >= 81) THEN WSINH = .;
   IF (WSCOC >= 81) THEN WSCOC = .;
   IF (WSHALL >= 81) THEN WSHALL = .;
   IF (WSHER >= 81) THEN WSHER = .;
   IF (WSOTHOP >= 81) THEN WSOTHOP = .;
   IF (WSNONE >= 81) THEN WSNONE = .;
   IF (NDLREAD >= 81) THEN NDLREAD = .;
   IF (GNNDLLIF >= 81) THEN GNNDLLIF = .;
   IF (GNNDLREC >= 81) THEN GNNDLREC = .;
   IF (GNNDLSED >= 81) THEN GNNDLSED = .;
   IF (GNNDLTRA >= 81) THEN GNNDLTRA = .;
   IF (GNNDLSTM >= 81) THEN GNNDLSTM = .;
   IF (GNNDLANL >= 81) THEN GNNDLANL = .;
   IF (GNNDLINH >= 81) THEN GNNDLINH = .;
   IF (GNNDLCOC >= 81) THEN GNNDLCOC = .;
   IF (GNNDLHAL >= 81) THEN GNNDLHAL = .;
   IF (GNNDLHER >= 81) THEN GNNDLHER = .;
   IF (GNNDLOPT >= 81) THEN GNNDLOPT = .;
   IF (GNNDLSTR >= 81) THEN GNNDLSTR = .;
   IF (GNNDLNON >= 81) THEN GNNDLNON = .;
   IF (GNNDLSH1 >= 81) THEN GNNDLSH1 = .;
   IF (GNNDLSH2 >= 81) THEN GNNDLSH2 = .;
   IF (SPTREAD >= 81) THEN SPTREAD = .;
   IF (DRUGTEST >= 81) THEN DRUGTEST = .;
   IF (TESTPOS >= 81) THEN TESTPOS = .;
   IF (ICELIFE >= 81) THEN ICELIFE = .;
   IF (ICEREC >= 81) THEN ICEREC = .;
   IF (STEROPP >= 981) THEN STEROPP = .;
   IF (STERAGE >= 981) THEN STERAGE = .;
   IF (STERTOT >= 81) THEN STERTOT = .;
   IF (STERREC >= 81) THEN STERREC = .;
   IF (SPNEWA >= 981) THEN SPNEWA = .;
   IF (SPNEWB >= 981) THEN SPNEWB = .;
   IF (SPNEWC >= 981) THEN SPNEWC = .;
   IF (SPNEWD >= 981) THEN SPNEWD = .;
   IF (SPNEWE >= 981) THEN SPNEWE = .;
   IF (BOOKED >= 81) THEN BOOKED = .;
   IF (NOBOOKYR >= 81) THEN NOBOOKYR = .;
   IF (BKLARCNY >= 81) THEN BKLARCNY = .;
   IF (BKBURGL >= 81) THEN BKBURGL = .;
   IF (BKAGASLT >= 81) THEN BKAGASLT = .;
   IF (BKSMASLT >= 81) THEN BKSMASLT = .;
   IF (BKMVTHFT >= 81) THEN BKMVTHFT = .;
   IF (BKROB >= 81) THEN BKROB = .;
   IF (BKRAPE >= 81) THEN BKRAPE = .;
   IF (BKMURDER >= 81) THEN BKMURDER = .;
   IF (BKARSON >= 81) THEN BKARSON = .;
   IF (BKDRVINF >= 81) THEN BKDRVINF = .;
   IF (BKDRUNK >= 81) THEN BKDRUNK = .;
   IF (BKDRUG >= 81) THEN BKDRUG = .;
   IF (BKPROS >= 81) THEN BKPROS = .;
   IF (BKVANDAL >= 81) THEN BKVANDAL = .;
   IF (BKOTHOFF >= 81) THEN BKOTHOFF = .;
   IF (NOTBKED >= 81) THEN NOTBKED = .;
   IF (PROBATON >= 81) THEN PROBATON = .;
   IF (PAROLE >= 81) THEN PAROLE = .;
   IF (STRSTEAL >= 81) THEN STRSTEAL = .;
   IF (OTHSTEAL >= 81) THEN OTHSTEAL = .;
   IF (DAMAGE >= 81) THEN DAMAGE = .;
   IF (CARSTEAL >= 81) THEN CARSTEAL = .;
   IF (FORCEMON >= 81) THEN FORCEMON = .;
   IF (BREAKIN >= 81) THEN BREAKIN = .;
   IF (PHYFIGHT >= 81) THEN PHYFIGHT = .;
   IF (HURTBAD >= 81) THEN HURTBAD = .;
   IF (GUNMONEY >= 81) THEN GUNMONEY = .;
   IF (DRUNKDRV >= 81) THEN DRUNKDRV = .;
   IF (SOLDDRUG >= 81) THEN SOLDDRUG = .;
   IF (OTHDOING >= 81) THEN OTHDOING = .;
   IF (OTHDOSP1 >= 81) THEN OTHDOSP1 = .;
   IF (OTHDOSP2 >= 81) THEN OTHDOSP2 = .;
   IF (DEXREAD >= 81) THEN DEXREAD = .;
   IF (NOBOOZYR >= 81) THEN NOBOOZYR = .;
   IF (ALCAGGR >= 81) THEN ALCAGGR = .;
   IF (ALCARGUM >= 81) THEN ALCARGUM = .;
   IF (ALCABSNT >= 81) THEN ALCABSNT = .;
   IF (ALCHIGH >= 81) THEN ALCHIGH = .;
   IF (ALCJOB >= 81) THEN ALCJOB = .;
   IF (ALCMATCD >= 81) THEN ALCMATCD = .;
   IF (ALCRELCD >= 81) THEN ALCRELCD = .;
   IF (ALCFRDCD >= 81) THEN ALCFRDCD = .;
   IF (ALCTOSS >= 81) THEN ALCTOSS = .;
   IF (ALCHOLIC >= 81) THEN ALCHOLIC = .;
   IF (ALCDRUNK >= 81) THEN ALCDRUNK = .;
   IF (ALCINTOX >= 81) THEN ALCINTOX = .;
   IF (ALCREM >= 81) THEN ALCREM = .;
   IF (ALCQUICK >= 81) THEN ALCQUICK = .;
   IF (ALCMORN >= 81) THEN ALCMORN = .;
   IF (ALCSHOOK >= 81) THEN ALCSHOOK = .;
   IF (ALCALONE >= 81) THEN ALCALONE = .;
   IF (ALCBRKPM >= 81) THEN ALCBRKPM = .;
   IF (ALCMJ >= 81) THEN ALCMJ = .;
   IF (ALCCOC >= 81) THEN ALCCOC = .;
   IF (ALCOPT >= 81) THEN ALCOPT = .;
   IF (ALCHAL >= 81) THEN ALCHAL = .;
   IF (ALCINH >= 81) THEN ALCINH = .;
   IF (ALCANAL >= 81) THEN ALCANAL = .;
   IF (ALCTRAN >= 81) THEN ALCTRAN = .;
   IF (ALCSTM >= 81) THEN ALCSTM = .;
   IF (ALCSED >= 81) THEN ALCSED = .;
   IF (AS13NONE >= 81) THEN AS13NONE = .;
   IF (DRDEPRSS >= 81) THEN DRDEPRSS = .;
   IF (DEPDRG1A >= 981) THEN DEPDRG1A = .;
   IF (DEPDRG2A >= 981) THEN DEPDRG2A = .;
   IF (DEPDRG3A >= 981) THEN DEPDRG3A = .;
   IF (DEPDRG4A >= 981) THEN DEPDRG4A = .;
   IF (DEPDRG5A >= 981) THEN DEPDRG5A = .;
   IF (DRARGUM >= 81) THEN DRARGUM = .;
   IF (ARGDRG1A >= 981) THEN ARGDRG1A = .;
   IF (ARGDRG2A >= 981) THEN ARGDRG2A = .;
   IF (ARGDRG3A >= 981) THEN ARGDRG3A = .;
   IF (ARGDRG4A >= 981) THEN ARGDRG4A = .;
   IF (ARGDRG5A >= 981) THEN ARGDRG5A = .;
   IF (DRALONE >= 81) THEN DRALONE = .;
   IF (ALNDRG1A >= 981) THEN ALNDRG1A = .;
   IF (ALNDRG2A >= 981) THEN ALNDRG2A = .;
   IF (ALNDRG3A >= 981) THEN ALNDRG3A = .;
   IF (ALNDRG4A >= 981) THEN ALNDRG4A = .;
   IF (ALNDRG5A >= 981) THEN ALNDRG5A = .;
   IF (DRANX >= 81) THEN DRANX = .;
   IF (ANXDRG1A >= 981) THEN ANXDRG1A = .;
   IF (ANXDRG2A >= 981) THEN ANXDRG2A = .;
   IF (ANXDRG3A >= 981) THEN ANXDRG3A = .;
   IF (ANXDRG4A >= 981) THEN ANXDRG4A = .;
   IF (ANXDRG5A >= 981) THEN ANXDRG5A = .;
   IF (DRHEALTH >= 81) THEN DRHEALTH = .;
   IF (HLTDRG1A >= 981) THEN HLTDRG1A = .;
   IF (HLTDRG2A >= 981) THEN HLTDRG2A = .;
   IF (HLTDRG3A >= 981) THEN HLTDRG3A = .;
   IF (HLTDRG4A >= 981) THEN HLTDRG4A = .;
   IF (HLTDRG5A >= 981) THEN HLTDRG5A = .;
   IF (DRNTHINK >= 81) THEN DRNTHINK = .;
   IF (NTKDRG1A >= 981) THEN NTKDRG1A = .;
   IF (NTKDRG2A >= 981) THEN NTKDRG2A = .;
   IF (NTKDRG3A >= 981) THEN NTKDRG3A = .;
   IF (NTKDRG4A >= 981) THEN NTKDRG4A = .;
   IF (NTKDRG5A >= 981) THEN NTKDRG5A = .;
   IF (DRUPSET >= 81) THEN DRUPSET = .;
   IF (UPSDRG1A >= 981) THEN UPSDRG1A = .;
   IF (UPSDRG2A >= 981) THEN UPSDRG2A = .;
   IF (UPSDRG3A >= 981) THEN UPSDRG3A = .;
   IF (UPSDRG4A >= 981) THEN UPSDRG4A = .;
   IF (UPSDRG5A >= 981) THEN UPSDRG5A = .;
   IF (DRLSWORK >= 81) THEN DRLSWORK = .;
   IF (LSWDRG1A >= 981) THEN LSWDRG1A = .;
   IF (LSWDRG2A >= 981) THEN LSWDRG2A = .;
   IF (LSWDRG3A >= 981) THEN LSWDRG3A = .;
   IF (LSWDRG4A >= 981) THEN LSWDRG4A = .;
   IF (LSWDRG5A >= 981) THEN LSWDRG5A = .;
   IF (DRSUSPIC >= 81) THEN DRSUSPIC = .;
   IF (SSPDRG1A >= 981) THEN SSPDRG1A = .;
   IF (SSPDRG2A >= 981) THEN SSPDRG2A = .;
   IF (SSPDRG3A >= 981) THEN SSPDRG3A = .;
   IF (SSPDRG4A >= 981) THEN SSPDRG4A = .;
   IF (SSPDRG5A >= 981) THEN SSPDRG5A = .;
   IF (DRCOPE >= 81) THEN DRCOPE = .;
   IF (CPEDRG1A >= 981) THEN CPEDRG1A = .;
   IF (CPEDRG2A >= 981) THEN CPEDRG2A = .;
   IF (CPEDRG3A >= 981) THEN CPEDRG3A = .;
   IF (CPEDRG4A >= 981) THEN CPEDRG4A = .;
   IF (CPEDRG5A >= 981) THEN CPEDRG5A = .;
   IF (DREMGMED >= 81) THEN DREMGMED = .;
   IF (EMDRG1A >= 981) THEN EMDRG1A = .;
   IF (EMDRG2A >= 981) THEN EMDRG2A = .;
   IF (EMDRG3A >= 981) THEN EMDRG3A = .;
   IF (EMDRG4A >= 981) THEN EMDRG4A = .;
   IF (EMDRG5A >= 981) THEN EMDRG5A = .;
   IF (DRTRMT >= 81) THEN DRTRMT = .;
   IF (TMTDRG1A >= 981) THEN TMTDRG1A = .;
   IF (TMTDRG2A >= 981) THEN TMTDRG2A = .;
   IF (TMTDRG3A >= 981) THEN TMTDRG3A = .;
   IF (TMTDRG4A >= 981) THEN TMTDRG4A = .;
   IF (TMTDRG5A >= 981) THEN TMTDRG5A = .;
   IF (DRDRVUN >= 81) THEN DRDRVUN = .;
   IF (DRVDRG1A >= 981) THEN DRVDRG1A = .;
   IF (DRVDRG2A >= 981) THEN DRVDRG2A = .;
   IF (DRVDRG3A >= 981) THEN DRVDRG3A = .;
   IF (DRVDRG4A >= 981) THEN DRVDRG4A = .;
   IF (DRVDRG5A >= 981) THEN DRVDRG5A = .;
   IF (TMTREAD >= 81) THEN TMTREAD = .;
   IF (EMPDRUG >= 81) THEN EMPDRUG = .;
   IF (CIGHELP >= 81) THEN CIGHELP = .;
   IF (DRNKHELP >= 81) THEN DRNKHELP = .;
   IF (TRMTHELP >= 81) THEN TRMTHELP = .;
   IF (TRMTEMRG >= 81) THEN TRMTEMRG = .;
   IF (TRMTHOSP >= 81) THEN TRMTHOSP = .;
   IF (TRMTDOC >= 81) THEN TRMTDOC = .;
   IF (TRMTTRMT >= 81) THEN TRMTTRMT = .;
   IF (TRMTMHC >= 81) THEN TRMTMHC = .;
   IF (TRMTSHG >= 81) THEN TRMTSHG = .;
   IF (TRMTSOP >= 81) THEN TRMTSOP = .;
   IF (TRMTSP >= 81) THEN TRMTSP = .;
   IF (TRMTREC >= 81) THEN TRMTREC = .;
   IF (NRTXLIFE >= 981) THEN NRTXLIFE = .;
   IF (NOTRMT >= 81) THEN NOTRMT = .;
   IF (TXEMRG >= 81) THEN TXEMRG = .;
   IF (TXHOSP >= 81) THEN TXHOSP = .;
   IF (TXDOC >= 81) THEN TXDOC = .;
   IF (TXTRMT >= 81) THEN TXTRMT = .;
   IF (TXMHC >= 81) THEN TXMHC = .;
   IF (TXSHG >= 81) THEN TXSHG = .;
   IF (TXSOP >= 81) THEN TXSOP = .;
   IF (TXSP >= 81) THEN TXSP = .;
   IF (TRMTLIFE >= 81) THEN TRMTLIFE = .;
   IF (TRMTRESP >= 81) THEN TRMTRESP = .;
   IF (TRMTFEAR >= 81) THEN TRMTFEAR = .;
   IF (TRMTCOST >= 81) THEN TRMTCOST = .;
   IF (TRMTEVNT >= 81) THEN TRMTEVNT = .;
   IF (TRMTPR >= 81) THEN TRMTPR = .;
   IF (TRMTHLTH >= 81) THEN TRMTHLTH = .;
   IF (TRMTJOB >= 81) THEN TRMTJOB = .;
   IF (TRMTJAIL >= 81) THEN TRMTJAIL = .;
   IF (TRMTSERV >= 81) THEN TRMTSERV = .;
   IF (TRMTBQD >= 81) THEN TRMTBQD = .;
   IF (TRMTDNA >= 81) THEN TRMTDNA = .;
   IF (TRMTSOR >= 81) THEN TRMTSOR = .;
   IF (TRMTRSP >= 81) THEN TRMTRSP = .;
   IF (TRMTDRGA >= 981) THEN TRMTDRGA = .;
   IF (TRMTDRGB >= 981) THEN TRMTDRGB = .;
   IF (TRMTDRGC >= 981) THEN TRMTDRGC = .;
   IF (TRMTDRGD >= 981) THEN TRMTDRGD = .;
   IF (TRMTDRGE >= 981) THEN TRMTDRGE = .;
   IF (TRMTOUTC >= 81) THEN TRMTOUTC = .;
   IF (TMTPHI >= 81) THEN TMTPHI = .;
   IF (TMTPSAVE >= 81) THEN TMTPSAVE = .;
   IF (TMTPFMLY >= 81) THEN TMTPFMLY = .;
   IF (TMTPEMPR >= 81) THEN TMTPEMPR = .;
   IF (TMTPMEDI >= 81) THEN TMTPMEDI = .;
   IF (TMTPFREE >= 81) THEN TMTPFREE = .;
   IF (TMTPOTH >= 81) THEN TMTPOTH = .;
   IF (TMTPASP >= 81) THEN TMTPASP = .;
   IF (RSKPKCIG >= 81) THEN RSKPKCIG = .;
   IF (RSKTRYMJ >= 81) THEN RSKTRYMJ = .;
   IF (RSKMJOCC >= 81) THEN RSKMJOCC = .;
   IF (RSKMJREG >= 81) THEN RSKMJREG = .;
   IF (RKTRYPCP >= 81) THEN RKTRYPCP = .;
   IF (RKPCPREG >= 81) THEN RKPCPREG = .;
   IF (RKTRYHER >= 81) THEN RKTRYHER = .;
   IF (RKHERREG >= 81) THEN RKHERREG = .;
   IF (RKTRYCOC >= 81) THEN RKTRYCOC = .;
   IF (RKCOCOCC >= 81) THEN RKCOCOCC = .;
   IF (RKCOCREG >= 81) THEN RKCOCREG = .;
   IF (RKCRKOCC >= 81) THEN RKCRKOCC = .;
   IF (RKANSOCC >= 81) THEN RKANSOCC = .;
   IF (RKANSREG >= 81) THEN RKANSREG = .;
   IF (RK2DRINK >= 81) THEN RK2DRINK = .;
   IF (RK5DRINK >= 81) THEN RK5DRINK = .;
   IF (RSKBINGE >= 81) THEN RSKBINGE = .;
   IF (RSKDIFMJ >= 81) THEN RSKDIFMJ = .;
   IF (RKDIFLSD >= 81) THEN RKDIFLSD = .;
   IF (RKDIFPCP >= 81) THEN RKDIFPCP = .;
   IF (RKDIFCOC >= 81) THEN RKDIFCOC = .;
   IF (RKDIFHER >= 81) THEN RKDIFHER = .;
   IF (RSKSELL >= 81) THEN RSKSELL = .;
   IF (RKNEIDRN >= 81) THEN RKNEIDRN = .;
   IF (RKNEISEL >= 81) THEN RKNEISEL = .;
   IF (HIGHBP >= 81) THEN HIGHBP = .;
   IF (BPMED >= 81) THEN BPMED = .;
   IF (WALKPAIN >= 81) THEN WALKPAIN = .;
   IF (TIMEPAIN >= 81) THEN TIMEPAIN = .;
   IF (UPSHOR >= 81) THEN UPSHOR = .;
   IF (ASTHMA >= 81) THEN ASTHMA = .;
   IF (TRPSYCH >= 81) THEN TRPSYCH = .;
   IF (HEART >= 81) THEN HEART = .;
   IF (FLU >= 81) THEN FLU = .;
   IF (ALLERG >= 94) THEN ALLERG = .;
   IF (HOSPYR >= 81) THEN HOSPYR = .;
   IF (SOREYR >= 81) THEN SOREYR = .;
   IF (RUNNYYR >= 81) THEN RUNNYYR = .;
   IF (COUGHYR >= 81) THEN COUGHYR = .;
   IF (PHLEGMYR >= 81) THEN PHLEGMYR = .;
   IF (HEALTHYR >= 81) THEN HEALTHYR = .;
   IF (FLTEAT >= 81) THEN FLTEAT = .;
   IF (FLTMIND >= 81) THEN FLTMIND = .;
   IF (FLTDEPRS >= 81) THEN FLTDEPRS = .;
   IF (FLTEFFRT >= 81) THEN FLTEFFRT = .;
   IF (FLTSLEEP >= 81) THEN FLTSLEEP = .;
   IF (FLTSAD >= 81) THEN FLTSAD = .;
   IF (FLTGOING >= 81) THEN FLTGOING = .;
   IF (MARITAL >= 81) THEN MARITAL = .;
   IF (NOMARR >= 81) THEN NOMARR = .;
   IF (WORKSTAT >= 81) THEN WORKSTAT = .;
   IF (PAYMO >= 89) THEN PAYMO = .;
   IF (PAYYR >= 981) THEN PAYYR = .;
   IF (NO5JOB >= 94) THEN NO5JOB = .;
   IF (WORKDAYS >= 81) THEN WORKDAYS = .;
   IF (WORKBLAH >= 81) THEN WORKBLAH = .;
   IF (CWE >= 81) THEN CWE = .;
   IF (CWESC1 >= 981) THEN CWESC1 = .;
   IF (CWESC2 >= 981) THEN CWESC2 = .;
   IF (FULLPART >= 81) THEN FULLPART = .;
   IF (EDUC >= 81) THEN EDUC = .;
   IF (GRADHS >= 81) THEN GRADHS = .;
   IF (DIPLOMA >= 81) THEN DIPLOMA = .;
   IF (ENROLLD >= 81) THEN ENROLLD = .;
   IF (SCHPLANS >= 81) THEN SCHPLANS = .;
   IF (STUDENT >= 81) THEN STUDENT = .;
   IF (SCHDAYS >= 81) THEN SCHDAYS = .;
   IF (SKIPPED >= 81) THEN SKIPPED = .;
   IF (MILES >= 99981) THEN MILES = .;
   IF (ACCID >= 81) THEN ACCID = .;
   IF (TOTPEOP >= 81) THEN TOTPEOP = .;
   IF (MOTHER >= 81) THEN MOTHER = .;
   IF (FATHER >= 81) THEN FATHER = .;
   IF (STEPMOM >= 81) THEN STEPMOM = .;
   IF (STEPDAD >= 81) THEN STEPDAD = .;
   IF (SPOUSE >= 81) THEN SPOUSE = .;
   IF (INLAW >= 81) THEN INLAW = .;
   IF (OWNCHILD >= 81) THEN OWNCHILD = .;
   IF (STEPCHLD >= 81) THEN STEPCHLD = .;
   IF (BROSIS >= 81) THEN BROSIS = .;
   IF (OTHREL >= 81) THEN OTHREL = .;
   IF (FRIENDS >= 81) THEN FRIENDS = .;
   IF (OTHERNON >= 81) THEN OTHERNON = .;
   IF (MOVDAWAY >= 81) THEN MOVDAWAY = .;
   IF (DORM >= 81) THEN DORM = .;
   IF (MILBASE >= 81) THEN MILBASE = .;
   IF (HOSP >= 81) THEN HOSP = .;
   IF (OTHGPH >= 81) THEN OTHGPH = .;
   IF (OTHGPHSP >= 81) THEN OTHGPHSP = .;
   IF (SERVICE >= 81) THEN SERVICE = .;
   IF (MILSTAT >= 81) THEN MILSTAT = .;
   IF (TELNO >= 81) THEN TELNO = .;
   IF (MOVES >= 81) THEN MOVES = .;
   IF (PROXABLE >= 81) THEN PROXABLE = .;
   IF (PROXYREL >= 981) THEN PROXYREL = .;
   IF (PROXHOME >= 81) THEN PROXHOME = .;
   IF (PROXJOIN >= 81) THEN PROXJOIN = .;
   IF (MEDICARE >= 81) THEN MEDICARE = .;
   IF (MEDICAID >= 81) THEN MEDICAID = .;
   IF (CHAMPUS >= 81) THEN CHAMPUS = .;
   IF (PRVHLTIN >= 81) THEN PRVHLTIN = .;
   IF (OWNHLTIN >= 81) THEN OWNHLTIN = .;
   IF (GRPHLTIN >= 81) THEN GRPHLTIN = .;
   IF (HLTINALC >= 81) THEN HLTINALC = .;
   IF (HLTINDRG >= 81) THEN HLTINDRG = .;
   IF (HLTINMNT >= 81) THEN HLTINMNT = .;
   IF (WHOANSHI >= 981) THEN WHOANSHI = .;
   IF (JOB >= 81) THEN JOB = .;
   IF (HOURS >= 981) THEN HOURS = .;
   IF (WORK >= 81) THEN WORK = .;
   IF (WAG1 >= 81) THEN WAG1 = .;
   IF (AWAG1 >= 999981) THEN AWAG1 = .;
   IF (WEEKS >= 81) THEN WEEKS = .;
   IF (SOC1 >= 81) THEN SOC1 = .;
   IF (ASOC1 >= 999981) THEN ASOC1 = .;
   IF (SSI1 >= 81) THEN SSI1 = .;
   IF (ASSI1 >= 999981) THEN ASSI1 = .;
   IF (PUB1 >= 81) THEN PUB1 = .;
   IF (AFDC1 >= 81) THEN AFDC1 = .;
   IF (WEL1 >= 81) THEN WEL1 = .;
   IF (AWEL1 >= 999981) THEN AWEL1 = .;
   IF (INT1 >= 81) THEN INT1 = .;
   IF (AINT1 >= 999981) THEN AINT1 = .;
   IF (CHD1 >= 81) THEN CHD1 = .;
   IF (ACHD1 >= 999981) THEN ACHD1 = .;
   IF (OTH1 >= 81) THEN OTH1 = .;
   IF (AOTH1 >= 999981) THEN AOTH1 = .;
   IF (FAMLYRES >= 81) THEN FAMLYRES = .;
   IF (WAG2 >= 81) THEN WAG2 = .;
   IF (AWAG2 >= 999981) THEN AWAG2 = .;
   IF (SOC2 >= 81) THEN SOC2 = .;
   IF (ASOC2 >= 999981) THEN ASOC2 = .;
   IF (SSI2 >= 81) THEN SSI2 = .;
   IF (ASSI2 >= 999981) THEN ASSI2 = .;
   IF (PUB2 >= 81) THEN PUB2 = .;
   IF (AFDC2 >= 81) THEN AFDC2 = .;
   IF (WEL2 >= 81) THEN WEL2 = .;
   IF (AWEL2 >= 999981) THEN AWEL2 = .;
   IF (INT2 >= 81) THEN INT2 = .;
   IF (AINT2 >= 999981) THEN AINT2 = .;
   IF (CHD2 >= 81) THEN CHD2 = .;
   IF (ACHD2 >= 999981) THEN ACHD2 = .;
   IF (OTH2 >= 81) THEN OTH2 = .;
   IF (AOTH2 >= 999981) THEN AOTH2 = .;
   IF (WHOANSIN >= 981) THEN WHOANSIN = .;
   IF (FSTAMP >= 81) THEN FSTAMP = .;
   IF (PEOPFD >= 81) THEN PEOPFD = .;
   IF (FOOD >= 81) THEN FOOD = .;
   IF (AFOOD >= 999981) THEN AFOOD = .;
   IF (BHOUR >= 81) THEN BHOUR = .;
   IF (BMIN >= 81) THEN BMIN = .;
   IF (BAP >= 81) THEN BAP = .;
   IF (EAP >= 81) THEN EAP = .;
   IF (LANGVER >= 81) THEN LANGVER = .;
   IF (UNDINT >= 81) THEN UNDINT = .;
   IF (COOPINT >= 81) THEN COOPINT = .;
   IF (PRIVACY >= 81) THEN PRIVACY = .;
   IF (PPRES >= 81) THEN PPRES = .;
   IF (SPRES >= 81) THEN SPRES = .;
   IF (PARPRES >= 81) THEN PARPRES = .;
   IF (OARPRES >= 81) THEN OARPRES = .;
   IF (OAPRES >= 81) THEN OAPRES = .;
   IF (CPRES >= 81) THEN CPRES = .;
   IF (OPRESNSP >= 81) THEN OPRESNSP = .;
   IF (OPRESSPA >= 981) THEN OPRESSPA = .;
   IF (OPRESSPB >= 981) THEN OPRESSPB = .;
   IF (WHOMARKD >= 81) THEN WHOMARKD = .;
   IF (FAMSKIP >= 81) THEN FAMSKIP = .;
   IF (GQTYPE = 9) THEN GQTYPE = .;
   IF (DC >= 9) THEN DC = .;
   IF (CHICAGO >= 9) THEN CHICAGO = .;
   IF (DENVER >= 9) THEN DENVER = .;
   IF (LA >= 9) THEN LA = .;
   IF (MIAMI >= 9) THEN MIAMI = .;
   IF (NEWYORK >= 9) THEN NEWYORK = .;
   IF (URBARE >= 9) THEN URBARE = .;
   IF (METRO >= 9) THEN METRO = .;
   IF (IRHOGRP >= 81) THEN IRHOGRP = .;
   IF (IIHOGRP >= 9) THEN IIHOGRP = .;
   IF (IRHOGRP2 >= 81) THEN IRHOGRP2 = .;
   IF (IIHOGRP2 >= 9) THEN IIHOGRP2 = .;
   IF (IRMARIT >= 81) THEN IRMARIT = .;
   IF (IIMARIT >= 9) THEN IIMARIT = .;
   IF (IRWORKST >= 81) THEN IRWORKST = .;
   IF (IIAWAG1 >= 9) THEN IIAWAG1 = .;
   IF (IIASOC1 >= 9) THEN IIASOC1 = .;
   IF (IIASSI1 >= 9) THEN IIASSI1 = .;
   IF (IIAWEL1 >= 9) THEN IIAWEL1 = .;
   IF (IIAINT1 >= 9) THEN IIAINT1 = .;
   IF (IIACHD1 >= 9) THEN IIACHD1 = .;
   IF (IIAOTH1 >= 9) THEN IIAOTH1 = .;
   IF (IIWAG2 >= 9) THEN IIWAG2 = .;
   IF (IIAWAG2 >= 9) THEN IIAWAG2 = .;
   IF (IISOC2 >= 9) THEN IISOC2 = .;
   IF (IIASOC2 >= 9) THEN IIASOC2 = .;
   IF (IISSI2 >= 9) THEN IISSI2 = .;
   IF (IIASSI2 >= 9) THEN IIASSI2 = .;
   IF (IIWEL2 >= 9) THEN IIWEL2 = .;
   IF (IIAWEL2 >= 9) THEN IIAWEL2 = .;
   IF (IIINT2 >= 9) THEN IIINT2 = .;
   IF (IIAINT2 >= 9) THEN IIAINT2 = .;
   IF (IICHD2 >= 9) THEN IICHD2 = .;
   IF (IIACHD2 >= 9) THEN IIACHD2 = .;
   IF (IIOTH2 >= 9) THEN IIOTH2 = .;
   IF (IIAOTH2 >= 9) THEN IIAOTH2 = .;
   IF (IIAFOOD >= 9) THEN IIAFOOD = .;
   IF (IRPEOP >= 81) THEN IRPEOP = .;
   IF (IRALCRC >= 9) THEN IRALCRC = .;
   IF (IRMJRC >= 9) THEN IRMJRC = .;
   IF (IRCOCRC >= 9) THEN IRCOCRC = .;
   IF (IRSEDRC >= 9) THEN IRSEDRC = .;
   IF (IRTRNRC >= 9) THEN IRTRNRC = .;
   IF (IRSTMRC >= 9) THEN IRSTMRC = .;
   IF (IRANLRC >= 9) THEN IRANLRC = .;
   IF (IRCIGRC >= 9) THEN IRCIGRC = .;
   IF (IROTBRC >= 9) THEN IROTBRC = .;
   IF (IRINHRC >= 9) THEN IRINHRC = .;
   IF (IRCRKRC >= 9) THEN IRCRKRC = .;
   IF (IRHALRC >= 9) THEN IRHALRC = .;
   IF (IRHERRC >= 9) THEN IRHERRC = .;
   IF (IRPCPRC >= 9) THEN IRPCPRC = .;
   IF (IRICERC >= 9) THEN IRICERC = .;
   IF (IRSTRRC >= 9) THEN IRSTRRC = .;
   IF (IRALCFQ >= 9) THEN IRALCFQ = .;
   IF (IRMJFQ >= 9) THEN IRMJFQ = .;
   IF (IRCOCFQ >= 9) THEN IRCOCFQ = .;
   IF (IRSEDFQ >= 9) THEN IRSEDFQ = .;
   IF (IRTRNFQ >= 9) THEN IRTRNFQ = .;
   IF (IRSTMFQ >= 9) THEN IRSTMFQ = .;
   IF (IRANLFQ >= 9) THEN IRANLFQ = .;
   IF (IROTBFQ >= 9) THEN IROTBFQ = .;
   IF (IRINHFQ >= 9) THEN IRINHFQ = .;
   IF (IRHALFQ >= 9) THEN IRHALFQ = .;
   IF (INDCAT >= 81) THEN INDCAT = .;
   IF (TOTCAT >= 81) THEN TOTCAT = .;
   IF (NEEDLREC >= 81) THEN NEEDLREC = .;
   IF (NDL90REC >= 81) THEN NDL90REC = .;
   IF (QC06 >= 81) THEN QC06 = .;
   IF (QC09 >= 81) THEN QC09 = .;
   IF (AL02 >= 81) THEN AL02 = .;
   IF (SE04 >= 81) THEN SE04 = .;
   IF (TR04 >= 81) THEN TR04 = .;
   IF (ST04 >= 81) THEN ST04 = .;
   IF (ST07 >= 81) THEN ST07 = .;
   IF (AN04 >= 81) THEN AN04 = .;
   IF (MJ04 >= 81) THEN MJ04 = .;
   IF (IN04 >= 81) THEN IN04 = .;
   IF (CC04 >= 81) THEN CC04 = .;
   IF (CC11 >= 81) THEN CC11 = .;
   IF (CK01 >= 81) THEN CK01 = .;
   IF (LS05 >= 81) THEN LS05 = .;
   IF (LS08 >= 81) THEN LS08 = .;
   IF (HE04 >= 81) THEN HE04 = .;
   IF (HE07 >= 81) THEN HE07 = .;
   IF (ND02 >= 81) THEN ND02 = .;
   IF (SP04 >= 81) THEN SP04 = .;
   IF (SP08 >= 81) THEN SP08 = .;
   IF (IRCDCIG >= 81) THEN IRCDCIG = .;
   IF (IRCDMJ >= 81) THEN IRCDMJ = .;
   IF (IREFCIG >= 81) THEN IREFCIG = .;
   IF (IREFALC >= 81) THEN IREFALC = .;
   IF (IREFMJ >= 81) THEN IREFMJ = .;
   IF (IREFCOC >= 81) THEN IREFCOC = .;
   IF (IRUDCIG >= 81) THEN IRUDCIG = .;
   IF (IRUDALC >= 81) THEN IRUDALC = .;
   IF (IRUDMJ >= 81) THEN IRUDMJ = .;
   IF (IRUDCOC >= 81) THEN IRUDCOC = .;
   IF (IRDPCIG >= 81) THEN IRDPCIG = .;
   IF (IRDPALC >= 81) THEN IRDPALC = .;
   IF (IRDPMJ >= 81) THEN IRDPMJ = .;
   IF (IRDPCOC >= 81) THEN IRDPCOC = .;
   IF (IRWSCIG >= 81) THEN IRWSCIG = .;
   IF (IRWSALC >= 81) THEN IRWSALC = .;
   IF (IRWSMJ >= 81) THEN IRWSMJ = .;
   IF (IRWSCOC >= 81) THEN IRWSCOC = .;
   IF (IRALCAGG >= 81) THEN IRALCAGG = .;
   IF (IRALCARG >= 81) THEN IRALCARG = .;
   IF (IRALCABS >= 81) THEN IRALCABS = .;
   IF (IRALCHIG >= 81) THEN IRALCHIG = .;
   IF (IRALCJOB >= 81) THEN IRALCJOB = .;
   IF (IRALCMAT >= 81) THEN IRALCMAT = .;
   IF (IRALCREL >= 81) THEN IRALCREL = .;
   IF (IRALCFRD >= 81) THEN IRALCFRD = .;
   IF (IRALCTOS >= 81) THEN IRALCTOS = .;
   IF (IRALCHOL >= 81) THEN IRALCHOL = .;
   IF (IRALCDRU >= 81) THEN IRALCDRU = .;
   IF (IRALCINT >= 81) THEN IRALCINT = .;
   IF (IRALCREM >= 81) THEN IRALCREM = .;
   IF (IRALCQUI >= 81) THEN IRALCQUI = .;
   IF (IRALCMOR >= 81) THEN IRALCMOR = .;
   IF (IRALCSHO >= 81) THEN IRALCSHO = .;
   IF (IRALCALO >= 81) THEN IRALCALO = .;
   IF (IRALCBRK >= 81) THEN IRALCBRK = .;
   IF (IRDEP >= 81) THEN IRDEP = .;
   IF (IRARG >= 81) THEN IRARG = .;
   IF (IRALN >= 81) THEN IRALN = .;
   IF (IRANX >= 81) THEN IRANX = .;
   IF (IRHLT >= 81) THEN IRHLT = .;
   IF (IRNTK >= 81) THEN IRNTK = .;
   IF (IRUPS >= 81) THEN IRUPS = .;
   IF (IRLSW >= 81) THEN IRLSW = .;
   IF (IRSSP >= 81) THEN IRSSP = .;
   IF (IRCPE >= 81) THEN IRCPE = .;
   IF (IREMG >= 81) THEN IREMG = .;
   IF (IRDEP1 >= 981) THEN IRDEP1 = .;
   IF (IRDEP2 >= 981) THEN IRDEP2 = .;
   IF (IRDEP3 >= 981) THEN IRDEP3 = .;
   IF (IRDEP4 >= 981) THEN IRDEP4 = .;
   IF (IRDEP5 >= 981) THEN IRDEP5 = .;
   IF (IRARG1 >= 981) THEN IRARG1 = .;
   IF (IRARG2 >= 981) THEN IRARG2 = .;
   IF (IRARG3 >= 981) THEN IRARG3 = .;
   IF (IRARG4 >= 981) THEN IRARG4 = .;
   IF (IRARG5 >= 981) THEN IRARG5 = .;
   IF (IRALN1 >= 981) THEN IRALN1 = .;
   IF (IRALN2 >= 981) THEN IRALN2 = .;
   IF (IRALN3 >= 981) THEN IRALN3 = .;
   IF (IRALN4 >= 981) THEN IRALN4 = .;
   IF (IRALN5 >= 981) THEN IRALN5 = .;
   IF (IRANX1 >= 981) THEN IRANX1 = .;
   IF (IRANX2 >= 981) THEN IRANX2 = .;
   IF (IRANX3 >= 981) THEN IRANX3 = .;
   IF (IRANX4 >= 981) THEN IRANX4 = .;
   IF (IRANX5 >= 981) THEN IRANX5 = .;
   IF (IRHLT1 >= 981) THEN IRHLT1 = .;
   IF (IRHLT2 >= 981) THEN IRHLT2 = .;
   IF (IRHLT3 >= 981) THEN IRHLT3 = .;
   IF (IRHLT4 >= 981) THEN IRHLT4 = .;
   IF (IRHLT5 >= 981) THEN IRHLT5 = .;
   IF (IRNTK1 >= 981) THEN IRNTK1 = .;
   IF (IRNTK2 >= 981) THEN IRNTK2 = .;
   IF (IRNTK3 >= 981) THEN IRNTK3 = .;
   IF (IRNTK4 >= 981) THEN IRNTK4 = .;
   IF (IRNTK5 >= 981) THEN IRNTK5 = .;
   IF (IRUPS1 >= 981) THEN IRUPS1 = .;
   IF (IRUPS2 >= 981) THEN IRUPS2 = .;
   IF (IRUPS3 >= 981) THEN IRUPS3 = .;
   IF (IRUPS4 >= 981) THEN IRUPS4 = .;
   IF (IRUPS5 >= 981) THEN IRUPS5 = .;
   IF (IRLSW1 >= 981) THEN IRLSW1 = .;
   IF (IRLSW2 >= 981) THEN IRLSW2 = .;
   IF (IRLSW3 >= 981) THEN IRLSW3 = .;
   IF (IRLSW4 >= 981) THEN IRLSW4 = .;
   IF (IRLSW5 >= 981) THEN IRLSW5 = .;
   IF (IRSSP1 >= 981) THEN IRSSP1 = .;
   IF (IRSSP2 >= 981) THEN IRSSP2 = .;
   IF (IRSSP3 >= 981) THEN IRSSP3 = .;
   IF (IRSSP4 >= 981) THEN IRSSP4 = .;
   IF (IRSSP5 >= 981) THEN IRSSP5 = .;
   IF (IRCPE1 >= 981) THEN IRCPE1 = .;
   IF (IRCPE2 >= 981) THEN IRCPE2 = .;
   IF (IRCPE3 >= 981) THEN IRCPE3 = .;
   IF (IRCPE4 >= 981) THEN IRCPE4 = .;
   IF (IRCPE5 >= 981) THEN IRCPE5 = .;
   IF (IREMG1 >= 981) THEN IREMG1 = .;
   IF (IREMG2 >= 981) THEN IREMG2 = .;
   IF (IREMG3 >= 981) THEN IREMG3 = .;
   IF (IREMG4 >= 981) THEN IREMG4 = .;
   IF (IREMG5 >= 981) THEN IREMG5 = .;
   IF (DEPCIG2 >= 81) THEN DEPCIG2 = .;
   IF (DEPALC2 >= 81) THEN DEPALC2 = .;
   IF (DEPMRJ2 >= 81) THEN DEPMRJ2 = .;
   IF (DEPCOC2 >= 81) THEN DEPCOC2 = .;
   IF (ARGCIG2 >= 81) THEN ARGCIG2 = .;
   IF (ARGALC2 >= 81) THEN ARGALC2 = .;
   IF (ARGMRJ2 >= 81) THEN ARGMRJ2 = .;
   IF (ARGCOC2 >= 81) THEN ARGCOC2 = .;
   IF (ALNCIG2 >= 81) THEN ALNCIG2 = .;
   IF (ALNALC2 >= 81) THEN ALNALC2 = .;
   IF (ALNMRJ2 >= 81) THEN ALNMRJ2 = .;
   IF (ALNCOC2 >= 81) THEN ALNCOC2 = .;
   IF (ANXCIG2 >= 81) THEN ANXCIG2 = .;
   IF (ANXALC2 >= 81) THEN ANXALC2 = .;
   IF (ANXMRJ2 >= 81) THEN ANXMRJ2 = .;
   IF (ANXCOC2 >= 81) THEN ANXCOC2 = .;
   IF (HLTCIG2 >= 81) THEN HLTCIG2 = .;
   IF (HLTALC2 >= 81) THEN HLTALC2 = .;
   IF (HLTMRJ2 >= 81) THEN HLTMRJ2 = .;
   IF (HLTCOC2 >= 81) THEN HLTCOC2 = .;
   IF (NTKCIG2 >= 81) THEN NTKCIG2 = .;
   IF (NTKALC2 >= 81) THEN NTKALC2 = .;
   IF (NTKMRJ2 >= 81) THEN NTKMRJ2 = .;
   IF (NTKCOC2 >= 81) THEN NTKCOC2 = .;
   IF (UPSCIG2 >= 81) THEN UPSCIG2 = .;
   IF (UPSALC2 >= 81) THEN UPSALC2 = .;
   IF (UPSMRJ2 >= 81) THEN UPSMRJ2 = .;
   IF (UPSCOC2 >= 81) THEN UPSCOC2 = .;
   IF (LSWCIG2 >= 81) THEN LSWCIG2 = .;
   IF (LSWALC2 >= 81) THEN LSWALC2 = .;
   IF (LSWMRJ2 >= 81) THEN LSWMRJ2 = .;
   IF (LSWCOC2 >= 81) THEN LSWCOC2 = .;
   IF (SSPCIG2 >= 81) THEN SSPCIG2 = .;
   IF (SSPALC2 >= 81) THEN SSPALC2 = .;
   IF (SSPMRJ2 >= 81) THEN SSPMRJ2 = .;
   IF (SSPCOC2 >= 81) THEN SSPCOC2 = .;
   IF (CPECIG2 >= 81) THEN CPECIG2 = .;
   IF (CPEALC2 >= 81) THEN CPEALC2 = .;
   IF (CPEMRJ2 >= 81) THEN CPEMRJ2 = .;
   IF (CPECOC2 >= 81) THEN CPECOC2 = .;
   IF (EMCIG2 >= 81) THEN EMCIG2 = .;
   IF (EMALC2 >= 81) THEN EMALC2 = .;
   IF (EMMRJ2 >= 81) THEN EMMRJ2 = .;
   IF (EMCOC2 >= 81) THEN EMCOC2 = .;
   IF (PRB1CIG >= 81) THEN PRB1CIG = .;
   IF (PRB1ALC >= 81) THEN PRB1ALC = .;
   IF (PRB1MRJ >= 81) THEN PRB1MRJ = .;
   IF (PRB1COC >= 81) THEN PRB1COC = .;
   IF (PRB2CIG >= 81) THEN PRB2CIG = .;
   IF (PRB2ALC >= 81) THEN PRB2ALC = .;
   IF (PRB2MRJ >= 81) THEN PRB2MRJ = .;
   IF (PRB2COC >= 81) THEN PRB2COC = .;
   IF (PRB3CIG >= 81) THEN PRB3CIG = .;
   IF (PRB3ALC >= 81) THEN PRB3ALC = .;
   IF (PRB3MRJ >= 81) THEN PRB3MRJ = .;
   IF (PRB3COC >= 81) THEN PRB3COC = .;
   IF (CHANCMJ2 >= 81) THEN CHANCMJ2 = .;
   IF (CHANCOC2 >= 81) THEN CHANCOC2 = .;
   IF (CHANHAL2 >= 81) THEN CHANHAL2 = .;
   IF (CHANHER2 >= 81) THEN CHANHER2 = .;
   IF (CWEOCC2 >= 981) THEN CWEOCC2 = .;
   IF (ROCCUP2 >= 981) THEN ROCCUP2 = .;
   IF (CWEBUS2 >= 981) THEN CWEBUS2 = .;
   IF (BUSINES2 >= 981) THEN BUSINES2 = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT CIGTRY cigtry. CIG5PK cig5pk. CIGAGE cigage.
         CIGYRS cigyrs. PACKS packs. CIGREC cigrec.
         AVCIG avcig. CIGTIME cigtime. SNUFREC snufrec.
         OTHTOB othtob. ALCTRY alctry. ALCREC alcrec.
         ALCAGE alcage. ALCDAYS alcdays. NODR30A nodr30a.
         DR5DAY dr5day. MODR30A modr30a. MODR30DY modr30dy.
         ALCPAT alcpat. DRUNKYR drunkyr. ALCBEER alcbeer.
         ALCWINE alcwine. ALCLIQR alcliqr. ALCVARY alcvary.
         NOSEDAT nosedat. BUTISOL butisol. BUTICAPS buticaps.
         AMYTAL amytal. MEBARAL mebaral. PLACIDYL placidyl.
         DORIDEN doriden. NOLUDAR noludar. NEMBUTAL nembutal.
         SECONAL seconal. TUINAL tuinal. DALMANE dalmane.
         RESTORIL restoril. HALCION halcion. AMOBARB amobarb.
         PHENOBAR phenobar. METHAQ methaq. CHHYD chhyd.
         PENTOB pentob. SECOB secob. SEDNEWA sednewa.
         SEDNEWB sednewb. SEDNEWC sednewc. SEDNEWD sednewd.
         SEDNEWE sednewe. SEDNOSP sednosp. SEDDKNAM seddknam.
         SEDAGE sedage. SEDTOT sedtot. SEDREC sedrec.
         SEDYRFRQ sedyrfrq. TRNREAD trnread. NOTRANQ notranq.
         VALIUM valium. LIBRIUM librium. LIMBTROL limbtrol.
         MENRIUM menrium. SERAX serax. TRANXENE tranxene.
         ATIVAN ativan. CENTRAX centrax. XANAX xanax.
         PAXIPAM paxipam. BUSPAR buspar. MILTOWN miltown.
         EQUANIL equanil. DEPROL deprol. VISTAR vistar.
         ATARAX atarax. DURRAX durrax. DIAZEPAM diazepam.
         SKLY skly. MEPROB meprob. TRNEWA trnewa.
         TRNEWB trnewb. TRNEWC trnewc. TRNEWD trnewd.
         TRNEWE trnewe. TRNOSP trnosp. TRDKNAM trdknam.
         TRANAGE tranage. TRANTOT trantot. TRANREC tranrec.
         TRNYRFRQ trnyrfrq. STMREAD stmread. NOSTIMS nostims.
         DEXED dexed. DEXAMYL dexamyl. ESKAT eskat.
         BENZ benz. BIPHET biphet. DESOXYN desoxyn.
         TENUATE tenuate. TEPANIL tepanil. DIDREX didrex.
         PLEGINE plegine. PRELUDIN preludin. IONAMIN ionamin.
         FASTIN fastin. PONDIMIN pondimin. VORANIL voranil.
         SANOREX sanorex. MAZANOR mazanor. RITALIN ritalin.
         CYLERT cylert. DETAMP detamp. METHI methi.
         METHAMP methamp. OBLA obla. STIMNEWA stimnewa.
         STIMNEWB stimnewb. STIMNEWC stimnewc. STIMNEWD stimnewd.
         STIMNEWE stimnewe. STIMNOSP stimnosp. STMDKNAM stmdknam.
         STIMAGE stimage. STIMTOT stimtot. STIMREC stimrec.
         STMYRFRQ stmyrfrq. STNEEDLE stneedle. STNDLREC stndlrec.
         ANLREAD anlread. ANALNONE analnone. DARVON darvon.
         DOLENE dolene. SK65A sk65a. WYGESIC wygesic.
         LEVODRO levodro. PERCODAN percodan. DEMEROL demerol.
         DILAUD dilaud. TYLCOD tylcod. PHENCOD phencod.
         TALWIN talwin. TALWINNX talwinnx. TALACEN talacen.
         PROPOXY propoxy. CODEINE codeine. ANILERID anilerid.
         MORPHINE morphine. METHDON methdon. STADOL stadol.
         ANALNEWA analnewa. ANALNEWB analnewb. ANALNEWC analnewc.
         ANALNEWD analnewd. ANALNEWE analnewe. ANLNOSP anlnosp.
         ANLDKNAM anldknam. ANALAGE analage. ANALTOT analtot.
         ANALREC analrec. ANLYRFRQ anlyrfrq. MJOPP mjopp.
         MJAGE mjage. MJTOT mjtot. MJREC mjrec.
         MJDAY30A mjday30a. MJAV30A mjav30a. MJAV30B mjav30b.
         MJAMT30A mjamt30a. MJFRIEND mjfriend. MJDEALER mjdealer.
         MJOTHSHR mjothshr. MJGIVEN mjgiven. MJTRGOOD mjtrgood.
         MJTRSERV mjtrserv. MJSTOLE mjstole. MJTRICK mjtrick.
         MJGREW mjgrew. MJOBTNON mjobtnon. MJBUCK mjbuck.
         MJYRFREQ mjyrfreq. MJJOINT mjjoint. MJPIPE mjpipe.
         MJBAKE mjbake. MJCHEW mjchew. MJWAY mjway.
         MJLFDALY mjlfdaly. INHREAD inhread. GAS gas.
         LGAS lgas. SPPAINT sppaint. AEROS aeros.
         GLUE glue. SOLVENT solvent. AMYLNIT amylnit.
         ETHER ether. NITOXID nitoxid. CLEFLU cleflu.
         INHNEWA inhnewa. INHNEWB inhnewb. INHNEWC inhnewc.
         INHNEWD inhnewd. INHNEWE inhnewe. INHNOSP inhnosp.
         INHDKNAM inhdknam. INHAGE inhage. INHTOT inhtot.
         INHREC inhrec. GAS30A gas30a. LGAS30A lgas30a.
         SPPAN30A sppan30a. AEROS30A aeros30a. GLUE30A glue30a.
         SOLVN30A solvn30a. AMLNT30A amlnt30a. ETHER30A ether30a.
         NOX30A nox30a. CLFL30A clfl30a. INNEW30A innew30a.
         INNEW30B innew30b. INNEW30C innew30c. INNEW30D innew30d.
         INNEW30E innew30e. IN30NOSP in30nosp. INH30NO inh30no.
         INHDY30A inhdy30a. INHYRFRQ inhyrfrq. INHPO inhpo.
         INHQNC1 inhqnc1f. INHQNC2 inhqnc2f. INHQNC3 inhqnc3f.
         INHQNC4 inhqnc4f. INHQNC5 inhqnc5f. INHQNC6 inhqnc6f.
         INHQNC7 inhqnc7f. INHQNC8 inhqnc8f. INHQNC10 inhqnc0f.
         INHANSY inhansy. COCOPP cocopp. COCAGE cocage.
         COCTOT coctot. COCREC cocrec. COCUS30A cocus30a.
         COCAM30A cocam30a. CCFRIEND ccfriend. CCDEALER ccdealer.
         CCOTHSHR ccothshr. CCGIVEN ccgiven. CCTRGOOD cctrgood.
         CCTRSERV cctrserv. CCSTOLE ccstole. CCTRICK cctrick.
         CCOBTNON ccobtnon. COCBUCK cocbuck. COCYRFRQ cocyrfrq.
         COCSNIFF cocsniff. COCSWAL cocswal. COCIV cociv.
         FREEBASE freebase. COCWAY cocway. CONDLREC condlrec.
         CCLFDALY cclfdaly. CRAKREC crakrec. CRKAM30A crkam30a.
         CKFRIEND ckfriend. CKDEALER ckdealer. CKOTHSHR ckothshr.
         CKGIVEN ckgiven. CKTRGOOD cktrgood. CKTRSERV cktrserv.
         CKSTOLE ckstole. CKTRICK cktrick. CKOBTNON ckobtnon.
         CRAKBUCK crakbuck. CKLFDALY cklfdaly. HALREAD halread.
         LSD lsd. PEYOTE peyote. MESC mesc.
         PSILCY psilcy. PCP pcp. ECSTASY ecstasy.
         HALNEWA halnewa. HALNEWB halnewb. HALNEWC halnewc.
         HALNEWD halnewd. HALNEWE halnewe. HALNOSP halnosp.
         HALDKNAM haldknam. HALLOPP hallopp. HALLAGE hallage.
         HALLTOT halltot. HALLREC hallrec. HAL30USE hal30use.
         HALYRFRQ halyrfrq. PCPREC pcprec. HERREAD herread.
         HEROPP heropp. HERAGE herage. HERTOT hertot.
         HERREC herrec. HER30USE her30use. HERNEEDL herneedl.
         HRNDLREC hrndlrec. HERSMOKE hersmoke. HRSMKREC hrsmkrec.
         HERSNIFF hersniff. HRSNFREC hrsnfrec. DRGREAD drgread.
         CDCIG cdcig. CDALC cdalc. CDSED cdsed.
         CDTRAN cdtran. CDSTM cdstm. CDANAL cdanal.
         CDMJ cdmj. CDINH cdinh. CDCOC cdcoc.
         CDHALL cdhall. CDHER cdher. CDOTHOP cdothop.
         CDNONE cdnone. UCDCIG ucdcig. UCDALC ucdalc.
         UCDSED ucdsed. UCDTRAN ucdtran. UCDSTM ucdstm.
         UCDANAL ucdanal. UCDMJ ucdmj. UCDINH ucdinh.
         UCDCOC ucdcoc. UCDHALL ucdhall. UCDHER ucdher.
         UCDOTHOP ucdothop. UCDNONE ucdnone. EFFCIG effcig.
         EFFALC effalc. EFFSED effsed. EFFTRAN efftran.
         EFFSTM effstm. EFFANAL effanal. EFFMJ effmj.
         EFFINH effinh. EFFCOC effcoc. EFFHALL effhall.
         EFFHER effher. EFFOTHOP effothop. EFFNONE effnone.
         UDAYCIG udaycig. UDAYALC udayalc. UDAYSED udaysed.
         UDAYTRAN udaytran. UDAYSTM udaystm. UDAYANAL udayanal.
         UDAYMJ udaymj. UDAYINH udayinh. UDAYCOC udaycoc.
         UDAYHALL udayhall. UDAYHER udayher. UDAYOTH udayoth.
         UDAYNONE udaynone. DEPCIG depcig. DEPALC depalc.
         DEPSED depsed. DEPTRAN deptran. DEPSTM depstm.
         DEPANAL depanal. DEPMJ depmj. DEPINH depinh.
         DEPCOC depcoc. DEPHALL dephall. DEPHER depher.
         DEPOTHOP depothop. DEPNONE depnone. WSCIG wscig.
         WSALC wsalc. WSSED wssed. WSTRAN wstran.
         WSSTM wsstm. WSANAL wsanal. WSMJ wsmj.
         WSINH wsinh. WSCOC wscoc. WSHALL wshall.
         WSHER wsher. WSOTHOP wsothop. WSNONE wsnone.
         NDLREAD ndlread. GNNDLLIF gnndllif. GNNDLREC gnndlrec.
         GNNDLSED gnndlsed. GNNDLTRA gnndltra. GNNDLSTM gnndlstm.
         GNNDLANL gnndlanl. GNNDLINH gnndlinh. GNNDLCOC gnndlcoc.
         GNNDLHAL gnndlhal. GNNDLHER gnndlher. GNNDLOPT gnndlopt.
         GNNDLSTR gnndlstr. GNNDLNON gnndlnon. GNNDLSH1 gnndlshf.
         GNNDLSH2 gnndls0f. SPTREAD sptread. DRUGTEST drugtest.
         TESTPOS testpos. ICELIFE icelife. ICEREC icerec.
         STEROPP steropp. STERAGE sterage. STERTOT stertot.
         STERREC sterrec. SPNEWA spnewa. SPNEWB spnewb.
         SPNEWC spnewc. SPNEWD spnewd. SPNEWE spnewe.
         BOOKED booked. NOBOOKYR nobookyr. BKLARCNY bklarcny.
         BKBURGL bkburgl. BKAGASLT bkagaslt. BKSMASLT bksmaslt.
         BKMVTHFT bkmvthft. BKROB bkrob. BKRAPE bkrape.
         BKMURDER bkmurder. BKARSON bkarson. BKDRVINF bkdrvinf.
         BKDRUNK bkdrunk. BKDRUG bkdrug. BKPROS bkpros.
         BKVANDAL bkvandal. BKOTHOFF bkothoff. NOTBKED notbked.
         PROBATON probaton. PAROLE parole. STRSTEAL strsteal.
         OTHSTEAL othsteal. DAMAGE damage. CARSTEAL carsteal.
         FORCEMON forcemon. BREAKIN breakin. PHYFIGHT phyfight.
         HURTBAD hurtbad. GUNMONEY gunmoney. DRUNKDRV drunkdrv.
         SOLDDRUG solddrug. OTHDOING othdoing. OTHDOSP1 othdospf.
         OTHDOSP2 othdos0f. DEXREAD dexread. NOBOOZYR noboozyr.
         ALCAGGR alcaggr. ALCARGUM alcargum. ALCABSNT alcabsnt.
         ALCHIGH alchigh. ALCJOB alcjob. ALCMATCD alcmatcd.
         ALCRELCD alcrelcd. ALCFRDCD alcfrdcd. ALCTOSS alctoss.
         ALCHOLIC alcholic. ALCDRUNK alcdrunk. ALCINTOX alcintox.
         ALCREM alcrem. ALCQUICK alcquick. ALCMORN alcmorn.
         ALCSHOOK alcshook. ALCALONE alcalone. ALCBRKPM alcbrkpm.
         ALCMJ alcmj. ALCCOC alccoc. ALCOPT alcopt.
         ALCHAL alchal. ALCINH alcinh. ALCANAL alcanal.
         ALCTRAN alctran. ALCSTM alcstm. ALCSED alcsed.
         AS13NONE as13none. DRDEPRSS drdeprss. DEPDRG1A depdrg1a.
         DEPDRG2A depdrg2a. DEPDRG3A depdrg3a. DEPDRG4A depdrg4a.
         DEPDRG5A depdrg5a. DRARGUM drargum. ARGDRG1A argdrg1a.
         ARGDRG2A argdrg2a. ARGDRG3A argdrg3a. ARGDRG4A argdrg4a.
         ARGDRG5A argdrg5a. DRALONE dralone. ALNDRG1A alndrg1a.
         ALNDRG2A alndrg2a. ALNDRG3A alndrg3a. ALNDRG4A alndrg4a.
         ALNDRG5A alndrg5a. DRANX dranx. ANXDRG1A anxdrg1a.
         ANXDRG2A anxdrg2a. ANXDRG3A anxdrg3a. ANXDRG4A anxdrg4a.
         ANXDRG5A anxdrg5a. DRHEALTH drhealth. HLTDRG1A hltdrg1a.
         HLTDRG2A hltdrg2a. HLTDRG3A hltdrg3a. HLTDRG4A hltdrg4a.
         HLTDRG5A hltdrg5a. DRNTHINK drnthink. NTKDRG1A ntkdrg1a.
         NTKDRG2A ntkdrg2a. NTKDRG3A ntkdrg3a. NTKDRG4A ntkdrg4a.
         NTKDRG5A ntkdrg5a. DRUPSET drupset. UPSDRG1A upsdrg1a.
         UPSDRG2A upsdrg2a. UPSDRG3A upsdrg3a. UPSDRG4A upsdrg4a.
         UPSDRG5A upsdrg5a. DRLSWORK drlswork. LSWDRG1A lswdrg1a.
         LSWDRG2A lswdrg2a. LSWDRG3A lswdrg3a. LSWDRG4A lswdrg4a.
         LSWDRG5A lswdrg5a. DRSUSPIC drsuspic. SSPDRG1A sspdrg1a.
         SSPDRG2A sspdrg2a. SSPDRG3A sspdrg3a. SSPDRG4A sspdrg4a.
         SSPDRG5A sspdrg5a. DRCOPE drcope. CPEDRG1A cpedrg1a.
         CPEDRG2A cpedrg2a. CPEDRG3A cpedrg3a. CPEDRG4A cpedrg4a.
         CPEDRG5A cpedrg5a. DREMGMED dremgmed. EMDRG1A emdrg1a.
         EMDRG2A emdrg2a. EMDRG3A emdrg3a. EMDRG4A emdrg4a.
         EMDRG5A emdrg5a. DRTRMT drtrmt. TMTDRG1A tmtdrg1a.
         TMTDRG2A tmtdrg2a. TMTDRG3A tmtdrg3a. TMTDRG4A tmtdrg4a.
         TMTDRG5A tmtdrg5a. DRDRVUN drdrvun. DRVDRG1A drvdrg1a.
         DRVDRG2A drvdrg2a. DRVDRG3A drvdrg3a. DRVDRG4A drvdrg4a.
         DRVDRG5A drvdrg5a. TMTREAD tmtread. EMPDRUG empdrug.
         CIGHELP cighelp. DRNKHELP drnkhelp. TRMTHELP trmthelp.
         TRMTEMRG trmtemrg. TRMTHOSP trmthosp. TRMTDOC trmtdoc.
         TRMTTRMT trmttrmt. TRMTMHC trmtmhc. TRMTSHG trmtshg.
         TRMTSOP trmtsop. TRMTSP trmtsp. TRMTREC trmtrec.
         NRTXLIFE nrtxlife. NOTRMT notrmt. TXEMRG txemrg.
         TXHOSP txhosp. TXDOC txdoc. TXTRMT txtrmt.
         TXMHC txmhc. TXSHG txshg. TXSOP txsop.
         TXSP txsp. TRMTLIFE trmtlife. TRMTRESP trmtresp.
         TRMTFEAR trmtfear. TRMTCOST trmtcost. TRMTEVNT trmtevnt.
         TRMTPR trmtpr. TRMTHLTH trmthlth. TRMTJOB trmtjob.
         TRMTJAIL trmtjail. TRMTSERV trmtserv. TRMTBQD trmtbqd.
         TRMTDNA trmtdna. TRMTSOR trmtsor. TRMTRSP trmtrsp.
         TRMTDRGA trmtdrga. TRMTDRGB trmtdrgb. TRMTDRGC trmtdrgc.
         TRMTDRGD trmtdrgd. TRMTDRGE trmtdrge. TRMTOUTC trmtoutc.
         TMTPHI tmtphi. TMTPSAVE tmtpsave. TMTPFMLY tmtpfmly.
         TMTPEMPR tmtpempr. TMTPMEDI tmtpmedi. TMTPFREE tmtpfree.
         TMTPOTH tmtpoth. TMTPASP tmtpasp. RSKPKCIG rskpkcig.
         RSKTRYMJ rsktrymj. RSKMJOCC rskmjocc. RSKMJREG rskmjreg.
         RKTRYPCP rktrypcp. RKPCPREG rkpcpreg. RKTRYHER rktryher.
         RKHERREG rkherreg. RKTRYCOC rktrycoc. RKCOCOCC rkcococc.
         RKCOCREG rkcocreg. RKCRKOCC rkcrkocc. RKANSOCC rkansocc.
         RKANSREG rkansreg. RK2DRINK rk2drink. RK5DRINK rk5drink.
         RSKBINGE rskbinge. RSKDIFMJ rskdifmj. RKDIFLSD rkdiflsd.
         RKDIFPCP rkdifpcp. RKDIFCOC rkdifcoc. RKDIFHER rkdifher.
         RSKSELL rsksell. RKNEIDRN rkneidrn. RKNEISEL rkneisel.
         HIGHBP highbp. BPMED bpmed. WALKPAIN walkpain.
         TIMEPAIN timepain. UPSHOR upshor. ASTHMA asthma.
         TRPSYCH trpsych. HEART heart. FLU flu.
         ALLERG allerg. HOSPYR hospyr. SOREYR soreyr.
         RUNNYYR runnyyr. COUGHYR coughyr. PHLEGMYR phlegmyr.
         HEALTHYR healthyr. FLTEAT flteat. FLTMIND fltmind.
         FLTDEPRS fltdeprs. FLTEFFRT flteffrt. FLTSLEEP fltsleep.
         FLTSAD fltsad. FLTGOING fltgoing. MARITAL marital.
         NOMARR nomarr. WORKSTAT workstat. PAYMO paymo.
         PAYYR payyr. NO5JOB no5job. WORKDAYS workdays.
         WORKBLAH workblah. CWE cwe. CWESC1 cwesc1ff.
         CWESC2 cwesc2ff. FULLPART fullpart. EDUC educ.
         GRADHS gradhs. DIPLOMA diploma. ENROLLD enrolld.
         SCHPLANS schplans. STUDENT student. SCHDAYS schdays.
         SKIPPED skipped. MILES miles. ACCID accid.
         TOTPEOP totpeop. MOTHER mother. FATHER father.
         STEPMOM stepmom. STEPDAD stepdad. SPOUSE spouse.
         INLAW inlaw. OWNCHILD ownchild. STEPCHLD stepchld.
         BROSIS brosis. OTHREL othrel. FRIENDS friends.
         OTHERNON othernon. MOVDAWAY movdaway. DORM dorm.
         MILBASE milbase. HOSP hosp. OTHGPH othgph.
         OTHGPHSP othgphsp. SERVICE service. MILSTAT milstat.
         TELNO telno. MOVES moves. NOFAMRES nofamres.
         PROXABLE proxable. PROXYREL proxyrel. PROXHOME proxhome.
         PROXJOIN proxjoin. MEDICARE medicare. MEDICAID medicaid.
         CHAMPUS champus. PRVHLTIN prvhltin. OWNHLTIN ownhltin.
         GRPHLTIN grphltin. HLTINALC hltinalc. HLTINDRG hltindrg.
         HLTINMNT hltinmnt. WHOANSHI whoanshi. JOB job.
         HOURS hours. WORK work. WAG1 wag1ffff.
         AWAG1 awag1fff. WEEKS weeks. SOC1 soc1ffff.
         ASOC1 asoc1fff. SSI1 ssi1ffff. ASSI1 assi1fff.
         PUB1 pub1ffff. AFDC1 afdc1fff. WEL1 wel1ffff.
         AWEL1 awel1fff. INT1 int1ffff. AINT1 aint1fff.
         CHD1 chd1ffff. ACHD1 achd1fff. OTH1 oth1ffff.
         AOTH1 aoth1fff. FAMLYRES famlyres. WAG2 wag2ffff.
         AWAG2 awag2fff. SOC2 soc2ffff. ASOC2 asoc2fff.
         SSI2 ssi2ffff. ASSI2 assi2fff. PUB2 pub2ffff.
         AFDC2 afdc2fff. WEL2 wel2ffff. AWEL2 awel2fff.
         INT2 int2ffff. AINT2 aint2fff. CHD2 chd2ffff.
         ACHD2 achd2fff. OTH2 oth2ffff. AOTH2 aoth2fff.
         WHOANSIN whoansin. FSTAMP fstamp. PEOPFD peopfd.
         FOOD food. AFOOD afood. BAP bap.
         EAP eap. LANGVER langver. UNDINT undint.
         COOPINT coopint. PRIVACY privacy. PPRES ppres.
         SPRES spres. PARPRES parpres. OARPRES oarpres.
         OAPRES oapres. CPRES cpres. OPRESNSP opresnsp.
         OPRESSPA opresspa. OPRESSPB opresspb. WHOMARKD whomarkd.
         QUARTER quarter. FAMSKIP famskip. PDEN pden.
         GQTYPE gqtype. PDEN2 pden2fff. DC dc.
         CHICAGO chicago. DENVER denver. LA la.
         MIAMI miami. NEWYORK newyork. REGION region.
         DIVISION division. CENCTY cencty. URBARE urbare.
         METRO metro. CENTRALC centralc. IIAGE iiage.
         IRSEX irsex. IISEX iisex. IRRACE irrace.
         IIRACE iirace. IRHOIND irhoind. IIHOIND iihoind.
         IRHOGRP irhogrp. IIHOGRP iihogrp. IRHOGRP2 irhogrpf.
         IIHOGRP2 iihogrpf. IRMARIT irmarit. IIMARIT iimarit.
         IREDUC ireduc. IIEDUC iieduc. IRHSGRAD irhsgrad.
         IIHSGRAD iihsgrad. IRWORKST irworkst. IIWORKST iiworkst.
         IRPINSUR irpinsur. IIPINSUR iipinsur. IRINSUR irinsur.
         IIINSUR iiinsur. IRWAG1 irwag1ff. IIWAG1 iiwag1ff.
         IRAWAG1 irawag1f. IIAWAG1 iiawag1f. IRSOC1 irsoc1ff.
         IISOC1 iisoc1ff. IRASOC1 irasoc1f. IIASOC1 iiasoc1f.
         IRSSI1 irssi1ff. IISSI1 iissi1ff. IRASSI1 irassi1f.
         IIASSI1 iiassi1f. IRWEL1 irwel1ff. IIWEL1 iiwel1ff.
         IRAWEL1 irawel1f. IIAWEL1 iiawel1f. IRINT1 irint1ff.
         IIINT1 iiint1ff. IRAINT1 iraint1f. IIAINT1 iiaint1f.
         IRCHD1 irchd1ff. IICHD1 iichd1ff. IRACHD1 irachd1f.
         IIACHD1 iiachd1f. IROTH1 iroth1ff. IIOTH1 iioth1ff.
         IRAOTH1 iraoth1f. IIAOTH1 iiaoth1f. IRWAG2 irwag2ff.
         IIWAG2 iiwag2ff. IRAWAG2 irawag2f. IIAWAG2 iiawag2f.
         IRSOC2 irsoc2ff. IISOC2 iisoc2ff. IRASOC2 irasoc2f.
         IIASOC2 iiasoc2f. IRSSI2 irssi2ff. IISSI2 iissi2ff.
         IRASSI2 irassi2f. IIASSI2 iiassi2f. IRWEL2 irwel2ff.
         IIWEL2 iiwel2ff. IRAWEL2 irawel2f. IIAWEL2 iiawel2f.
         IRINT2 irint2ff. IIINT2 iiint2ff. IRAINT2 iraint2f.
         IIAINT2 iiaint2f. IRCHD2 irchd2ff. IICHD2 iichd2ff.
         IRACHD2 irachd2f. IIACHD2 iiachd2f. IROTH2 iroth2ff.
         IIOTH2 iioth2ff. IRAOTH2 iraoth2f. IIAOTH2 iiaoth2f.
         IRFOOD irfood. IIFOOD iifood. IRAFOOD irafood.
         IIAFOOD iiafood. IRALCRC iralcrc. IIALCRC iialcrc.
         IRMJRC irmjrc. IIMJRC iimjrc. IRCOCRC ircocrc.
         IICOCRC iicocrc. IRSEDRC irsedrc. IISEDRC iisedrc.
         IRTRNRC irtrnrc. IITRNRC iitrnrc. IRSTMRC irstmrc.
         IISTMRC iistmrc. IRANLRC iranlrc. IIANLRC iianlrc.
         IRCIGRC ircigrc. IICIGRC iicigrc. IROTBRC irotbrc.
         IIOTBRC iiotbrc. IRINHRC irinhrc. IIINHRC iiinhrc.
         IRCRKRC ircrkrc. IICRKRC iicrkrc. IRHALRC irhalrc.
         IIHALRC iihalrc. IRHERRC irherrc. IIHERRC iiherrc.
         IRPCPRC irpcprc. IIPCPRC iipcprc. IRICERC iricerc.
         IIICERC iiicerc. IRSTRRC irstrrc. IISTRRC iistrrc.
         IRALCFQ iralcfq. IIALCFQ iialcfq. IRMJFQ irmjfq.
         IIMJFQ iimjfq. IRCOCFQ ircocfq. IICOCFQ iicocfq.
         IRSEDFQ irsedfq. IISEDFQ iisedfq. IRTRNFQ irtrnfq.
         IITRNFQ iitrnfq. IRSTMFQ irstmfq. IISTMFQ iistmfq.
         IRANLFQ iranlfq. IIANLFQ iianlfq. IROTBFQ irotbfq.
         IIOTBFQ iiotbfq. IRINHFQ irinhfq. IIINHFQ iiinhfq.
         IRHALFQ irhalfq. IIHALFQ iihalfq. CATAGE catage.
         CATAG2 catag2ff. CATAG3 catag3ff. RACE race.
         HISPRACE hisprace. EDUCCAT2 educcatf. EMPSTAT2 empstatf.
         IIINDINC iiindinc. INDCAT indcat. PERINC perinc.
         PERINC2 perinc2f. PERINC3 perinc3f. TOTINC totinc.
         IITOTINC iitotinc. TOTCAT totcat. FAMINC faminc.
         FAMINC2 faminc2f. FAMINC3 faminc3f. WELFARE welfare.
         HALFLAG halflag. HALYR halyr. HALMON halmon.
         PCPFLAG pcpflag. PCPYR pcpyr. PCPMON pcpmon.
         STMFLAG stmflag. STMYR stmyr. STMMON stmmon.
         SEDFLAG sedflag. SEDYR sedyr. SEDMON sedmon.
         TRQFLAG trqflag. TRQYR trqyr. TRQMON trqmon.
         ANLFLAG anlflag. ANLYR anlyr. ANLMON anlmon.
         ALCFLAG alcflag. ALCYR alcyr. ALCMON alcmon.
         CIGFLAG cigflag. CIGYR cigyr. CIGMON cigmon.
         SMKFLAG smkflag. SMKYR smkyr. SMKMON smkmon.
         HERFLAG herflag. HERYR heryr. HERMON hermon.
         STRFLAG strflag. STRYR stryr. STRMON strmon.
         MRJFLAG mrjflag. MRJYR mrjyr. MRJMON mrjmon.
         COCFLAG cocflag. COCYR cocyr. COCMON cocmon.
         CRKFLAG crkflag. CRKYR crkyr. CRKMON crkmon.
         INHFLAG inhflag. INHYR inhyr. INHMON inhmon.
         ICEFLAG iceflag. ICEYR iceyr. ICEMON icemon.
         NEEDLREC needlrec. NDL90REC ndl90rec. NEDFLAG3 nedflagf.
         NEDYR3 nedyr3ff. HALYRF halyrf. HALMONF halmonf.
         HALWKF halwkf. HALOCCF haloccf. HALDLYF haldlyf.
         STMYRF stmyrf. STMMONF stmmonf. STMWKF stmwkf.
         STMOCCF stmoccf. STMDLYF stmdlyf. SEDYRF sedyrf.
         SEDMONF sedmonf. SEDWKF sedwkf. SEDOCCF sedoccf.
         SEDDLYF seddlyf. TRQYRF trqyrf. TRQMONF trqmonf.
         TRQWKF trqwkf. TRQOCCF trqoccf. TRQDLYF trqdlyf.
         ANLYRF anlyrf. ANLMONF anlmonf. ANLWKF anlwkf.
         ANLOCCF anloccf. ANLDLYF anldlyf. ALCYRF alcyrf.
         ALCMONF alcmonf. ALCWKF alcwkf. ALCOCCF alcoccf.
         ALCDLYF alcdlyf. SMKYRF smkyrf. SMKMONF smkmonf.
         SMKWKF smkwkf. SMKOCCF smkoccf. SMKDLYF smkdlyf.
         MRJYRF mrjyrf. MRJMONF mrjmonf. MRJWKF mrjwkf.
         MRJOCCF mrjoccf. MRJDLYF mrjdlyf. COCYRF cocyrf.
         COCMONF cocmonf. COCWKF cocwkf. COCOCCF cococcf.
         COCDLYF cocdlyf. INHYRF inhyrf. INHMONF inhmonf.
         INHWKF inhwkf. INHOCCF inhoccf. INHDLYF inhdlyf.
         PSYFLAG2 psyflagf. PSYYR2 psyyr2ff. PSYMON2 psymon2f.
         SUMFLAG sumflag. SUMYR sumyr. SUMMON summon.
         MJOFLAG mjoflag. MJOYR2 mjoyr2ff. MJOMON2 mjomon2f.
         IEMFLAG iemflag. IEMYR iemyr. IEMMON iemmon.
         HSPHCONC hsphconc. HSPPCONC hsppconc. OWNOCONC ownoconc.
         UCLASS9 uclass9f. QC06 qc06ffff. QC09 qc09ffff.
         AL02 al02ffff. SE04 se04ffff. TR04 tr04ffff.
         ST04 st04ffff. ST07 st07ffff. AN04 an04ffff.
         MJ04 mj04ffff. IN04 in04ffff. CC04 cc04ffff.
         CC11 cc11ffff. CK01 ck01ffff. LS05 ls05ffff.
         LS08 ls08ffff. HE04 he04ffff. HE07 he07ffff.
         ND02 nd02ffff. SP04 sp04ffff. SP08 sp08ffff.
         MJTOT2 mjtot2ff. COCTOT2 coctot2f. MJTOT3 mjtot3ff.
         COCTOT3 coctot3f. MJDY30A2 mjdy30af. ALCDAYS2 alcdaysf.
         MRJMON2 mrjmon2f. ALCMON2 alcmon2f. CIGMON2 cigmon2f.
         LSD2 lsd2ffff. PEYOTE2 peyote2f. MESC2 mesc2fff.
         PSILCY2 psilcy2f. ECSTASY2 ecstasyf. GAS2 gas2ffff.
         LGAS2 lgas2fff. SPPAINT2 sppaintf. AEROS2 aeros2ff.
         GLUE2 glue2fff. SOLVENT2 solventf. AMYLNIT2 amylnitf.
         ETHER2 ether2ff. NITOXID2 nitoxidf. CLEFLU2 cleflu2f.
         COCSNIF2 cocsni0f. FREEBAS2 freebasf. COCSWAL2 cocswalf.
         COCIV2 cociv2ff. MJDY30A3 mjdy300f. ALCDAYS3 alcday0f.
         DRINKER2 drinkerf. HVYDRK2 hvydrk2f. AVCIG2 avcig2ff.
         RACESEX racesex. NOTMARJ notmarj. COCWAY2 cocway2f.
         RACESEX2 racesexf. IRCDCIG ircdcig. IRCDALC ircdalc.
         IRCDMJ ircdmj. IRCDCOC ircdcoc. IREFCIG irefcig.
         IREFALC irefalc. IREFMJ irefmj. IREFCOC irefcoc.
         IRUDCIG irudcig. IRUDALC irudalc. IRUDMJ irudmj.
         IRUDCOC irudcoc. IRDPCIG irdpcig. IRDPALC irdpalc.
         IRDPMJ irdpmj. IRDPCOC irdpcoc. IRWSCIG irwscig.
         IRWSALC irwsalc. IRWSMJ irwsmj. IRWSCOC irwscoc.
         AVCIG3 avcig3ff. ALCPROBS alcprobs. MJPROBS mjprobs.
         COCPROBS cocprobs. CIGPROBS cigprobs. IRALCAGG iralcagg.
         IRALCARG iralcarg. IRALCABS iralcabs. IRALCHIG iralchig.
         IRALCJOB iralcjob. IRALCMAT iralcmat. IRALCREL iralcrel.
         IRALCFRD iralcfrd. IRALCTOS iralctos. IRALCHOL iralchol.
         IRALCDRU iralcdru. IRALCINT iralcint. IRALCREM iralcrem.
         IRALCQUI iralcqui. IRALCMOR iralcmor. IRALCSHO iralcsho.
         IRALCALO iralcalo. IRALCBRK iralcbrk. IRNOBOOZ irnobooz.
         ANYALC anyalc. THREALC threalc. DRUNKYR2 drunkyrf.
         IRDEP irdep. IRARG irarg. IRALN iraln.
         IRANX iranx. IRHLT irhlt. IRNTK irntk.
         IRUPS irups. IRLSW irlsw. IRSSP irssp.
         IRCPE ircpe. IREMG iremg. IRDEP1 irdep1ff.
         IRDEP2 irdep2ff. IRDEP3 irdep3ff. IRDEP4 irdep4ff.
         IRDEP5 irdep5ff. IRARG1 irarg1ff. IRARG2 irarg2ff.
         IRARG3 irarg3ff. IRARG4 irarg4ff. IRARG5 irarg5ff.
         IRALN1 iraln1ff. IRALN2 iraln2ff. IRALN3 iraln3ff.
         IRALN4 iraln4ff. IRALN5 iraln5ff. IRANX1 iranx1ff.
         IRANX2 iranx2ff. IRANX3 iranx3ff. IRANX4 iranx4ff.
         IRANX5 iranx5ff. IRHLT1 irhlt1ff. IRHLT2 irhlt2ff.
         IRHLT3 irhlt3ff. IRHLT4 irhlt4ff. IRHLT5 irhlt5ff.
         IRNTK1 irntk1ff. IRNTK2 irntk2ff. IRNTK3 irntk3ff.
         IRNTK4 irntk4ff. IRNTK5 irntk5ff. IRUPS1 irups1ff.
         IRUPS2 irups2ff. IRUPS3 irups3ff. IRUPS4 irups4ff.
         IRUPS5 irups5ff. IRLSW1 irlsw1ff. IRLSW2 irlsw2ff.
         IRLSW3 irlsw3ff. IRLSW4 irlsw4ff. IRLSW5 irlsw5ff.
         IRSSP1 irssp1ff. IRSSP2 irssp2ff. IRSSP3 irssp3ff.
         IRSSP4 irssp4ff. IRSSP5 irssp5ff. IRCPE1 ircpe1ff.
         IRCPE2 ircpe2ff. IRCPE3 ircpe3ff. IRCPE4 ircpe4ff.
         IRCPE5 ircpe5ff. IREMG1 iremg1ff. IREMG2 iremg2ff.
         IREMG3 iremg3ff. IREMG4 iremg4ff. IREMG5 iremg5ff.
         IRAS13 iras13ff. DEPCIG2 depcig2f. DEPALC2 depalc2f.
         DEPMRJ2 depmrj2f. DEPCOC2 depcoc2f. ARGCIG2 argcig2f.
         ARGALC2 argalc2f. ARGMRJ2 argmrj2f. ARGCOC2 argcoc2f.
         ALNCIG2 alncig2f. ALNALC2 alnalc2f. ALNMRJ2 alnmrj2f.
         ALNCOC2 alncoc2f. ANXCIG2 anxcig2f. ANXALC2 anxalc2f.
         ANXMRJ2 anxmrj2f. ANXCOC2 anxcoc2f. HLTCIG2 hltcig2f.
         HLTALC2 hltalc2f. HLTMRJ2 hltmrj2f. HLTCOC2 hltcoc2f.
         NTKCIG2 ntkcig2f. NTKALC2 ntkalc2f. NTKMRJ2 ntkmrj2f.
         NTKCOC2 ntkcoc2f. UPSCIG2 upscig2f. UPSALC2 upsalc2f.
         UPSMRJ2 upsmrj2f. UPSCOC2 upscoc2f. LSWCIG2 lswcig2f.
         LSWALC2 lswalc2f. LSWMRJ2 lswmrj2f. LSWCOC2 lswcoc2f.
         SSPCIG2 sspcig2f. SSPALC2 sspalc2f. SSPMRJ2 sspmrj2f.
         SSPCOC2 sspcoc2f. CPECIG2 cpecig2f. CPEALC2 cpealc2f.
         CPEMRJ2 cpemrj2f. CPECOC2 cpecoc2f. EMCIG2 emcig2ff.
         EMALC2 emalc2ff. EMMRJ2 emmrj2ff. EMCOC2 emcoc2ff.
         PRB1CIG prb1cig. PRB1ALC prb1alc. PRB1MRJ prb1mrj.
         PRB1COC prb1coc. PRB2CIG prb2cig. PRB2ALC prb2alc.
         PRB2MRJ prb2mrj. PRB2COC prb2coc. PRB3CIG prb3cig.
         PRB3ALC prb3alc. PRB3MRJ prb3mrj. PRB3COC prb3coc.
         ANYPROB anyprob. TWOPROB twoprob. THREPROB threprob.
         ALCONLYL alconlyl. ALCONLYY alconlyy. ALCONLYM alconlym.
         ILLONLYL illonlyl. ILLONLYY illonlyy. ILLONLYM illonlym.
         MRJONLYL mrjonlyl. MRJONLYY mrjonlyy. MRJONLYM mrjonlym.
         PSYONLYL psyonlyl. PSYONLYY psyonlyy. PSYONLYM psyonlym.
         OTHONLYL othonlyl. OTHONLYY othonlyy. OTHONLYM othonlym.
         ALCILLL alcilll. ALCILLY alcilly. ALCILLM alcillm.
         ALCMRJL alcmrjl. ALCMRJY alcmrjy. ALCMRJM alcmrjm.
         ALCPSYL alcpsyl. ALCPSYY alcpsyy. ALCPSYM alcpsym.
         ALCOTHL alcothl. ALCOTHY alcothy. ALCOTHM alcothm.
         SUB1LIF sub1lif. SUB2LIF sub2lif. SUB3LIF sub3lif.
         SUB1YR sub1yr. SUB2YR sub2yr. SUB3YR sub3yr.
         SUB1MON sub1mon. SUB2MON sub2mon. SUB3MON sub3mon.
         CHANCMJ2 chancmjf. CHANCOC2 chancocf. CHANHAL2 chanhalf.
         CHANHER2 chanherf. TRMTHLP2 trmthlpf. DRNKHLP2 drnkhlpf.
         DRALHELP dralhelp. RURORURB rurorurb. PBLACKHH pblackhh.
         PBLACKP pblackp. PPOVERTY ppoverty. POWNED powned.
         PRENTED prented. OWNEDAVE ownedave. RENTAVE rentave.
         IRKIDS irkids. CWEOCC2 cweocc2f. ROCCUP2 roccup2f.
         CWEBUS2 cwebus2f. BUSINES2 businesf.  ;

RUN ;
